@@ -47,9 +47,10 @@
 #include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 /////////////////////// Local includes
+#include "../nongui/DiscoveriesPreferences.hpp"
 #include "../nongui/MsRunDataSet.hpp"
 #include "../nongui/ProcessingFlow.hpp"
-#include "../nongui/AnalysisPreferences.hpp"
+#include "MsFragmentationSpec.hpp"
 #include "MzIntegrationParamsDlg.hpp"
 
 namespace Ui
@@ -110,6 +111,28 @@ class BasePlotCompositeWidget: public QWidget
   void setMzIntegrationParams(
     const pappso::MzIntegrationParams &mz_integration_params);
 
+  pappso::FilterNameInterfaceCstSPtr filter(const QString filter_name,
+                                            const QCPAbstractPlottable *plottable_p) const;
+
+  bool isPinnedDown() const;
+
+  virtual const pappso::BasePlotWidget *getPlotWidget() const;
+
+  virtual const ProcessingFlow *getCstProcessingFlowPtrForPlottable(
+      const QCPAbstractPlottable *plottable_p) const;
+  virtual ProcessingFlow *getProcessingFlowPtrForPlottable(const QCPAbstractPlottable *plottable_p);
+
+  virtual void removePlottableProcessingFlowMapItem(const QCPAbstractPlottable *plottable_p);
+
+  virtual MsRunDataSetCstSPtr getMsRunDataSetCstSPtrForPlottable(
+      const QCPAbstractPlottable *plottable_p) const;
+
+  QCPAbstractPlottable *plottableToBeUsedAsIntegrationSource() const;
+  QCPAbstractPlottable *firstPlottable() const;
+  QList<QCPAbstractPlottable *> plottablesToBeUsedAsIntegrationDestination() const;
+
+  virtual bool isFocussed() const;
+
   public slots:
 
   virtual void lastCursorHoveredPoint(const QPointF &pointf);
@@ -141,32 +164,7 @@ class BasePlotCompositeWidget: public QWidget
 
   void msFragmentationSpecChanged(MsFragmentationSpec ms_fragmentation_spec);
 
-  pappso::FilterNameInterfaceCstSPtr
-  filter(const QString filter_name,
-         const QCPAbstractPlottable *plottable_p) const;
-
   void pinDown(bool push_pinned);
-  bool isPinnedDown() const;
-
-  virtual const pappso::BasePlotWidget *getPlotWidget() const;
-
-  virtual const ProcessingFlow *getCstProcessingFlowPtrForPlottable(
-    const QCPAbstractPlottable *plottable_p) const;
-  virtual ProcessingFlow *
-  getProcessingFlowPtrForPlottable(const QCPAbstractPlottable *plottable_p);
-
-  virtual void
-  removePlottableProcessingFlowMapItem(const QCPAbstractPlottable *plottable_p);
-
-  virtual MsRunDataSetCstSPtr getMsRunDataSetCstSPtrForPlottable(
-    const QCPAbstractPlottable *plottable_p) const;
-
-  QCPAbstractPlottable *plottableToBeUsedAsIntegrationSource() const;
-  QCPAbstractPlottable *firstPlottable() const;
-  QList<QCPAbstractPlottable *>
-  plottablesToBeUsedAsIntegrationDestination() const;
-
-  void mainMenuPushButtonClicked();
 
   void showMsFragmentationSpecDlg();
   void showMzIntegrationParamsDlg();
@@ -206,6 +204,7 @@ class BasePlotCompositeWidget: public QWidget
 
   QString getAnalysisStanza();
   QString craftAnalysisStanza(const pappso::BasePlotContext &context);
+  QString craftAnalysisStanzaOld(const pappso::BasePlotContext &context);
 
   void setPlottingColor(QCPAbstractPlottable *plottable_p, const QColor &color);
   void setSampleNameColor(const QColor &color);
@@ -238,7 +237,7 @@ class BasePlotCompositeWidget: public QWidget
   QString m_axisLabelX;
   QString m_axisLabelY;
 
-  mutable double m_lastTicIntensity = 0;
+  mutable double m_lastTicIntensity = qQNaN();
 
   MsFragmentationSpec m_msFragmentationSpec;
   MsFragmentationSpecDlg *mp_msFragmentationSpecifDlg = nullptr;
@@ -259,6 +258,8 @@ class BasePlotCompositeWidget: public QWidget
   //! Color used for the background of focused plot.
   QBrush m_focusedBrush = QBrush(m_focusedColor);
 
+  bool m_isFocussed = false;
+
   //! Key code of the last keyboard key being pressed.
   int m_plotWidgetPressedKeyCode;
 
@@ -279,9 +280,9 @@ class BasePlotCompositeWidget: public QWidget
   QMenu *mp_plotGraphicsMenu = nullptr;
 
   virtual void setupWidget() = 0;
-  virtual void createMainMenu();
+  void createMainMenu();
   QFile *getAnalysisFilePtr();
-  AnalysisPreferences *getAnalysisPreferences();
+  DiscoveriesPreferences *getDiscoveriesPreferences();
 
   QString m_analysisStanza;
 };
