@@ -35,11 +35,11 @@
 
 
 /////////////////////// Qt includes
-#include <QSettings>
-#include <QMenuBar>
-#include <QMenu>
 #include <QDebug>
-#include <QtConcurrent>
+#include <QMenu>
+#include <QMenuBar>
+#include <QSettings>
+#include <QStyleOptionSlider>
 
 /////////////////////// pappsomspp includes
 
@@ -52,8 +52,9 @@
 #include "MzIntegrationParamsDlg.hpp"
 #include "PlotAreaOverlay.hpp"
 #include "ProgramWindow.hpp"
-#include "ui_BasePlotWnd.h"
+#include "SaveToGraphicsFileDlg.hpp"
 #include "ui_BasePlotCompositeWidget.h"
+#include "ui_BasePlotWnd.h"
 
 namespace MsXpS
 {
@@ -74,12 +75,12 @@ BasePlotWnd::BasePlotWnd(QWidget *parent,
     m_ui(new ::Ui::BasePlotWnd)
 {
   if(parent == Q_NULLPTR)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   m_ui->setupUi(this);
 
   if(!initialize())
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 }
 
 //! Destruct \c this BasePlotWnd instance.
@@ -213,7 +214,7 @@ BasePlotWnd::initialize()
   // At this point that the overlay plot has been created, we can create the
   // slider that will govern the position of the vertical rule that span the
   // whole height of the scroll area.
-  mp_vertRuleSlider = new QSlider(Qt::Horizontal, mp_centralWidget);
+  mp_vertRuleSlider = new VerticalRuleSlider(mp_centralWidget);
   mp_vertRuleSlider->setSingleStep(1);
   mp_vertRuleSlider->setPageStep(1);
   mp_vertRuleSlider->setMinimum(1);
@@ -226,9 +227,9 @@ BasePlotWnd::initialize()
   mp_centralWidgetGridLayout->addWidget(mp_vertRuleSlider, 0, 0);
 
   connect(mp_vertRuleSlider,
-          &QSlider::valueChanged,
+          &VerticalRuleSlider::sliderHandleCenterPositionXChangedSignal,
           this,
-          &BasePlotWnd::verticalRulerSliderValueChanged);
+          &BasePlotWnd::verticalRuleSliderValueChanged);
 
   readSettings();
 
@@ -236,7 +237,7 @@ BasePlotWnd::initialize()
 }
 
 void
-BasePlotWnd::verticalRulerSliderValueChanged(int value)
+BasePlotWnd::verticalRuleSliderValueChanged(int x_position)
 {
   // The user has modified the position of the slider, which means we need to
   // update the position of the vertical rule that spans all the composite plot
@@ -244,13 +245,73 @@ BasePlotWnd::verticalRulerSliderValueChanged(int value)
 
   // qDebug() << "The vertical ruler slide has value:" << value;
 
-  // We need the plot overlay widget to know the current value of the slider,
-  // that represents the position of the vertical ruler.
-  mpa_plotAreaOverlay->setLastHorSliderValue(value);
+  // We need the plot-overlay-widget to know the current value of the slider,
+  // that represents the position of the vertical ruler. Using the new value,
+  // the update call below will plot the vertical line at the right position.
 
-  // Now that the new position of the rule is known, we can update the widget so
-  // that it repaints itself, thus drawing the vertical line at the right
-  // position.
+  mpa_plotAreaOverlay->setLastHorSliderValue(x_position);
+  qDebug() << "Now setting the last horizontal slider value to" << x_position;
+
+  // There is one provision: if the plot widgets in this plot window are locked
+  // in their x-axis, then we want to show on the slider handle the x-axis
+  // value that it is hovering over.
+
+  if(m_isLockedXRange)
+    {
+      // qDebug() << "The XRange is locked.";
+
+      // We want to display the x-axis value on the rule vertical slider handle.
+      // Get the list of plot composite widgets that are in this window.
+
+      QList<BasePlotCompositeWidget *> widget_list =
+        findChildren<BasePlotCompositeWidget *>("plotCompositeWidget");
+
+      // If there are not plot composite widgets, there are not plottables
+      // (traces) there, and thus not x-axis value. Return.
+      if(!widget_list.size())
+        return;
+
+      BasePlotCompositeWidget *composite_widget_p = widget_list.first();
+      Q_ASSERT(composite_widget_p != nullptr);
+
+      // Iterate down from window coordinates to x-axis coordinates!
+
+      // First the composite widget coordinates:
+      QPointF composite_widget_coord =
+        composite_widget_p->mapFromParent(QPointF(x_position, 0));
+      // qDebug() << "composite_widget_coord_x:" << composite_widget_coord.x();
+
+      // Then the plot widget coordinates:
+      QPointF widget_coord = composite_widget_p->getPlotWidget()->mapFromParent(
+        composite_widget_coord);
+      // qDebug() << "widget_coord_x:" << widget_coord.x();
+
+      double x_axis_coordinate =
+        composite_widget_p->getPlotWidget()->xAxis->pixelToCoord(
+          widget_coord.x());
+      // qDebug() << "Plot widget xAxis x:" << x_axis_coordinate;
+
+#if 0
+      // This produces the same result as the above call.
+      QCPAbstractPlottable *plottable_p =
+        composite_widget_p->plottableToBeUsedAsIntegrationSource();
+      double coord_x = 0;
+      double coord_y = 0;
+      plottable_p->pixelsToCoords(widget_coord.x(), 0, coord_x, coord_y);
+      qDebug() << qSetRealNumberPrecision(5)
+               << "Plottable x:" << coord_x;
+#endif
+
+      mp_vertRuleSlider->updatePosLabelXaxisValue(x_axis_coordinate);
+    }
+  else
+    {
+      mp_vertRuleSlider->setXposLabelVisible(false);
+    }
+
+  // Now that the new position at which the rule needs to be drawn, we can
+  // update the widget so that it repaints itself, thus drawing the vertical
+  // line at the right position.
   mpa_plotAreaOverlay->update();
 }
 
@@ -351,54 +412,84 @@ BasePlotWnd::createMainMenu()
 {
   // The toolbar menu button
 
+  ProgramWindow *program_window_p =
+    static_cast<Application *>(qApp)->getProgramWindow();
+  QString action_label;
+  libXpertMassGui::ActionId action_id;
+  QKeySequence key_sequence;
+  QAction *action_p = nullptr;
+
   // The main menu in the form of a button with an icon like thoses found for
   // the menus in mobile phone applications.
-
   mp_mainMenu = new QMenu(this);
 
   const QIcon main_menu_icon =
     QIcon(":/images/svg/mobile-phone-like-menu-button.svg");
-  mp_mainMenuPushButton = new QPushButton(main_menu_icon, QString(""), this);
-  mp_mainMenuPushButton->setToolTip("Plot widget menu (Ctrl+W, M)");
-  mp_mainMenuPushButton->setShortcut(QKeySequence("Ctrl+W, M"));
 
-  // When the main menu push button is clicked, the menu show up.
-  connect(mp_mainMenuPushButton, &QPushButton::clicked, [this]() {
-    mp_mainMenu->show();
+  mp_mainMenuToolButton = new QToolButton(this);
+  mp_mainMenuToolButton->setIcon(main_menu_icon);
+  mp_mainMenuToolButton->setMenu(mp_mainMenu);
+
+  mp_toolBar->addWidget(mp_mainMenuToolButton);
+
+  key_sequence = QKeySequence("Ctrl+W, M");
+  action_label = QString("Plot window menu");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  mp_mainMenuToolButton->setToolTip(action_p->text());
+  // When the main menu push button is clicked, the menu shows up.
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(isActiveWindow())
+      {
+        // qDebug() << "Trigger." << this->windowTitle();
+
+        // Show the menu aligned to the bottom of the button, otherwise the menu
+        // appears at the top left corner of the screen.
+        mp_mainMenu->exec(mp_mainMenuToolButton->mapToGlobal(
+          QPoint(0, mp_mainMenuToolButton->height())));
+        // mp_mainMenu->show();
+      }
   });
 
-
   ////////////// MZ INTEG PARAMS and MS FRAG SPEC ////////////////////
   ////////////// MZ INTEG PARAMS and MS FRAG SPEC ////////////////////
 
   // We want to be able to set the mz integ params for all the plot widgets in
   // the window in one go.
 
-  QAction *new_act_p = new QAction(
-    "Set m/z &integration params for all pinned-down widgets", this);
-  new_act_p->setShortcut(QKeySequence("Ctrl+I, P"));
-
-  connect(new_act_p, &QAction::triggered, [this]() {
-    setMzIntegrationParamsForAllPlotWidgets();
+  key_sequence = QKeySequence("Ctrl+I, P");
+  action_label =
+    QString("Set m/z integration params for all pinned-down widgets");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(isActiveWindow())
+      setMzIntegrationParamsForAllPlotWidgets();
   });
-
-  mp_mainMenu->addAction(new_act_p);
+  mp_mainMenu->addAction(action_p);
 
   // We want to be able to set the ms fragmentation spec for all the plot
   // widgets in the window in one go.
 
-  new_act_p =
-    new QAction("Set MS &fragmentation spec for all pinned-down widgets", this);
-  new_act_p->setShortcut(QKeySequence("Ctrl+F, S"));
-
-  connect(new_act_p, &QAction::triggered, [this]() {
-    setMsFragmentationSpecForAllPlotWidgets();
+  key_sequence = QKeySequence("Ctrl+F, P");
+  action_label =
+    QString("Set MS fragmentation spec for all pinned-down widgets");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(isActiveWindow())
+      setMsFragmentationSpecForAllPlotWidgets();
   });
+  mp_mainMenu->addAction(action_p);
 
-  mp_mainMenu->addAction(new_act_p);
-
-  ////////////// MZ INTEG PARAMS and MS FRAG SPEC ////////////////////
-  ////////////// MZ INTEG PARAMS and MS FRAG SPEC ////////////////////
+  ////////////// END MZ INTEG PARAMS and MS FRAG SPEC ////////////////////
+  ////////////// END MZ INTEG PARAMS and MS FRAG SPEC ////////////////////
 
 
   // Separate the last added item from the rest.
@@ -408,20 +499,32 @@ BasePlotWnd::createMainMenu()
   ////////////// PLOT WIDGET MANAGEMENT ////////////////////
   ////////////// PLOT WIDGET MANAGEMENT ////////////////////
 
-  mp_plotWidgetManagementMenu = new QMenu("Plot &widget management", this);
+  mp_plotWidgetManagementMenu = new QMenu("Plot widget management", this);
   mp_mainMenu->addMenu(mp_plotWidgetManagementMenu);
 
   // An action to allow resizing all the plot widget to the mean size. Useful
   // when the user has resized to naught some plot widget and they want to get
   // back to their initial size.
-  mp_resetPlotSizesAct =
-    new QAction(tr("&Reset all the plot widget sizes"), this);
-  mp_resetPlotSizesAct->setStatusTip(tr("Reset all the plot widget sizes"));
-  mp_resetPlotSizesAct->setShortcut(QKeySequence("Ctrl+R, S"));
+
+  // Old version, remove when tested.
+  // mp_resetPlotSizesAct =
+  //   new QAction(tr("&Reset all the plot widget sizes"), this);
+  // mp_resetPlotSizesAct->setStatusTip(tr("Reset all the plot widget sizes"));
+  // mp_resetPlotSizesAct->setShortcut(QKeySequence("Ctrl+R, S"));
+
+  key_sequence = QKeySequence("Ctrl+R, S");
+  action_label = QString("Reset all the plot widget sizes");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
 
   // Lambda function to compute the right size for each plot widget in the
   // splitter.
-  connect(mp_resetPlotSizesAct, &QAction::triggered, [this]() {
+  connect(mp_resetPlotSizesAct, &QAction::triggered, this, [&]() {
+    if(!isActiveWindow())
+      return;
+
     // First off, if there are not widgets, do nothing, division by zero !!!
 
     if(!mp_splitter->count())
@@ -440,156 +543,172 @@ BasePlotWnd::createMainMenu()
 
     mp_splitter->setSizes(new_sizes);
   });
-
-  mp_plotWidgetManagementMenu->addAction(mp_resetPlotSizesAct);
+  // mp_plotWidgetManagementMenu->addAction(mp_resetPlotSizesAct);
+  mp_plotWidgetManagementMenu->addAction(action_p);
 
   QMenu *pin_unpin_plot_widgets_menu_p =
-    new QMenu("&Pin-down/Unpin plot widgets...", this);
+    new QMenu("Pin-down/Unpin plot widgets...", this);
   mp_plotWidgetManagementMenu->addMenu(pin_unpin_plot_widgets_menu_p);
 
-
   // An action to push-pin all the widgets.
+  key_sequence = QKeySequence("Ctrl+P, Ctrl+A");
+  action_label = QString("Pin-down all the widgets");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(!isActiveWindow())
+      return;
 
-  new_act_p = new QAction(tr("&Pin-down all the widgets"), this);
-  new_act_p->setStatusTip(tr("Pin-down all the widgets"));
-  new_act_p->setShortcut(QKeySequence("Ctrl+P, A"));
-
-  connect(new_act_p, &QAction::triggered, [this]() {
     std::vector<BasePlotCompositeWidget *> widget_list = allWidgets();
 
     for(auto &&widget_p : widget_list)
       widget_p->pinDown(true);
   });
-
-  pin_unpin_plot_widgets_menu_p->addAction(new_act_p);
+  pin_unpin_plot_widgets_menu_p->addAction(action_p);
 
   // An action to unpush-pin all the widgets.
+  key_sequence = QKeySequence("Ctrl+U, Ctrl+A");
+  action_label = QString("Un-pin all the widgets");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(!isActiveWindow())
+      return;
 
-  new_act_p = new QAction(tr("&Un-pin all the widgets"), this);
-  new_act_p->setStatusTip(tr("Un-pin all the widgets"));
-  new_act_p->setShortcut(QKeySequence("Ctrl+U, A"));
-
-  connect(new_act_p, &QAction::triggered, [this]() {
     std::vector<BasePlotCompositeWidget *> widget_list = allWidgets();
 
     for(auto &&widget_p : widget_list)
       widget_p->pinDown(false);
   });
-
-  pin_unpin_plot_widgets_menu_p->addAction(new_act_p);
+  pin_unpin_plot_widgets_menu_p->addAction(action_p);
 
   mp_plotWidgetManagementMenu->addSeparator();
 
-  QMenu *remove_plot_widgets_menu_p =
-    new QMenu("Remove plot &widgets...", this);
+  QMenu *remove_plot_widgets_menu_p = new QMenu("Remove plot widgets...", this);
   mp_plotWidgetManagementMenu->addMenu(remove_plot_widgets_menu_p);
 
-  QAction *remove_pinned_plot_widgets_p =
-    new QAction(tr("&Remove pinned-down plot widgets"), this);
-  remove_pinned_plot_widgets_p->setStatusTip(
-    tr("Remove pinned-down plot widgets"));
-  remove_pinned_plot_widgets_p->setShortcut(QKeySequence("Ctrl+R, P"));
+  // An action to remove all the pinned-down widgets.
+  key_sequence = QKeySequence("Ctrl+R, Ctrl+P");
+  action_label = QString("Remove pinned-down plot widgets");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(!isActiveWindow())
+      return;
 
-  connect(remove_pinned_plot_widgets_p, &QAction::triggered, [this]() {
     std::vector<BasePlotCompositeWidget *> widget_list = pinnedDownWidgets();
 
     for(auto &&widget_p : widget_list)
       plotCompositeWidgetDestructionRequested(widget_p);
   });
+  remove_plot_widgets_menu_p->addAction(action_p);
 
-  remove_plot_widgets_menu_p->addAction(remove_pinned_plot_widgets_p);
+  // An action to remove all the pinned-down widgets.
+  key_sequence = QKeySequence("Ctrl+R, Ctrl+D");
+  action_label = QString("Remove pinned-down plot widgets and descendants");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(!isActiveWindow())
+      return;
 
-  QAction *remove_pinned_plot_widgets_descendants_p =
-    new QAction(tr("Remove pinned-down plot widgets and &descendants"), this);
-  remove_pinned_plot_widgets_descendants_p->setStatusTip(
-    tr("Remove pinned-down plot widgets and descendants"));
-  remove_pinned_plot_widgets_descendants_p->setShortcut(
-    QKeySequence("Ctrl+R, Ctrl+P, D"));
+    std::vector<BasePlotCompositeWidget *> widget_list = pinnedDownWidgets();
 
-  connect(
-    remove_pinned_plot_widgets_descendants_p, &QAction::triggered, [this]() {
-      std::vector<BasePlotCompositeWidget *> widget_list = pinnedDownWidgets();
-
-      for(auto &&widget_p : widget_list)
-        plotCompositeWidgetDestructionRequested(widget_p);
-    });
-
-  remove_plot_widgets_menu_p->addAction(
-    remove_pinned_plot_widgets_descendants_p);
+    for(auto &&widget_p : widget_list)
+      plotCompositeWidgetDestructionRequested(widget_p);
+  });
+  remove_plot_widgets_menu_p->addAction(action_p);
 
   remove_plot_widgets_menu_p->addSeparator();
 
-  mp_removeEmptyPlotWidgetsAct =
-    new QAction(tr("Remove &empty plot widgets"), this);
-  mp_removeEmptyPlotWidgetsAct->setStatusTip(tr("Remove empty plot widgets"));
-  mp_removeEmptyPlotWidgetsAct->setShortcut(QKeySequence("Ctrl+R, E"));
+  // An action to remove all the empty plot widgets.
+  key_sequence = QKeySequence("Ctrl+R, Ctrl+E");
+  action_label = QString("Remove all the empty plot widgets");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(!isActiveWindow())
+      return;
 
-  connect(mp_removeEmptyPlotWidgetsAct,
-          &QAction::triggered,
-          this,
-          &BasePlotWnd::removeEmptyPlotWidgets);
+    BasePlotWnd::removeEmptyPlotWidgets();
+  });
+  remove_plot_widgets_menu_p->addAction(action_p);
 
-  remove_plot_widgets_menu_p->addAction(mp_removeEmptyPlotWidgetsAct);
+  // An action to remove all the plot widgets.
+  key_sequence = QKeySequence("Ctrl+R, Ctrl+A");
+  action_label = QString("Remove all the plot widgets");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    if(!isActiveWindow())
+      return;
 
-
-  mp_removeAllPlotWidgetsAct =
-    new QAction(tr("Remove &all plot widgets"), this);
-  mp_removeAllPlotWidgetsAct->setStatusTip(tr("Remove all plot widgets"));
-  mp_removeAllPlotWidgetsAct->setShortcut(QKeySequence("Ctrl+R, A"));
-
-  connect(mp_removeAllPlotWidgetsAct, &QAction::triggered, [this]() {
     QList<BasePlotCompositeWidget *> widget_list =
       findChildren<BasePlotCompositeWidget *>("plotCompositeWidget");
 
     while(widget_list.size())
       plotCompositeWidgetDestructionRequested(widget_list.takeLast());
   });
+  remove_plot_widgets_menu_p->addAction(action_p);
 
-  remove_plot_widgets_menu_p->addAction(mp_removeAllPlotWidgetsAct);
+#if 0
+  // It looks like this feature does not work.
+  // An action to remove all the plot widgets and descendants.
+  key_sequence = QKeySequence("Ctrl+Shift+R, Ctrl+A");
+  action_label = QString("Remove all the plot widgets and descendants");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger.";
 
-  mp_removeAllPlotWidgetsAndDescendantsAct =
-    new QAction(tr("Remove all plot widgets and d&escendants"), this);
-  mp_removeAllPlotWidgetsAndDescendantsAct->setStatusTip(
-    tr("Remove all plot widgets and descendants"));
-  mp_removeAllPlotWidgetsAndDescendantsAct->setShortcut(
-    QKeySequence("Ctrl+R, Ctrl+A, D"));
+    if(!isActiveWindow())
+      return;
 
-  connect(
-    mp_removeAllPlotWidgetsAndDescendantsAct, &QAction::triggered, [this]() {
-      QList<BasePlotCompositeWidget *> widget_list =
-        findChildren<BasePlotCompositeWidget *>("plotCompositeWidget");
+    QList<BasePlotCompositeWidget *> widget_list =
+      findChildren<BasePlotCompositeWidget *>("plotCompositeWidget");
 
-      while(widget_list.size())
-        // We want the removal to recursively remove all descendants
-        plotCompositeWidgetDestructionRequested(widget_list.takeLast());
-    });
+    while(widget_list.size())
+      // We want the removal to recursively remove all descendants
+      plotCompositeWidgetDestructionRequested(widget_list.takeLast());
+  });
+  remove_plot_widgets_menu_p->addAction(action_p);
+#endif
 
-  remove_plot_widgets_menu_p->addAction(
-    mp_removeAllPlotWidgetsAndDescendantsAct);
-
-  ////////////// PLOT WIDGET MANAGEMENT ////////////////////
-  ////////////// PLOT WIDGET MANAGEMENT ////////////////////
+  ////////////// END PLOT WIDGET MANAGEMENT ////////////////////
+  ////////////// END PLOT WIDGET MANAGEMENT ////////////////////
 
   mp_mainMenu->addSeparator();
 
-  QAction *save_plot_to_graphics_file_p =
-    new QAction("Save pinned plot(s) to &graphics file", this);
-  save_plot_to_graphics_file_p->setStatusTip(
-    tr("Save pinned plot(s) to graphics file"));
-  save_plot_to_graphics_file_p->setShortcut(QKeySequence("Ctrl+S, P"));
+  // An action to save all the pinned plot(s) to a graphics file.
+  key_sequence = QKeySequence("Ctrl+S, Ctrl+P");
+  action_label = QString("Save pinned plot(s) to graphics file");
+  action_id.initialize("Global", "Menus", "PlotWindow", action_label);
+  action_p = program_window_p->getActionManager()->installAction(action_id,
+                                                                 key_sequence);
+  this->addAction(action_p);
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger.";
 
-  mp_mainMenu->addAction(save_plot_to_graphics_file_p);
+    if(!isActiveWindow())
+      return;
 
-  connect(save_plot_to_graphics_file_p,
-          &QAction::triggered,
-          this,
-          &BasePlotWnd::savePinnedPlotsToGraphicsFile);
-
-  // The main menu is under the control of a push button.
-  mp_mainMenuPushButton->setMenu(mp_mainMenu);
-
-  // Finally add the main menu push button to the toolbar!
-  mp_toolBar->addWidget(mp_mainMenuPushButton);
+    BasePlotWnd::savePinnedPlotsToGraphicsFile();
+  });
+  mp_mainMenu->addAction(action_p);
 }
 
 void
@@ -610,7 +729,8 @@ BasePlotWnd::setMzIntegrationParamsForAllPlotWidgets()
   connect(
     mz_integration_params_dlg_p,
     &MzIntegrationParamsDlg::mzIntegrationParamsDlgShouldBeDestroyedSignal,
-    [this]() {
+    this,
+    [&]() {
       // qDebug();
       delete QObject::sender();
     });
@@ -709,7 +829,8 @@ BasePlotWnd::setMsFragmentationSpecForAllPlotWidgets()
   connect(
     ms_fragmentation_spec_dlg_p,
     &MsFragmentationSpecDlg::msFragmentationSpecDlgShouldBeDestroyedSignal,
-    [this]() {
+    this,
+    [&]() {
       // qDebug();
       delete QObject::sender();
     });
@@ -810,7 +931,7 @@ BasePlotWnd::integrateToTicIntensity(QCPAbstractPlottable *parent_plottable_p,
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // Pass the integrator the flow we got as param and that describes in its
   // most recent step the integration that it should perform.
@@ -972,7 +1093,7 @@ BasePlotWnd::integrateToTicIntensity(
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // First prepare a vector of QualifiedMassSpectrumCstSPtr
 
@@ -1184,6 +1305,9 @@ void
 BasePlotWnd::lockXRangeToggle(bool checked)
 {
   m_isLockedXRange = checked;
+  // qDebug() << "Is the lockXRange check button checked?:" << m_isLockedXRange;
+  mp_vertRuleSlider->computeHandlePosition();
+  mp_vertRuleSlider->setXposLabelVisible(m_isLockedXRange);
 }
 
 //! Set the y-axis range lock between all the plot widgets.
@@ -1191,14 +1315,19 @@ void
 BasePlotWnd::lockYRangeToggle(bool checked)
 {
   m_isLockedYRange = checked;
+  // qDebug() << "Is the lockYRange check button checked?:" << m_isLockedXRange;
 }
 
 void
 BasePlotWnd::lockYMarkerToggle(bool checked)
 {
   m_isLockedYMarker = checked;
-  mpa_plotAreaOverlay->setVertRulerVisible(m_isLockedYMarker);
+  mpa_plotAreaOverlay->setVertRuleVisible(m_isLockedYMarker);
   mp_vertRuleSlider->setVisible(m_isLockedYMarker);
+  mp_vertRuleSlider->computeHandlePosition();
+  // Only show the x axis value in the label if we are in locked X range mode.
+  if(m_isLockedXRange)
+    mp_vertRuleSlider->updatePosLabelXaxisValue();
 
   if(m_isLockedYMarker)
     {
@@ -1227,14 +1356,14 @@ BasePlotWnd::plotWidgetGotFocus(BasePlotCompositeWidget *composite_widget_p)
 
       if(composite_widget_p == iter_composite_widget_p)
         {
-          iter_composite_widget_p->redrawBackground(true);
+          iter_composite_widget_p->redrawBackground(true /*has_focus*/);
 
           // qDebug() << "Asking focused background redraw for plot widget:"
           //<< iter_composite_widget_p;
         }
       else
         {
-          iter_composite_widget_p->redrawBackground(false);
+          iter_composite_widget_p->redrawBackground(false /*has_focus*/);
 
           // qDebug() << "Asking unfocused background redraw for plot widget:"
           //<< iter_composite_widget_p;
@@ -1403,10 +1532,10 @@ BasePlotWnd::getAnalysisFilePtr()
   return mp_programWindow->getAnalysisFilePtr();
 }
 
-AnalysisPreferences *
-BasePlotWnd::getAnalysisPreferences()
+DiscoveriesPreferences *
+BasePlotWnd::getDiscoveriesPreferences()
 {
-  return mp_programWindow->getAnalysisPreferences();
+  return mp_programWindow->getDiscoveriesPreferences();
 }
 
 void
@@ -1541,7 +1670,7 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   //                                                *qualified_mass_spectra_sp,
   //                                                pappso::Enums::DataKind::rt);
 
-  qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
+  // qDebug() << "Added RT mass spectra:" << added_rt_mass_spectra;
 
   // Now see if we can remove some mass spectra on the basis of DT values.
 
@@ -1554,19 +1683,21 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
   // the mass spectral acquisitions involved ion mobility.
   if(integration)
     {
-      qDebug() << "Detected DT integration, removing mass spectra outside DT "
-                  "range:"
-               << range_pair.first << "-" << range_pair.second;
+      // qDebug() << "Detected DT integration, removing mass spectra outside DT
+      // "
+      //             "range:"
+      //          << range_pair.first << "-" << range_pair.second;
 
       std::size_t removed_mass_spectra;
 
       // Perform this lengthy computation in another thread.
-      QPromise<int> promise;
-      QFuture<int> future = promise.future();
+      QPromise<int> new_promise;
+      QFuture<int> new_future = new_promise.future();
 
-      QScopedPointer<QThread> thread(QThread::create(
-        [&](QPromise<int> promise) {
-          promise.start(); // notifies QFuture that the computation is started
+      QScopedPointer<QThread> new_thread(QThread::create(
+        [&](QPromise<int> new_promise) {
+          new_promise
+            .start(); // notifies QFuture that the computation is started
 
           removed_mass_spectra =
             ms_run_data_set_csp->getMsRunDataSetTreeCstSPtr()
@@ -1577,14 +1708,16 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
                 pappso::Enums::DataKind::dt);
 
 
-          promise.addResult(removed_mass_spectra);
-          promise.finish(); // notifies QFuture that the computation is finished
+          new_promise.addResult(removed_mass_spectra);
+          new_promise
+            .finish(); // notifies QFuture that the computation is finished
         },
-        std::move(promise)));
+        std::move(new_promise)));
 
-      thread->start();
-      future.waitForFinished(); // blocks until QPromise::finish is called
-      removed_mass_spectra = future.result(); // returns removed_mass_spectra
+      new_thread->start();
+      new_future.waitForFinished(); // blocks until QPromise::finish is called
+      removed_mass_spectra =
+        new_future.result(); // returns removed_mass_spectra
 
       // Original version in the main thread
       // removed_mass_spectra =
@@ -1595,14 +1728,14 @@ BasePlotWnd::fillInQualifiedMassSpectraVector(
       //                            *qualified_mass_spectra_sp,
       //                            pappso::Enums::DataKind::dt);
 
-      qDebug() << "Removed DT mass spectra:" << removed_mass_spectra;
+      // qDebug() << "Removed DT mass spectra:" << removed_mass_spectra;
     }
 
   // At this point we need to really check which of the remaining spectra are
   // inside of the selection polygon.
 
-  qDebug() << "Finally returning" << qualified_mass_spectra_sp->size()
-           << "spectra.";
+  // qDebug() << "Finally returning" << qualified_mass_spectra_sp->size()
+  //          << "spectra.";
 
   return qualified_mass_spectra_sp->size();
 }
