@@ -44,13 +44,13 @@
 #include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 
 /////////////////////// Local includes
-#include "BasePlotCompositeWidget.hpp"
-#include "../nongui/MassDataIntegrator.hpp"
-#include "SaveToGraphicsFileDlg.hpp"
-#include "../nongui/AnalysisPreferences.hpp"
+#include "../nongui/DiscoveriesPreferences.hpp"
 #include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToTicInt.hpp"
+#include "BasePlotCompositeWidget.hpp"
+#include "MsFragmentationSpec.hpp"
+#include "VerticalRuleSlider.hpp"
 #include "PlotAreaOverlay.hpp"
-
+#include "QualifiedMassSpectrumVectorMassDataIntegrator.hpp"
 
 namespace Ui
 {
@@ -67,7 +67,7 @@ class MsRunDataSet;
 class ProgramWindow;
 class DataPlottableNode;
 
-class BasePlotWnd : public QMainWindow
+class BasePlotWnd: public QMainWindow
 {
   Q_OBJECT
 
@@ -101,7 +101,7 @@ class BasePlotWnd : public QMainWindow
 
   virtual void show();
 
-  void verticalRulerSliderValueChanged(int value);
+  void verticalRuleSliderValueChanged(int x_position);
 
   void integrateToTicIntensity(
     QCPAbstractPlottable *parent_plottable_p,
@@ -135,8 +135,8 @@ class BasePlotWnd : public QMainWindow
   void savePinnedPlotsToGraphicsFile();
 
   void setMzIntegrationParamsForAllPlotWidgets();
-  void
-  mzIntegrationParamsChanged(pappso::MzIntegrationParams &mz_integration_params);
+  void mzIntegrationParamsChanged(
+    pappso::MzIntegrationParams &mz_integration_params);
 
   pappso::MzIntegrationParams::InitializationResult getSavedMzIntegrationParams(
     pappso::MzIntegrationParams &mz_integration_params);
@@ -164,7 +164,7 @@ class BasePlotWnd : public QMainWindow
   ProgramWindow *mp_programWindow = nullptr;
 
   QFile *getAnalysisFilePtr();
-  AnalysisPreferences *getAnalysisPreferences();
+  DiscoveriesPreferences *getDiscoveriesPreferences();
 
   /****************** BEGIN ******************/
   /****************** The button tool bar ******************/
@@ -173,7 +173,7 @@ class BasePlotWnd : public QMainWindow
 
   QMenu *mp_mainMenu                 = nullptr;
   QMenu *mp_plotWidgetManagementMenu = nullptr;
-  QPushButton *mp_mainMenuPushButton = nullptr;
+  QToolButton *mp_mainMenuToolButton = nullptr;
 
   QAction *mp_beforePlotWidgetManagementSeparatorAction = nullptr;
 
@@ -211,8 +211,8 @@ class BasePlotWnd : public QMainWindow
 
   QSplitter *mp_splitter;
 
-  QSlider *mp_vertRuleSlider           = nullptr;
-  PlotAreaOverlay *mpa_plotAreaOverlay = nullptr;
+  VerticalRuleSlider *mp_vertRuleSlider = nullptr;
+  PlotAreaOverlay *mpa_plotAreaOverlay  = nullptr;
 
   QString m_title;
   QString m_settingsTitle;
