@@ -46,13 +46,21 @@
 
 #include <pappsomspp/core/processing/filters/savgolfilter.h>
 #include <pappsomspp/core/processing/filters/filterlowintensitysignalremoval.h>
+#include <pappsomspp/core/processing/filters/filterpass.h>
+
+
+/////////////////////// libXpertMass includes
+
+
+/////////////////////// libXpertMassGui includes
+#include <MsXpS/libXpertMassGui/LabelledNumberLineEditAction.hpp>
+
 
 /////////////////////// Local includes
 #include "BaseTracePlotCompositeWidget.hpp"
 #include "BaseTracePlotWnd.hpp"
 #include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 #include "ProgramWindow.hpp"
-#include "LabelledNumberLineEditAction.hpp"
 #include "Application.hpp"
 #include "ui_BasePlotCompositeWidget.h"
 
@@ -69,14 +77,10 @@ BaseTracePlotCompositeWidget::BaseTracePlotCompositeWidget(
   // We need to add some menus / menu items.
 
   createMainMenu();
+  configureOutIntegrationCheckButtons();
 
   createLabellingSessionMenu();
 
-  connect(m_ui->labellingSessionMenuPushButton,
-          &QPushButton::clicked,
-          this,
-          &BaseTracePlotCompositeWidget::labellingSessionMenuPushButtonClicked);
-
   // The trace combined plot widget receives traces from integrations. It is
   // possible to perform various actions with the traces inside a composite plot
   // widget and the selection of the action to perform is done using check
@@ -137,7 +141,7 @@ BaseTracePlotCompositeWidget::BaseTracePlotCompositeWidget(
                   NewTraceHandlingMethod::MINUS_COMBINE;
               }
             else
-              qFatal("Programming error.");
+              qFatal() << "Programming error.";
           });
 }
 
@@ -149,11 +153,14 @@ BaseTracePlotCompositeWidget::~BaseTracePlotCompositeWidget()
 void
 BaseTracePlotCompositeWidget::createMainMenu()
 {
-  BasePlotCompositeWidget::createMainMenu();
+  qDebug() << "Completing the main menu:" << mp_mainMenu;
 
-  // Now append new Trace-specific menus
+  // Complete the base class menu with the trace specific menu item.
 
-  // Complete the export/save menu item list with the trace specific menu item.
+  QIcon the_icon = m_ui->mainMenuPushButton->icon();
+  QSize size = m_ui->mainMenuPushButton->iconSize(); // typically what you want
+  QPixmap pixmap = the_icon.pixmap(size);
+  pixmap.save("/tmp/basetraceploticon.png");
 
   QAction *save_peak_list_to_clipboard_p =
     new QAction("Save peak list to clipboard", this);
@@ -201,7 +208,6 @@ BaseTracePlotCompositeWidget::createMainMenu()
 
   mp_mainMenu->addSeparator();
 
-
   QMenu *filters_menu_p = mp_mainMenu->addMenu("&Filters");
 
   // We want to provide the user with the ability to define a noise sample. They
@@ -265,79 +271,190 @@ BaseTracePlotCompositeWidget::createMainMenu()
   // Now add a new menu for the Low intensity signal removel filter.
 
   QWidgetAction *widget_action_p =
-    new LabelledNumberLineEditAction("Low intensity threshold removal",
-                                     10000,
-                                     0,
-                                     10e100,
-                                     2,
-                                     true,
-                                     dynamic_cast<QObject *>(this));
+    new libXpertMassGui::LabelledNumberLineEditAction(
+      "Low intensity threshold removal",
+      10000,
+      0,
+      10e100,
+      2,
+      true,
+      dynamic_cast<QObject *>(this));
   widget_action_p->setStatusTip("Remove signal below the provided threshold");
+  connect(widget_action_p, &QAction::triggered, [this, widget_action_p]() {
+    runLowIntensityThresholdRemovalFilter(widget_action_p);
+  });
   filters_menu_p->addAction(widget_action_p);
 
-  connect(widget_action_p, &QAction::triggered, [this, widget_action_p]() {
-    bool ok = false;
 
-    double threshold =
-      static_cast<LabelledNumberLineEditAction *>(widget_action_p)
-        ->getValue()
-        .toDouble(&ok);
-
-    if(!ok)
-      qFatal("Failed to convert QVariant to double");
-
-    // qDebug() << "triggered with threshold value:" << threshold;
-
-    // Get the source plottable that might be of interest to the user.
-    QCPAbstractPlottable *source_plottable_p =
-      plottableToBeUsedAsIntegrationSource();
-
-    // qDebug() << "The source plottable:" << source_plottable_p;
-
-    if(source_plottable_p == nullptr)
-      {
-        QMessageBox::information(
+  QAction *filter_high_pass_0_action_p = new QAction(
+    "Remove less than 0 intensity data points", dynamic_cast<QObject *>(this));
+  filter_high_pass_0_action_p->setStatusTip(
+    "Remove less than 0 intensity data points");
+  connect(filter_high_pass_0_action_p,
+          &QAction::triggered,
           this,
-          "Please select *one* trace",
-          "In order to set the Savitzky-Golay filter parameters, the source "
-          "graph needs to be selected.",
-          QMessageBox::StandardButton::Ok,
-          QMessageBox::StandardButton::NoButton);
+          &BaseTracePlotCompositeWidget::removeZeroIntensityDataPointsFilter);
+  filters_menu_p->addAction(filter_high_pass_0_action_p);
+}
 
-        return;
-      }
+void
+BaseTracePlotCompositeWidget::configureOutIntegrationCheckButtons()
+{
+  // The right hand side strip of buttons, which act as check buttons
+  // configure the destination of the integrations.
 
-    std::size_t point_count;
-    double mean    = 0;
-    double std_dev = 0;
+  ProgramWindow *program_window_p =
+    static_cast<Application *>(qApp)->getProgramWindow();
+  QString action_label;
+  libXpertMassGui::ActionId action_id;
+  QKeySequence key_sequence;
+  QAction *action_p = nullptr;
 
-    // If there is no noise sample trace, then provide 0-valued variables. The
-    // user will see nothing.
-    bool res = static_cast<BaseTracePlotWnd *>(mp_parentWnd)
-                 ->getNoiseSampleStats(point_count, mean, std_dev);
+  action_label = "Duplicate trace";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+D, T"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->duplicateTracePushButton->addAction(action_p);
+  m_ui->duplicateTracePushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    // qDebug() << "Trigger" << static_cast<QAction
+    // *>(QObject::sender())->text(); This action is set to may different
+    // buttons all over the windows, we do not want that the action be triggered
+    // for any other window than this one!
+    if(!isActiveWindow())
+      return;
+    // This one is a true button, not a button that acts like a check button!
+    m_ui->duplicateTracePushButton->click();
+  });
 
-    if(!res)
-      {
-        mean    = 0;
-        std_dev = 0;
-      }
+  action_label = "Integrate to an ion mobility spectrum";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, D"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToDtPushButton->addAction(action_p);
+  m_ui->integrateToDtPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    // qDebug() << "Trigger" << static_cast<QAction
+    // *>(QObject::sender())->text(); This action is set to may different
+    // buttons all over the windows, we do not want that the action be triggered
+    // for any other window than this one!
+    if(!isActiveWindow())
+      return;
+    // m_ui->integrateToDtPushButton->click();
+    m_ui->integrateToDtPushButton->setChecked(true);
+  });
 
-    // Create the new filter.
+  action_label = "Integrate to a mass spectrum";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, M"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToMzPushButton->addAction(action_p);
+  m_ui->integrateToMzPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    // qDebug() << "Trigger" << static_cast<QAction
+    // *>(QObject::sender())->text(); This action is set to may different
+    // buttons all over the windows, we do not want that the action be triggered
+    // for any other window than this one!
+    if(!isActiveWindow())
+      return;
+    // m_ui->integrateToMzPushButton->click();
+    m_ui->integrateToMzPushButton->setChecked(true);
+  });
 
-    pappso::FilterLowIntensitySignalRemovalCstSPtr new_filter_csp =
-      std::make_shared<pappso::FilterLowIntensitySignalRemoval>(
-        pappso::FilterLowIntensitySignalRemoval(mean, std_dev, threshold));
+  action_label = "Integrate to a TIC/XIC chromatogram";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, R"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToRtPushButton->addAction(action_p);
+  m_ui->integrateToRtPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    // qDebug() << "Trigger" << static_cast<QAction
+    // *>(QObject::sender())->text(); This action is set to may different
+    // buttons all over the windows, we do not want that the action be triggered
+    // for any other window than this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToRtPushButton->setChecked(true);
+  });
 
-    // Get the processing flow for that specific graph.
-    ProcessingFlow *processing_flow_p =
-      getProcessingFlowPtrForPlottable(source_plottable_p);
+  action_label = "Integrate to a TIC intensity value";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, I"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToIntPushButton->addAction(action_p);
+  m_ui->integrateToIntPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    // qDebug() << "Trigger" << static_cast<QAction
+    // *>(QObject::sender())->text(); This action is set to may different
+    // buttons all over the windows, we do not want that the action be triggered
+    // for any other window than this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToIntPushButton->setChecked(true);
+  });
 
-    // Add the filter to the processing flow for the proper plottable.
-    processing_flow_p->addFilter(new_filter_csp);
+  action_label = "Integrate to an ion mobility / mass spectrum color map";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, Ctrl+D"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToDtMzPushButton->addAction(action_p);
+  m_ui->integrateToDtMzPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    // qDebug() << "Trigger" << static_cast<QAction
+    // *>(QObject::sender())->text(); This action is set to may different
+    // buttons all over the windows, we do not want that the action be triggered
+    // for any other window than this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToDtMzPushButton->setChecked(true);
+  });
 
-    // Finally, since the action was triggered, run the filter.
+  action_label = "Integrate to an ion mobility / TIC chromatogram color map";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, Ctrl+R"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToDtRtPushButton->addAction(action_p);
+  m_ui->integrateToDtRtPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    // qDebug() << "Trigger" << static_cast<QAction
+    // *>(QObject::sender())->text(); This action is set to may different
+    // buttons all over the windows, we do not want that the action be triggered
+    // for any other window than this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToDtRtPushButton->setChecked(true);
+  });
 
-    runFilter(new_filter_csp->name());
+  action_label = "Integrate to a mass spectrum / TIC chromatogram color map";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, Ctrl+M"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToMzRtPushButton->addAction(action_p);
+  m_ui->integrateToMzRtPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    // qDebug() << "Trigger" << static_cast<QAction
+    // *>(QObject::sender())->text(); This action is set to may different
+    // buttons all over the windows, we do not want that the action be triggered
+    // for any other window than this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToMzRtPushButton->setChecked(true);
   });
 }
 
@@ -393,7 +510,7 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
   else if(m_newTraceHandlingMethod == NewTraceHandlingMethod::MINUS_COMBINE ||
           m_newTraceHandlingMethod == NewTraceHandlingMethod::PLUS_COMBINE)
     {
-      // qDebug();
+      // qDebug() << "The added trace will be combined.";
 
       // Combination is requested. There are some situations:
 
@@ -410,6 +527,9 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
         must_create_new_graph = true;
       else
         {
+          // qDebug() << "There is indeed at least one graph that will be
+          // handled.";
+
           // // The integration that is performed here is granted to be in
           // integration to either TIC or DT because for MZ there is an
           // overriden function in the MassSpecTracePlotCompositeWidget class.
@@ -443,37 +563,9 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
               // Now replace the graph's data. Note that the data are
               // inherently sorted (true below).
 
-              // Old version that was deprecated in 5.14.2
-              //
-              // iter_graph_p->setData(
-              // QVector<double>::fromStdVector(map_trace.firstToVector()),
-              // QVector<double>::fromStdVector(map_trace.secondToVector()),
-              // true);
-
               QVector<double> key_vector;
               QVector<double> value_vector;
 
-              // Apparently, as of 20210928, that bug is fixed.
-              // #pragma GCC warning "Filippo Rusconi: Please check if the bug
-              // was fixed in Qt"
-
-              // Now replace the graph's data. Note that the data are
-              // inherently sorted (true below).
-
-              // The begin() -- end() ranges constructor did not work as of
-              // Qt 5.14.2 this day: 20200721 -- and still does not work
-              // 20211018.
-
-
-              // key_vector =
-              // QVector(map_trace.xValues().begin(),
-              // map_trace.xValues().end());
-              // value_vector =
-              // QVector(map_trace.yValues().begin(),
-              // map_trace.yValues().end());
-
-              // This is the workaround fix.
-
               for(auto &value : map_trace.xValues())
                 key_vector.push_back(value);
 
@@ -493,6 +585,8 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
   // End of if(m_ui->keepTraceCombineNewPushButton->isChecked())
   else if(m_newTraceHandlingMethod == NewTraceHandlingMethod::REPLACE)
     {
+      // qDebug() << "The traces currently selected will be replaced.";
+
       // Start by erasing all the traces that are selected.
 
       for(int iter = 0; iter < dest_graph_list.size(); ++iter)
@@ -515,7 +609,7 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
 
   if(must_create_new_graph)
     {
-      // qDebug();
+      // qDebug() << "We will be creating a new graph.";
 
       // At this point we know we need to create a new trace.
 
@@ -531,7 +625,7 @@ BaseTracePlotCompositeWidget::addTrace(const pappso::Trace &trace,
 
       // We need to allocate a new ProcessingFlow instance with the graph
       // as its parent.
-      ProcessingFlow *processing_flow_p     = processing_flow.clone(graph_p);
+      ProcessingFlow *processing_flow_p = processing_flow.clone(graph_p);
 
       // Map the graph_p to the processing flow that we got to document
       // how the trace was obtained in the first place.
@@ -752,7 +846,7 @@ BaseTracePlotCompositeWidget::savitzkyGolayFilterParamsChanged(
 void
 BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
 {
-  // qDebug();
+  qDebug();
 
   // We want to run a filter by its name. The filter is going to be applied to
   // the trace that is either unique in the widget or selected (if there are
@@ -800,27 +894,46 @@ BaseTracePlotCompositeWidget::runFilter(const QString &filter_name)
           showSavitzkyGolayFilterParamsDlg();
           return;
         }
-    }
 
-  // qDebug() << "Could load parameters:" << parameters;
-
-  // We could find the parameters in the settings. Just use them
-  // to craft a filter.
-
-  pappso::FilterNameInterfaceCstSPtr filter_csp =
-    std::make_shared<const pappso::FilterSavitzkyGolay>(
-      QString("%1|%2").arg(filter_name).arg(filter_parameters));
-
-  if(filter_csp == nullptr)
-    {
-      // qDebug() << "Could not create filter using these parameters.";
-
-      showSavitzkyGolayFilterParamsDlg();
       return;
     }
 
-  // qDebug() << "Running filter by name:" << filter_name
-  //          << "with string representation : " << filter_csp->toString();
+  qDebug() << "Could load parameters:" << filter_parameters;
+
+  // We could find the parameters in the settings. Just use them
+  // to craft a filter.
+  pappso::FilterNameInterfaceCstSPtr filter_csp = nullptr;
+
+  if(filter_name == "Savitzky-Golay")
+    {
+      filter_csp = std::make_shared<const pappso::FilterSavitzkyGolay>(
+        QString("%1|%2").arg(filter_name, filter_parameters));
+
+      if(filter_csp == nullptr)
+        {
+          // qDebug() << "Could not create filter using these parameters.";
+
+          showSavitzkyGolayFilterParamsDlg();
+          return;
+        }
+    }
+  else if(filter_name == "FilterLowIntensitySignalRemoval")
+    {
+      filter_csp =
+        std::make_shared<const pappso::FilterLowIntensitySignalRemoval>(
+          QString("%1|%2").arg(filter_name, filter_parameters));
+
+      if(filter_csp == nullptr)
+        {
+          qDebug() << "Could not create filter using these parameters:"
+                   << filter_parameters;
+
+          return;
+        }
+    }
+
+  qDebug() << "Running filter by name:" << filter_name
+           << "with string representation : " << filter_csp->toString();
 
   pappso::Trace data_trace =
     static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
@@ -871,6 +984,156 @@ BaseTracePlotCompositeWidget::runSavitzkyGolayFilter()
   runFilter("Savitzky-Golay");
 }
 
+void
+BaseTracePlotCompositeWidget::runLowIntensityThresholdRemovalFilter(
+  QWidgetAction *widget_action_p)
+{
+  qDebug();
+
+  bool ok = false;
+
+  double threshold =
+    static_cast<libXpertMassGui::LabelledNumberLineEditAction *>(
+      widget_action_p)
+      ->getValue()
+      .toDouble(&ok);
+
+  if(!ok)
+    qFatal() << "Failed to convert QVariant to double";
+
+  qDebug() << "Triggered with threshold value:" << threshold;
+
+  // Get the source plottable that might be of interest to the user.
+  QCPAbstractPlottable *source_plottable_p =
+    plottableToBeUsedAsIntegrationSource();
+
+  // qDebug() << "The source plottable:" << source_plottable_p;
+
+  if(source_plottable_p == nullptr)
+    {
+      QMessageBox::information(this,
+                               "Please select *one* trace",
+                               "In order to run the low intensity threshold "
+                               "removal filter, the source "
+                               "graph needs to be selected.",
+                               QMessageBox::StandardButton::Ok,
+                               QMessageBox::StandardButton::NoButton);
+
+      return;
+    }
+
+  std::size_t point_count;
+  double mean    = 0;
+  double std_dev = 0;
+
+  // If there is no noise sample trace, then provide 0-valued variables. The
+  // user will see nothing.
+  bool res = static_cast<BaseTracePlotWnd *>(mp_parentWnd)
+               ->getNoiseSampleStats(point_count, mean, std_dev);
+
+  if(!res)
+    {
+      mean    = 0;
+      std_dev = 0;
+    }
+
+  // Create the new filter.
+
+  qDebug() << "Now allocating FilterLowIntensitySignalRemoval";
+
+  pappso::FilterLowIntensitySignalRemovalCstSPtr new_filter_csp =
+    std::make_shared<pappso::FilterLowIntensitySignalRemoval>(
+      pappso::FilterLowIntensitySignalRemoval(mean, std_dev, threshold));
+
+  qDebug() << "Allocated:" << new_filter_csp->toString();
+
+  // Get the processing flow for that specific graph.
+  ProcessingFlow *processing_flow_p =
+    getProcessingFlowPtrForPlottable(source_plottable_p);
+
+  // Add the filter to the processing flow for the proper plottable.
+  processing_flow_p->addFilter(new_filter_csp);
+
+  // Store the new params to the Settings. These params will be read
+  // when the filter is to be applied.
+  QString parameters = new_filter_csp->toString().split('|').last();
+
+  writeFilterParamsToSettings("FilterLowIntensitySignalRemoval", parameters);
+
+  // Finally, since the action was triggered, run the filter.
+
+  runFilter(new_filter_csp->name());
+}
+
+void
+BaseTracePlotCompositeWidget::removeZeroIntensityDataPointsFilter()
+{
+  qDebug();
+  // We want to remove all the points that are 0-intensity, that is,
+  // that have y=0.
+
+  // Get the source plottable that might be of interest to the user.
+  QCPAbstractPlottable *source_plottable_p =
+    plottableToBeUsedAsIntegrationSource();
+
+  // qDebug() << "The source plottable:" << source_plottable_p;
+
+  if(source_plottable_p == nullptr)
+    {
+      QMessageBox::information(this,
+                               "Please select *one* trace",
+                               "In order to run the low intensity threshold "
+                               "removal filter, the source "
+                               "graph needs to be selected.",
+                               QMessageBox::StandardButton::Ok,
+                               QMessageBox::StandardButton::NoButton);
+
+      return;
+    }
+
+  pappso::Trace data_trace =
+    static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
+      ->toTrace(static_cast<QCPGraph *>(source_plottable_p));
+
+  pappso::FilterHighPass filter_high_pass(0);
+
+  data_trace = filter_high_pass.filter(data_trace);
+
+  // At this point, add the trace ! But only if it has points in it.
+
+  if(!data_trace.size())
+    {
+      // qDebug() << "The trace produced by the filter is empty.";
+
+      m_ui->statusLineEdit->setText(
+        QString("The filter %1 produced an empty trace. Plotting nothing.")
+          .arg("High pass (0)"));
+
+      return;
+    }
+
+  // Make a copy of the ProcessingFlow, without parentship, because we'll
+  // pass that instance by reference to downstream code that will allocate
+  // an instance with proper parentship. Just delete the temporary pointer
+  // after that call.
+  ProcessingFlow *temp_processing_flow_p =
+    getCstProcessingFlowPtrForPlottable(source_plottable_p)->clone(nullptr);
+
+  // temp_processing_flow_p->addFilter(filter_csp);
+
+  MsRunDataSetCstSPtr ms_run_data_set_csp =
+    getMsRunDataSetCstSPtrForPlottable(source_plottable_p);
+
+  addTrace(data_trace,
+           source_plottable_p,
+           ms_run_data_set_csp,
+           ms_run_data_set_csp->getMsRunId()->getSampleName(),
+           *temp_processing_flow_p,
+           source_plottable_p->pen().color());
+
+  delete temp_processing_flow_p;
+}
+
 void
 BaseTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
@@ -970,7 +1233,8 @@ BaseTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(
   // keys pressed, and if m_isPeakApexPinPointing is true, then the user is
   // capturing the x axis (or y axis) value in the console.
 
-  if (m_isPinPointingPeakApex) {
+  if(m_isPinPointingPeakApex)
+    {
       // qDebug() << "Peak apex pin pointing.";
 
       double x_value = context.m_lastCursorHoveredPoint.x();
@@ -978,20 +1242,27 @@ BaseTracePlotCompositeWidget::plotWidgetMouseReleaseEvent(
 
       QString text;
 
-      if (context.m_pressedKeyCode == Qt::Key_X) {
+      if(context.m_pressedKeyCode == Qt::Key_X)
+        {
           text = QString("%1").arg(x_value, 0, 'f', 4);
-      } else if (context.m_pressedKeyCode == Qt::Key_Y) {
+        }
+      else if(context.m_pressedKeyCode == Qt::Key_Y)
+        {
           text = QString("%1").arg(y_value, 0, 'f', 4);
-      } else if (context.m_pressedKeyCode == Qt::Key_C) {
+        }
+      else if(context.m_pressedKeyCode == Qt::Key_C)
+        {
           // (X,Y)
-          text = QString("(%1,%2)").arg(x_value, 0, 'f', 4).arg(y_value, 0, 'f', 4);
-      }
+          text =
+            QString("(%1,%2)").arg(x_value, 0, 'f', 4).arg(y_value, 0, 'f', 4);
+        }
 
-      if (!text.isEmpty()) {
+      if(!text.isEmpty())
+        {
           mp_parentWnd->getProgramWindow()->logTextToConsole(text);
           labelPeak(text, QPointF(x_value, y_value));
-      }
-  }
+        }
+    }
 }
 
 void
@@ -1235,220 +1506,238 @@ BaseTracePlotCompositeWidget::pinPointPeakApexCheckBoxStateChanged(
     }
 }
 
-void BaseTracePlotCompositeWidget::createLabellingSessionMenu()
+void
+BaseTracePlotCompositeWidget::createLabellingSessionMenu()
 {
-    // qDebug() << "ENTER";
+  // qDebug() << "ENTER";
 
-    if (mp_labelSessionMenu != nullptr)
-        delete mp_labelSessionMenu;
+  if(mp_labelSessionMenu != nullptr)
+    return;
 
-    // Create the menu.
-    mp_labelSessionMenu = new QMenu(this);
+  // Create the menu.
+  mp_labelSessionMenu = new QMenu(this);
 
-    // Create the menu push button.
-    const QIcon menu_icon = QIcon(":/images/svg/label-session-menu-button.svg");
-    mp_labelSessionMenu->setIcon(menu_icon);
-    mp_labelSessionMenu->setToolTip("Labelling session menu (Ctrl+L, S)");
+  // Create the menu push button.
+  const QIcon menu_icon = QIcon(":/images/svg/label-session-menu-button.svg");
+  mp_labelSessionMenu->setIcon(menu_icon);
+  mp_labelSessionMenu->setToolTip("Labelling session menu (Ctrl+L, S)");
 
-    // Finally set the push button to be the menu...
-    m_ui->labellingSessionMenuPushButton->setMenu(mp_labelSessionMenu);
+  // Finally set the push button to be the menu...
+  m_ui->labellingSessionMenuPushButton->setMenu(mp_labelSessionMenu);
 
-    QAction *pick_peaks_only_on_visible_maxima_p = mp_labelSessionMenu->addAction(
-        "Pick peaks only on visible maxima");
+  QAction *pick_peaks_only_on_visible_maxima_p =
+    mp_labelSessionMenu->addAction("Pick peaks only on visible maxima");
 
-    connect(pick_peaks_only_on_visible_maxima_p,
-            &QAction::triggered,
-            this,
-            &BaseTracePlotCompositeWidget::pickPeaksOnlyOnVisibleMaxima);
+  connect(pick_peaks_only_on_visible_maxima_p,
+          &QAction::triggered,
+          this,
+          &BaseTracePlotCompositeWidget::pickPeaksOnlyOnVisibleMaxima);
 
-    mp_labelSessionMenu->addSeparator();
+  mp_labelSessionMenu->addSeparator();
 
-    QAction *start_stop_labelling_session_p = mp_labelSessionMenu->addAction(
-        "Start/Stop labelling session");
+  QAction *start_stop_labelling_session_p =
+    mp_labelSessionMenu->addAction("Start/Stop labelling session");
 
-    start_stop_labelling_session_p->setCheckable(true);
-    start_stop_labelling_session_p->setShortcut(QKeySequence("Ctrl+L, S"));
+  start_stop_labelling_session_p->setCheckable(true);
+  start_stop_labelling_session_p->setShortcut(QKeySequence("Ctrl+L, S"));
 
-    connect(start_stop_labelling_session_p, &QAction::toggled, [this](bool checked) {
-        m_isPinPointingPeakApex = checked;
-        // qDebug() << "Labelling session open?" << checked;
+  connect(
+    start_stop_labelling_session_p, &QAction::toggled, [this](bool checked) {
+      m_isPinPointingPeakApex = checked;
+      // qDebug() << "Labelling session open?" << checked;
     });
 
-    mp_labelSessionMenu->addSeparator();
+  mp_labelSessionMenu->addSeparator();
 
-    QAction *toggle_all_labels_visibility_action_p = mp_labelSessionMenu->addAction(
-        "Toggle all peak labels visibility");
+  QAction *toggle_all_labels_visibility_action_p =
+    mp_labelSessionMenu->addAction("Toggle all peak labels visibility");
 
-    toggle_all_labels_visibility_action_p->setShortcut(QKeySequence("Ctrl+T, V"));
+  toggle_all_labels_visibility_action_p->setShortcut(QKeySequence("Ctrl+T, V"));
 
-    connect(toggle_all_labels_visibility_action_p,
-            &QAction::triggered,
-            this,
-            &BaseTracePlotCompositeWidget::toggleAllPeakLabelsVisibility);
+  connect(toggle_all_labels_visibility_action_p,
+          &QAction::triggered,
+          this,
+          &BaseTracePlotCompositeWidget::toggleAllPeakLabelsVisibility);
 
-    mp_labelSessionMenu->addSeparator();
+  mp_labelSessionMenu->addSeparator();
 
-    QAction *remove_first_label_action_p = mp_labelSessionMenu->addAction(
-        "Remove first peak label");
+  QAction *remove_first_label_action_p =
+    mp_labelSessionMenu->addAction("Remove first peak label");
 
-    remove_first_label_action_p->setShortcut(QKeySequence("Ctrl+R, F"));
+  remove_first_label_action_p->setShortcut(QKeySequence("Ctrl+R, F"));
 
-    connect(remove_first_label_action_p,
-            &QAction::triggered,
-            this,
-            &BaseTracePlotCompositeWidget::removeFirstPeakLabel);
+  connect(remove_first_label_action_p,
+          &QAction::triggered,
+          this,
+          &BaseTracePlotCompositeWidget::removeFirstPeakLabel);
 
-    QAction *remove_last_label_action_p = mp_labelSessionMenu->addAction("Remove last peak label");
+  QAction *remove_last_label_action_p =
+    mp_labelSessionMenu->addAction("Remove last peak label");
 
-    remove_last_label_action_p->setShortcut(QKeySequence("Ctrl+R, L"));
+  remove_last_label_action_p->setShortcut(QKeySequence("Ctrl+R, L"));
 
-    connect(remove_last_label_action_p,
-            &QAction::triggered,
-            this,
-            &BaseTracePlotCompositeWidget::removeLastPeakLabel);
+  connect(remove_last_label_action_p,
+          &QAction::triggered,
+          this,
+          &BaseTracePlotCompositeWidget::removeLastPeakLabel);
 
-    mp_labelSessionMenu->addSeparator();
+  mp_labelSessionMenu->addSeparator();
 
-    QAction *remove_all_labels_action_p = mp_labelSessionMenu->addAction("Remove all peak labels");
+  QAction *remove_all_labels_action_p =
+    mp_labelSessionMenu->addAction("Remove all peak labels");
 
-    remove_all_labels_action_p->setShortcut(QKeySequence("Ctrl+R, A"));
+  remove_all_labels_action_p->setShortcut(QKeySequence("Ctrl+R, A"));
 
-    connect(remove_all_labels_action_p,
-            &QAction::triggered,
-            this,
-            &BaseTracePlotCompositeWidget::removeAllPeakLabels);
+  connect(remove_all_labels_action_p,
+          &QAction::triggered,
+          this,
+          &BaseTracePlotCompositeWidget::removeAllPeakLabels);
 
-    mp_labelSessionMenu->addSeparator();
+  mp_labelSessionMenu->addSeparator();
 
-    QAction *export_labels_to_clipboard_action_p = mp_labelSessionMenu->addAction(
-        "Export peak labels to clipboard");
+  QAction *export_labels_to_clipboard_action_p =
+    mp_labelSessionMenu->addAction("Export peak labels to clipboard");
 
-    export_labels_to_clipboard_action_p->setShortcut(QKeySequence("Ctrl+E, L"));
+  export_labels_to_clipboard_action_p->setShortcut(QKeySequence("Ctrl+E, L"));
 
-    connect(export_labels_to_clipboard_action_p,
-            &QAction::triggered,
-            this,
-            &BaseTracePlotCompositeWidget::exportPeakLabelsToClipboard);
+  connect(export_labels_to_clipboard_action_p,
+          &QAction::triggered,
+          this,
+          &BaseTracePlotCompositeWidget::exportPeakLabelsToClipboard);
 }
 
-void BaseTracePlotCompositeWidget::labellingSessionMenuPushButtonClicked()
+void
+BaseTracePlotCompositeWidget::labellingSessionMenuPushButtonClicked()
 {
-    createLabellingSessionMenu();
-    m_ui->mainMenuPushButton->showMenu();
+  createLabellingSessionMenu();
+  m_ui->mainMenuPushButton->showMenu();
 }
 
-void BaseTracePlotCompositeWidget::labelPeak(const QString &text, const QPointF &plot_point)
+void
+BaseTracePlotCompositeWidget::labelPeak(const QString &text,
+                                        const QPointF &plot_point)
 {
-    PeakLabelSPtr peak_label_sp = std::make_shared<PeakLabel>(mp_plotWidget, text, plot_point);
+  PeakLabelSPtr peak_label_sp =
+    std::make_shared<PeakLabel>(mp_plotWidget, text, plot_point);
 
-    m_peakLabels.push_back(peak_label_sp);
+  m_peakLabels.push_back(peak_label_sp);
 
-    mp_plotWidget->replot();
+  mp_plotWidget->replot();
 }
 
-void BaseTracePlotCompositeWidget::labelPeaks(const pappso::Trace &trace)
+void
+BaseTracePlotCompositeWidget::labelPeaks(const pappso::Trace &trace)
 {
-    QString text;
+  QString text;
 
-    for (const pappso::DataPoint &dp : trace) {
-        text = QString("(%1,%2)").arg(dp.x, 0, 'f', 4).arg(dp.y, 0, 'f', 4);
+  for(const pappso::DataPoint &dp : trace)
+    {
+      text = QString("(%1,%2)").arg(dp.x, 0, 'f', 4).arg(dp.y, 0, 'f', 4);
 
-        PeakLabelSPtr peak_label_sp = std::make_shared<PeakLabel>(mp_plotWidget,
-                                                                  text,
-                                                                  QPointF(dp.x, dp.y));
+      PeakLabelSPtr peak_label_sp =
+        std::make_shared<PeakLabel>(mp_plotWidget, text, QPointF(dp.x, dp.y));
 
-        m_peakLabels.push_back(peak_label_sp);
+      m_peakLabels.push_back(peak_label_sp);
     }
 
+  mp_plotWidget->replot();
+}
+
+void
+BaseTracePlotCompositeWidget::toggleAllPeakLabelsVisibility()
+{
+  // qDebug();
+
+  if(!m_peakLabels.size())
+    return;
+
+  for(PeakLabelSPtr peak_label_sp : m_peakLabels)
+    peak_label_sp->rp_qcpItemText->setVisible(
+      !peak_label_sp->rp_qcpItemText->visible());
+
+  mp_plotWidget->replot();
+}
+
+void
+BaseTracePlotCompositeWidget::removeFirstPeakLabel()
+{
+  // qDebug();
+
+  if(!m_peakLabels.size())
+    return;
+
+  PeakLabelSPtr peak_label_sp = *m_peakLabels.begin();
+
+  bool res = mp_plotWidget->removeItem(peak_label_sp->rp_qcpItemText);
+  if(!res)
+    qDebug() << "The item could not be removed.";
+  else
     mp_plotWidget->replot();
+
+  m_peakLabels.erase(m_peakLabels.begin());
 }
 
-void BaseTracePlotCompositeWidget::toggleAllPeakLabelsVisibility()
+void
+BaseTracePlotCompositeWidget::removeLastPeakLabel()
 {
-    // qDebug();
+  // qDebug();
 
-    if (!m_peakLabels.size())
-        return;
+  if(!m_peakLabels.size())
+    return;
 
-    for (PeakLabelSPtr peak_label_sp : m_peakLabels)
-        peak_label_sp->rp_qcpItemText->setVisible(!peak_label_sp->rp_qcpItemText->visible());
+  PeakLabelSPtr peak_label_sp = *std::prev(m_peakLabels.end());
 
+  bool res = mp_plotWidget->removeItem(peak_label_sp->rp_qcpItemText);
+  if(!res)
+    qCritical() << "The item could not be removed.";
+  else
     mp_plotWidget->replot();
+
+  m_peakLabels.erase(std::prev(m_peakLabels.end()));
 }
 
-void BaseTracePlotCompositeWidget::removeFirstPeakLabel()
+void
+BaseTracePlotCompositeWidget::removeAllPeakLabels()
 {
-    // qDebug();
+  // qDebug();
 
-    if (!m_peakLabels.size())
-        return;
+  if(!m_peakLabels.size())
+    return;
 
-    PeakLabelSPtr peak_label_sp = *m_peakLabels.begin();
+  std::vector<PeakLabelSPtr>::iterator the_iterator = m_peakLabels.begin();
 
-    bool res = mp_plotWidget->removeItem(peak_label_sp->rp_qcpItemText);
-    if (!res)
-        qDebug() << "The item could not be removed.";
-    else
-        mp_plotWidget->replot();
-
-    m_peakLabels.erase(m_peakLabels.begin());
-}
-
-void BaseTracePlotCompositeWidget::removeLastPeakLabel()
-{
-    // qDebug();
-
-    if (!m_peakLabels.size())
-        return;
-
-    PeakLabelSPtr peak_label_sp = *std::prev(m_peakLabels.end());
-
-    bool res = mp_plotWidget->removeItem(peak_label_sp->rp_qcpItemText);
-    if (!res)
+  while(the_iterator != m_peakLabels.end())
+    {
+      bool res = mp_plotWidget->removeItem((*the_iterator)->rp_qcpItemText);
+      if(!res)
         qCritical() << "The item could not be removed.";
-    else
+      else
         mp_plotWidget->replot();
 
-    m_peakLabels.erase(std::prev(m_peakLabels.end()));
-}
-
-void BaseTracePlotCompositeWidget::removeAllPeakLabels()
-{
-    // qDebug();
-
-    if (!m_peakLabels.size())
-        return;
-
-    std::vector<PeakLabelSPtr>::iterator the_iterator = m_peakLabels.begin();
-
-    while (the_iterator != m_peakLabels.end()) {
-        bool res = mp_plotWidget->removeItem((*the_iterator)->rp_qcpItemText);
-        if (!res)
-            qCritical() << "The item could not be removed.";
-        else
-            mp_plotWidget->replot();
-
-        the_iterator = m_peakLabels.erase(the_iterator);
+      the_iterator = m_peakLabels.erase(the_iterator);
     }
 }
 
-void BaseTracePlotCompositeWidget::exportPeakLabelsToClipboard()
+void
+BaseTracePlotCompositeWidget::exportPeakLabelsToClipboard()
 {
-    QString text;
+  QString text;
 
-    for (const PeakLabelSPtr &peak_label_sp : m_peakLabels)
-        text += QString("%1\n").arg(peak_label_sp->rp_qcpItemText->text());
+  for(const PeakLabelSPtr &peak_label_sp : m_peakLabels)
+    text += QString("%1\n").arg(peak_label_sp->rp_qcpItemText->text());
 
-    if (!text.isEmpty()) {
-        QClipboard *clipboard_p = QApplication::clipboard();
+  if(!text.isEmpty())
+    {
+      QClipboard *clipboard_p = QApplication::clipboard();
 
-        clipboard_p->setText(text, QClipboard::Clipboard);
+      clipboard_p->setText(text, QClipboard::Clipboard);
     }
 }
 
-pappso::Trace BaseTracePlotCompositeWidget::pickPeaksOnlyOnVisibleMaxima()
+pappso::Trace
+BaseTracePlotCompositeWidget::pickPeaksOnlyOnVisibleMaxima()
 {
-pappso::Trace  trace;
+  pappso::Trace trace;
   // First we get the source graph that might be of interest to the user.
 
   QCPAbstractPlottable *source_plottable_p =
