@@ -54,7 +54,6 @@
 #include "../nongui/ProcessingFlow.hpp"
 #include "SavitzkyGolayFilterParamsDlg.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -62,22 +61,22 @@ namespace MineXpert
 
 struct PeakLabel
 {
-    QCPItemText *rp_qcpItemText = nullptr;
-    QPointF position;
+  QCPItemText *rp_qcpItemText = nullptr;
+  QPointF position;
 
-    PeakLabel(QCustomPlot *plot_p, const QString text, const QPointF &position)
-    {
-        rp_qcpItemText = new QCPItemText(plot_p);
-        rp_qcpItemText->setText(text);
-        rp_qcpItemText->setLayer("plotsLayer");
-        rp_qcpItemText->setColor(QColor("black"));
+  PeakLabel(QCustomPlot *plot_p, const QString text, const QPointF &position)
+  {
+    rp_qcpItemText = new QCPItemText(plot_p);
+    rp_qcpItemText->setText(text);
+    rp_qcpItemText->setLayer("plotsLayer");
+    rp_qcpItemText->setColor(QColor("black"));
 
-        rp_qcpItemText->setPositionAlignment(Qt::AlignBottom | Qt::AlignLeft);
-        rp_qcpItemText->position->setType(QCPItemPosition::ptPlotCoords);
-        rp_qcpItemText->position->setCoords(position.x(), position.y());
-        rp_qcpItemText->setRotation(-60);
-        rp_qcpItemText->setVisible(true);
-    }
+    rp_qcpItemText->setPositionAlignment(Qt::AlignBottom | Qt::AlignLeft);
+    rp_qcpItemText->position->setType(QCPItemPosition::ptPlotCoords);
+    rp_qcpItemText->position->setCoords(position.x(), position.y());
+    rp_qcpItemText->setRotation(-60);
+    rp_qcpItemText->setVisible(true);
+  }
 };
 
 using PeakLabelSPtr = std::shared_ptr<PeakLabel>;
@@ -85,22 +84,17 @@ using PeakLabelSPtr = std::shared_ptr<PeakLabel>;
 class BaseTracePlotWnd;
 class MsFragmentationSpecDlg;
 
-
 // The BaseTracePlotCompositeWidget class is aimed at receiving QCPGraph_s, not
 // QCPColorMap_s. This class implements all the basic features related to the
 // presence of QCPGraph_s, like adding a Trace plot, for example, which would
 // not work if the plot were of type QCPColorMap...
-class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
+class BaseTracePlotCompositeWidget: public BasePlotCompositeWidget
 {
   Q_OBJECT
 
   friend class BasePlotWnd;
   friend class BaseTracePlotWnd;
 
-  public slots:
-
-  void labellingSessionMenuPushButtonClicked();
-
   public:
   explicit BaseTracePlotCompositeWidget(QWidget *parent,
                                         const QString &x_axis_label,
@@ -129,6 +123,8 @@ class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
 
   void runFilter(const QString &filter_name);
   void runSavitzkyGolayFilter();
+  void runLowIntensityThresholdRemovalFilter(QWidgetAction *widget_action_p);
+  void removeZeroIntensityDataPointsFilter();
 
   pappso::Trace pickPeaksOnlyOnVisibleMaxima();
 
@@ -147,6 +143,8 @@ class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
 
   public slots:
 
+  virtual void labellingSessionMenuPushButtonClicked();
+
   virtual void
   plotWidgetKeyPressEvent(const pappso::BasePlotContext &context) override;
 
@@ -171,16 +169,17 @@ class BaseTracePlotCompositeWidget : public BasePlotCompositeWidget
   protected:
   // These are the members that are specific to the BaseTrace plot composite
   // widget.
-      QMenu *mp_labelSessionMenu = nullptr;
-      bool m_isSinglePointIntegrationMode = false;
-      QCPRange m_integrationRange;
-      SavitzkyGolayFilterParamsDlg *mp_savitzkyGolayFilterParamsDlg = nullptr;
+  QMenu *mp_labelSessionMenu          = nullptr;
+  bool m_isSinglePointIntegrationMode = false;
+  QCPRange m_integrationRange;
+  SavitzkyGolayFilterParamsDlg *mp_savitzkyGolayFilterParamsDlg = nullptr;
 
-      bool m_isPinPointingPeakApex = false;
-      std::vector<PeakLabelSPtr> m_peakLabels;
+  bool m_isPinPointingPeakApex = false;
+  std::vector<PeakLabelSPtr> m_peakLabels;
 
-      virtual void createMainMenu() override;
-      pappso::Trace lowIntensitySignalRemoval(pappso::Trace &trace, double value);
+  void createMainMenu() ;
+  void configureOutIntegrationCheckButtons();
+  pappso::Trace lowIntensitySignalRemoval(pappso::Trace &trace, double value);
 };
 
 
