@@ -97,7 +97,8 @@ BaseTracePlotWnd::getNoiseSampleStats(std::size_t &point_count,
   if(mpa_noiseSampleTrace == nullptr)
     return false;
 
-  if(!mpa_noiseSampleTrace->size())
+  if(!dynamic_cast<std::vector<pappso::DataPoint> *>(mpa_noiseSampleTrace)
+        ->size())
     return false;
 
   // We need to compute the mean value of the intensities, but without taking
@@ -161,8 +162,8 @@ BaseTracePlotWnd::newTrace(const pappso::Trace &trace,
   // We get a new trace, but we cannot know before where to put it. We first
   // need to check if there are pinned-down widgets or not.
 
-  qDebug() << "20250904 - Adding new trace with parent plottable:"
-           << parent_plottable_p;
+  // qDebug() << "Adding new trace with parent plottable:"
+  //          << parent_plottable_p;
 
 
   // We need to establish what widget is the destination of the integration. If
@@ -177,21 +178,30 @@ BaseTracePlotWnd::newTrace(const pappso::Trace &trace,
 
   if(pinned_down_widgets.size())
     {
+      // qDebug() << "There is at least one pinned composite plot widget.";
+
       for(auto &&pinned_down_widget : pinned_down_widgets)
-        static_cast<BaseTracePlotCompositeWidget *>(pinned_down_widget)
-          ->addTrace(trace,
-                     static_cast<QCPGraph *>(parent_plottable_p),
-                     ms_run_data_set_csp,
-                     ms_run_data_set_csp->getMsRunId()->getSampleName(),
-                     processing_flow,
-                     color);
+        {
+          // qDebug() << "Iterating in one pinned-down composite widget.";
+
+          static_cast<BaseTracePlotCompositeWidget *>(pinned_down_widget)
+            ->addTrace(trace,
+                       static_cast<QCPGraph *>(parent_plottable_p),
+                       ms_run_data_set_csp,
+                       ms_run_data_set_csp->getMsRunId()->getSampleName(),
+                       processing_flow,
+                       color);
+        }
     }
   else
-    addTracePlot(trace,
-                 ms_run_data_set_csp,
-                 processing_flow,
-                 color,
-                 static_cast<QCPGraph *>(parent_plottable_p));
+    {
+      // qDebug() << "There is no pinned composite plot widget.";
+      addTracePlot(trace,
+                   ms_run_data_set_csp,
+                   processing_flow,
+                   color,
+                   static_cast<QCPGraph *>(parent_plottable_p));
+    }
 }
 
 QCPGraph *
@@ -359,14 +369,14 @@ BaseTracePlotWnd::duplicateTracePlot(
         processing_flow_p->getMsRunDataSetCstSPtr();
 
       if(ms_run_data_set_csp == nullptr)
-        qFatal("The pointer cannot be nullptr.");
+        qFatal() << "The pointer cannot be nullptr.";
 
       // Sanity check
       MsRunDataSetCstSPtr check_ms_run_data_set_csp =
         composite_widget_p->getMsRunDataSetCstSPtrForPlottable(parent_graph_p);
 
       if(check_ms_run_data_set_csp != ms_run_data_set_csp)
-        qFatal("Cannot be that the pointers be different.");
+        qFatal() << "Cannot be that the pointers be different.";
 
       if(!destination_widget_list_size)
         {
