@@ -55,7 +55,7 @@ ConsoleWnd::ConsoleWnd(QWidget *parent, const QString &applicationName)
     m_ui(new ::Ui::ConsoleWnd)
 {
   if(parent == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   m_ui->setupUi(this);
 
@@ -65,14 +65,12 @@ ConsoleWnd::ConsoleWnd(QWidget *parent, const QString &applicationName)
   readSettings();
 }
 
-
 //! Destruct \c this ConsoleWnd instance.
 ConsoleWnd::~ConsoleWnd()
 {
   writeSettings();
 }
 
-
 void
 ConsoleWnd::closeEvent(QCloseEvent *event)
 {
@@ -80,7 +78,6 @@ ConsoleWnd::closeEvent(QCloseEvent *event)
   event->accept();
 }
 
-
 //! Save the settings to later restore the window in its same position.
 void
 ConsoleWnd::writeSettings()
@@ -97,7 +94,6 @@ ConsoleWnd::writeSettings()
   settings.endGroup();
 }
 
-
 //! Read the settings to restore the window in its last position.
 void
 ConsoleWnd::readSettings()
@@ -114,7 +110,6 @@ ConsoleWnd::readSettings()
   settings.endGroup();
 }
 
-
 //! Overload without color for scripting simplicity.
 void
 ConsoleWnd::logTextToConsole(QString text)
@@ -122,7 +117,6 @@ ConsoleWnd::logTextToConsole(QString text)
   logColoredTextToConsole(text, Qt::black);
 }
 
-
 //! Log a message into the console.
 /*!
 
@@ -181,7 +175,6 @@ ConsoleWnd::logColoredTextToConsole(QString msg, const QColor &color)
   m_ui->consolePlainTextEdit->setTextCursor(cursor);
 }
 
-
 void
 ConsoleWnd::hide()
 {
