@@ -68,7 +68,6 @@ DataPlottableTree::~DataPlottableTree()
   m_rootNodes.clear();
 }
 
-
 const BasePlotCompositeWidget *
 DataPlottableTree::getPlotWidget(QCPAbstractPlottable *plottable_p)
 {
@@ -80,7 +79,6 @@ DataPlottableTree::getPlotWidget(QCPAbstractPlottable *plottable_p)
   return nullptr;
 }
 
-
 DataPlottableNode *
 DataPlottableTree::addPlottable(MsRunDataSetCstSPtr ms_run_data_set_csp,
                                 QCPAbstractPlottable *plottable_p,
@@ -88,7 +86,7 @@ DataPlottableTree::addPlottable(MsRunDataSetCstSPtr ms_run_data_set_csp,
                                 BasePlotCompositeWidget *plot_widget_p)
 {
   if(plottable_p == nullptr)
-    qFatal("The pointer cannot be nullptr.");
+    qFatal() << "The pointer cannot be nullptr.";
 
   // If parent_p is not nullptr, then, we need to find the node that handles it.
   // That node will be the host for the new node we created for plottable_p.
@@ -115,7 +113,7 @@ DataPlottableTree::addPlottable(MsRunDataSetCstSPtr ms_run_data_set_csp,
       parent_node_p = findNode(parent_plottable_p);
 
       if(parent_node_p == nullptr)
-        qFatal("Cannot be that the plottable has no matching parent node.");
+        qFatal() << "Cannot be that the plottable has no matching parent node.";
 
       new_node_p = new DataPlottableNode(
         ms_run_data_set_csp, plottable_p, parent_node_p, plot_widget_p);
@@ -138,14 +136,12 @@ DataPlottableTree::addPlottable(MsRunDataSetCstSPtr ms_run_data_set_csp,
   return new_node_p;
 }
 
-
 const std::vector<DataPlottableNode *> &
 DataPlottableTree::getRootNodes() const
 {
   return m_rootNodes;
 }
 
-
 DataPlottableNode *
 DataPlottableTree::findNode(QCPAbstractPlottable *plot_plottable_p)
 {
@@ -179,7 +175,6 @@ DataPlottableTree::findNode(QCPAbstractPlottable *plot_plottable_p)
   return nullptr;
 }
 
-
 std::vector<DataPlottableNode *>
 DataPlottableTree::findNodes(MsRunDataSetCstSPtr ms_run_data_set_csp,
                              bool recursively)
@@ -206,7 +201,6 @@ DataPlottableTree::findNodes(MsRunDataSetCstSPtr ms_run_data_set_csp,
   return found_nodes;
 }
 
-
 std::vector<DataPlottableNode *>::iterator
 DataPlottableTree::findNode(DataPlottableNode *searched_node_p)
 {
@@ -214,7 +208,7 @@ DataPlottableTree::findNode(DataPlottableNode *searched_node_p)
   // the tree. We are looking for a node searched_node_p.
 
   if(searched_node_p == nullptr)
-    qFatal("Pointer cannot be nullptr.");
+    qFatal() << "Pointer cannot be nullptr.";
 
   // First search if any of the root nodes is the searched_node_p.
 
@@ -239,7 +233,7 @@ DataPlottableTree::findNode(DataPlottableNode *searched_node_p)
       // found.
 
       std::vector<DataPlottableNode *>::iterator iter =
-        root_node_p->findNode(searched_node_p);
+        root_node_p->findNodeIterator(searched_node_p);
 
       if(iter != root_node_p->m_children.end())
         return iter;
@@ -249,13 +243,12 @@ DataPlottableTree::findNode(DataPlottableNode *searched_node_p)
   return m_rootNodes.end();
 }
 
-
 std::vector<DataPlottableNode *>
 DataPlottableTree::findNodes(
   BasePlotCompositeWidget *base_plot_composite_widget_p, bool recursively)
 {
   if(base_plot_composite_widget_p == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // qDebug() << "Finding nodes that match plot widget:"
   //<< base_plot_composite_widget_p;
@@ -281,15 +274,16 @@ DataPlottableTree::findNodes(
   return found_nodes;
 }
 
-
 bool
 DataPlottableTree::isRootNode(DataPlottableNode *node_p)
 {
 
-  std::vector<DataPlottableNode *>::iterator iter = std::find_if(
-    m_rootNodes.begin(),
-    m_rootNodes.end(),
-    [node_p](DataPlottableNode *iter_node) { return iter_node == node_p; });
+  std::vector<DataPlottableNode *>::iterator iter =
+    std::find_if(m_rootNodes.begin(),
+                 m_rootNodes.end(),
+                 [node_p](DataPlottableNode *iter_node) {
+                   return iter_node == node_p;
+                 });
 
   if(iter != m_rootNodes.end())
     return true;
@@ -297,7 +291,6 @@ DataPlottableTree::isRootNode(DataPlottableNode *node_p)
   return false;
 }
 
-
 bool
 DataPlottableTree::isRootPlottable(QCPAbstractPlottable *plot_plottable_p)
 {
@@ -312,7 +305,6 @@ DataPlottableTree::isRootPlottable(QCPAbstractPlottable *plot_plottable_p)
   return false;
 }
 
-
 std::size_t
 DataPlottableTree::depth() const
 {
@@ -341,7 +333,6 @@ DataPlottableTree::depth() const
   return greatest_depth;
 }
 
-
 std::size_t
 DataPlottableTree::size(bool look_deep) const
 {
@@ -372,7 +363,6 @@ DataPlottableTree::size(bool look_deep) const
   return cumulative_node_count;
 }
 
-
 bool
 DataPlottableTree::reparent(DataPlottableNode *node_p,
                             DataPlottableNode *new_parent_node_p)
@@ -409,14 +399,19 @@ DataPlottableTree::reparent(DataPlottableNode *node_p,
       // The node to reparent is a root node. Remove that node from
       // m_rootNodes.
 
-      std::vector<DataPlottableNode *>::iterator iter = std::find_if(
-        m_rootNodes.begin(),
-        m_rootNodes.end(),
-        [node_p](DataPlottableNode *iter_node) { return iter_node == node_p; });
+      std::vector<DataPlottableNode *>::iterator iter =
+        std::find_if(m_rootNodes.begin(),
+                     m_rootNodes.end(),
+                     [node_p](DataPlottableNode *iter_node) {
+                       return iter_node == node_p;
+                     });
 
       if(iter == m_rootNodes.end())
         {
-          qFatal("Cannot be that root node not be found in m_rootNodes.");
+          qFatal() << "Cannot be that root node not be found in m_rootNodes.";
+          // Needed for cppcheck to see that erase will be called if
+          // iterator is not end().
+          return false;
         }
 
       // At this point, simply remove the node from the m_rootNodes vector
@@ -425,10 +420,11 @@ DataPlottableTree::reparent(DataPlottableNode *node_p,
       m_rootNodes.erase(iter);
 
       // Sanity check:
-      iter = std::find_if(
-        m_rootNodes.begin(),
-        m_rootNodes.end(),
-        [node_p](DataPlottableNode *iter_node) { return iter_node == node_p; });
+      iter = std::find_if(m_rootNodes.begin(),
+                          m_rootNodes.end(),
+                          [node_p](DataPlottableNode *iter_node) {
+                            return iter_node == node_p;
+                          });
 
       if(iter != m_rootNodes.end())
         {
@@ -442,10 +438,12 @@ DataPlottableTree::reparent(DataPlottableNode *node_p,
       // The node to reparent is not a root node, so remove that node from its
       // parent's m_children vector of nodes.
 
-      std::vector<DataPlottableNode *>::iterator iter = std::find_if(
-        node_p->mp_parent->m_children.begin(),
-        node_p->mp_parent->m_children.end(),
-        [node_p](DataPlottableNode *iter_node) { return iter_node == node_p; });
+      std::vector<DataPlottableNode *>::iterator iter =
+        std::find_if(node_p->mp_parent->m_children.begin(),
+                     node_p->mp_parent->m_children.end(),
+                     [node_p](DataPlottableNode *iter_node) {
+                       return iter_node == node_p;
+                     });
 
       if(iter == node_p->mp_parent->m_children.end())
         {
@@ -459,10 +457,11 @@ DataPlottableTree::reparent(DataPlottableNode *node_p,
       node_p->mp_parent->m_children.erase(iter);
 
       // Sanity check:
-      iter = std::find_if(
-        node_p->mp_parent->m_children.begin(),
-        node_p->mp_parent->m_children.end(),
-        [node_p](DataPlottableNode *iter_node) { return iter_node == node_p; });
+      iter = std::find_if(node_p->mp_parent->m_children.begin(),
+                          node_p->mp_parent->m_children.end(),
+                          [node_p](DataPlottableNode *iter_node) {
+                            return iter_node == node_p;
+                          });
 
       if(iter != node_p->mp_parent->m_children.end())
         qFatal(
@@ -495,7 +494,6 @@ DataPlottableTree::reparent(DataPlottableNode *node_p,
   return true;
 }
 
-
 bool
 DataPlottableTree::removeNodeAndPlottable(DataPlottableNode *node_p,
                                           bool recursively)
@@ -505,7 +503,7 @@ DataPlottableTree::removeNodeAndPlottable(DataPlottableNode *node_p,
   // this node if they sit in the same widget being destructed.
 
   if(node_p == nullptr)
-    qFatal("Pointer cannot be nullptr.");
+    qFatal() << "Pointer cannot be nullptr.";
 
   // What is the plot widget in which resides the plottable being destroyed ?
   BasePlotCompositeWidget *plot_composite_widget_p = node_p->mp_plotWidget;
@@ -626,13 +624,15 @@ DataPlottableTree::removeNodeAndPlottable(DataPlottableNode *node_p,
       //"node in the parent node's m_children. Parent node:"
       //<< parent_node_p->toString(0, true);
 
-      std::vector<DataPlottableNode *>::iterator iter = std::find_if(
-        parent_node_p->m_children.begin(),
-        parent_node_p->m_children.end(),
-        [node_p](DataPlottableNode *iter_node) { return iter_node == node_p; });
+      std::vector<DataPlottableNode *>::iterator iter =
+        std::find_if(parent_node_p->m_children.begin(),
+                     parent_node_p->m_children.end(),
+                     [node_p](DataPlottableNode *iter_node) {
+                       return iter_node == node_p;
+                     });
 
       if(iter == parent_node_p->m_children.end())
-        qFatal("Programming error.");
+        qFatal() << "Programming error.";
 
       // Ok, we found node_p amongst the children of node_p's parent.
       // Remove it from the parent's list of children. It is going to be
@@ -646,10 +646,10 @@ DataPlottableTree::removeNodeAndPlottable(DataPlottableNode *node_p,
       // Sanity check
 
       if(*iter != node_p)
-        qFatal("Programming error.");
+        qFatal() << "Programming error.";
 
       if((*iter)->mp_parent != parent_node_p)
-        qFatal("Programming error.");
+        qFatal() << "Programming error.";
 
       // With the sanity checks, we can safely delete node_p and remove its
       // pointer from the vector.
@@ -668,10 +668,12 @@ DataPlottableTree::removeNodeAndPlottable(DataPlottableNode *node_p,
       // " "node to remove is a root node.Searching the node to remove " "in the
       // root nodes.";
 
-      std::vector<DataPlottableNode *>::iterator iter = std::find_if(
-        m_rootNodes.begin(),
-        m_rootNodes.end(),
-        [node_p](DataPlottableNode *iter_node) { return iter_node == node_p; });
+      std::vector<DataPlottableNode *>::iterator iter =
+        std::find_if(m_rootNodes.begin(),
+                     m_rootNodes.end(),
+                     [node_p](DataPlottableNode *iter_node) {
+                       return iter_node == node_p;
+                     });
 
       if(iter == m_rootNodes.end())
         qFatal(
@@ -690,10 +692,10 @@ DataPlottableTree::removeNodeAndPlottable(DataPlottableNode *node_p,
       // Sanity check
 
       if(*iter != node_p)
-        qFatal("Programming error.");
+        qFatal() << "Programming error.";
 
       if((*iter)->mp_parent != parent_node_p)
-        qFatal("Programming error.");
+        qFatal() << "Programming error.";
 
       // qDebug().noquote() << "Before erasing node, the root nodes have
       // become:";
