@@ -45,9 +45,8 @@
 
 
 /////////////////////// Local includes
-#include "DataPlottableNode.hpp"
 #include "../nongui/MsRunDataSet.hpp"
-#include "DataPlottableNode.hpp"
+#include "BasePlotCompositeWidget.hpp"
 
 
 namespace MsXpS
@@ -56,11 +55,11 @@ namespace MineXpert
 {
 
 class DataPlottableTree;
+class DataPlottableNode;
 
 typedef std::shared_ptr<DataPlottableTree> DataPlottableTreeSPtr;
 typedef std::shared_ptr<const DataPlottableTree> DataPlottableTreeCstSPtr;
 
-
 class DataPlottableTree
 {
   public:
