@@ -79,6 +79,8 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::setupWidget()
 {
   // qDebug();
 
+  setWindowIcon(qApp->windowIcon());
+
   /************  The QCustomPlot widget *************/
   /************  The QCustomPlot widget *************/
   mp_plotWidget = new pappso::DriftSpecMassSpecColorMapPlotWidget(
@@ -146,7 +148,6 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::setupWidget()
           this,
           &DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested);
 
-
   /************ The QCustomPlot widget *************/
 
   /************ The various widgets in this composite widget ***************/
@@ -345,12 +346,12 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
   if(x_axis_data_kind == pappso::Enums::DataKind::dt &&
      y_axis_data_kind != pappso::Enums::DataKind::mz)
     {
-      qFatal("Programming error.");
+      qFatal() << "Programming error.";
     }
   else if(x_axis_data_kind == pappso::Enums::DataKind::mz &&
           y_axis_data_kind != pappso::Enums::DataKind::dt)
     {
-      qFatal("Programming error.");
+      qFatal() << "Programming error.";
     }
 
   // The colormap can have its axes transposed, so we need to ensure that we
@@ -445,8 +446,10 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Now we know we have the right selection polygon for x:MZ and y:DT.
 
-  processing_step_sp->setDataKind(pappso::Enums::Axis::x, pappso::Enums::DataKind::dt);
-  processing_step_sp->setDataKind(pappso::Enums::Axis::y, pappso::Enums::DataKind::mz);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::x,
+                                  pappso::Enums::DataKind::dt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::y,
+                                  pappso::Enums::DataKind::mz);
 
   local_integration_scope_base_sp->setDataKindX(pappso::Enums::DataKind::dt);
   local_integration_scope_base_sp->setDataKindY(pappso::Enums::DataKind::mz);
@@ -542,7 +545,7 @@ DriftSpecMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       if(!res)
         {
-          qFatal("Failed to get the m/z range out of the selection polygon");
+          qFatal() << "Failed to get the m/z range out of the selection polygon";
         }
 
       // At this point, change the values in the mz_integration_params so
