@@ -52,7 +52,6 @@
 #include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -69,13 +68,11 @@ DriftSpecMassSpecColorMapWnd::DriftSpecMassSpecColorMapWnd(
 {
 }
 
-
 //! Destruct \c this DriftSpecMassSpecColorMapWnd instance.
 DriftSpecMassSpecColorMapWnd::~DriftSpecMassSpecColorMapWnd()
 {
 }
 
-
 QCPColorMap *
 DriftSpecMassSpecColorMapWnd::addColorMapPlot(
   std::shared_ptr<std::map<double, pappso::MapTrace>> &double_map_trace_map_sp,
@@ -115,7 +112,6 @@ DriftSpecMassSpecColorMapWnd::addColorMapPlot(
                                            parent_plottable_p);
 }
 
-
 void
 DriftSpecMassSpecColorMapWnd::integrateToDtMz(
   QCPAbstractPlottable *parent_plottable_p,
@@ -131,7 +127,7 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
@@ -141,7 +137,7 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
 
   if(!integration_rt)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
   //          << "for y axis: " << range_pair.first << "-" << range_pair.second;
@@ -150,7 +146,8 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
   //
   // if(integration_dt)
   //   qDebug() << qSetRealNumberPrecision(10) << "Innermost DT range:"
-  //            << "for y axis: " << range_pair.first << "-" << range_pair.second;
+  //            << "for y axis: " << range_pair.first << "-" <<
+  //            range_pair.second;
 
   // FIXME: END Sanity check that might be removed when the program is
   // stabilized.
@@ -158,13 +155,16 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
   bool integration_mz = processing_flow.innermostRange("ANY_MZ", range_pair);
 
   if(integration_mz)
-    qDebug() << qSetRealNumberPrecision(10)
-             << "Innermost m/z range:" << range_pair.first << "-"
-             << range_pair.second;
+    {
+      // qDebug() << qSetRealNumberPrecision(10)
+      //          << "Innermost m/z range:" << range_pair.first << "-"
+      //          << range_pair.second;
+    }
   else
     {
-      qDebug() << "There is no m/z integration. We need to get the range from "
-                  "the MsRunDataSet instance.";
+      // qDebug() << "There is no m/z integration. We need to get the range from
+      // "
+      //             "the MsRunDataSet instance.";
 
       MsRunDataSetStats ms_run_data_stats =
         ms_run_data_set_csp->getMsRunDataSetStats();
@@ -172,9 +172,9 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
       range_pair.first  = ms_run_data_stats.m_minMz;
       range_pair.second = ms_run_data_stats.m_maxMz;
 
-      qDebug() << qSetRealNumberPrecision(10)
-               << "Smallest m/z: " << range_pair.first
-               << "Greatest m/z: " << range_pair.second;
+      // qDebug() << qSetRealNumberPrecision(10)
+      //          << "Smallest m/z: " << range_pair.first
+      //          << "Greatest m/z: " << range_pair.second;
     }
 
   // First prepare a vector of QualifiedMassSpectrumCstSPtr. If the
@@ -185,9 +185,10 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
-  qDebug()
-    << "The number of selected mass spectra on the basis of rough RT/DT values:"
-    << qualified_mass_spectra_count;
+  // qDebug()
+  //   << "The number of selected mass spectra on the basis of rough RT/DT
+  //   values:"
+  //   << qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
     return;
@@ -342,7 +343,6 @@ DriftSpecMassSpecColorMapWnd::integrateToDtMz(
     &MassDataIntegratorTask::integrateToDtRtMz);
 }
 
-
 void
 DriftSpecMassSpecColorMapWnd::finishedIntegratingToDtMz(
   QualifiedMassSpectrumVectorMassDataIntegrator *mass_data_integrator_p,
@@ -394,7 +394,7 @@ DriftSpecMassSpecColorMapWnd::finishedIntegratingToDtMz(
 
   if(!double_map_trace_map_sp->size())
     {
-      qDebug() << "There is not a single item in the dt / mz map.";
+      // qDebug() << "There is not a single item in the dt / mz map.";
 
       return;
     }
