@@ -65,7 +65,6 @@
 
 /////////////////////// Local includes
 #include "MassSpecTracePlotCompositeWidget.hpp"
-#include "MassSpecTracePlotWidget.hpp"
 #include "MassSpecTracePlotWnd.hpp"
 #include "ProgramWindow.hpp"
 #include "ui_BasePlotCompositeWidget.h"
@@ -99,6 +98,7 @@ MassSpecTracePlotCompositeWidget::setupWidget()
   /************  The QCustomPlot widget *************/
   mp_plotWidget =
     new pappso::MassSpecTracePlotWidget(this, m_axisLabelX, m_axisLabelY);
+
   m_ui->qcpTracePlotWidgetHorizontalLayout->addWidget(mp_plotWidget);
 
   // We want that the axis labels be output inside the plot wiget area.
@@ -182,6 +182,7 @@ MassSpecTracePlotCompositeWidget::setupWidget()
 
   // Create the context menu that should have menu items specific for this mass
   // spec-specific wiget.
+
   createMainMenu();
 
   /************ The QCustomPlot widget *************/
@@ -202,11 +203,20 @@ MassSpecTracePlotCompositeWidget::setupWidget()
 void
 MassSpecTracePlotCompositeWidget::createMainMenu()
 {
-  // qDebug() << "ENTER";
+  // Complete the base class menu with the color-map-specific menu
+  // item.
 
-  // First make sure we do construct the base trace plot context menu.
+  qDebug() << "Completing the main menu:" << mp_mainMenu;
 
-  BaseTracePlotCompositeWidget::createMainMenu();
+  // Debug: the icon is there
+  // QIcon the_icon =  m_ui->mainMenuPushButton->icon();
+  // QSize size = m_ui->mainMenuPushButton->iconSize();  // typically what you
+  // want QPixmap pixmap = the_icon.pixmap(size);
+  // pixmap.save("/tmp/massspecicon.png");
+
+  // Update the menu tooltip.
+  m_ui->mainMenuPushButton->setToolTip(
+    "Mass spec trace plot widget menu (Ctrl+P, M)");
 
   mp_mainMenu->addSeparator();
 
@@ -739,27 +749,6 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
   return;
 }
 
-void
-MassSpecTracePlotCompositeWidget::mainMenuPushButtonClicked()
-{
-  // qDebug() << "ENTER";
-
-  //// Create the contextual menu that will show when the button is
-  /// clicked (see / below).
-
-  // The menu, when it is opened (shown) changes the size of the plot
-  // widget. We want to restore the initial size.
-
-  QByteArray composite_plot_widget_geometry = mp_plotWidget->saveGeometry();
-
-  createMainMenu();
-  m_ui->mainMenuPushButton->showMenu();
-
-  mp_plotWidget->restoreGeometry(composite_plot_widget_geometry);
-
-  // qDebug() << "EXIT";
-}
-
 void
 MassSpecTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::MassSpecTracePlotContext &context)
@@ -916,21 +905,23 @@ MassSpecTracePlotCompositeWidget::plotWidgetMassDeconvolution(
   //.arg(context.m_lastMz)
   //.arg(context.m_lastMr);
 
-  QString new_text = QString("[%1--%2] - delta: %3 -- z: %4 - m/z: %5 - Mr: %6")
-                       .arg(std::min<double>(context.m_xRegionRangeStart,
-                                             context.m_xRegionRangeEnd),
-                            0,
-                            'f',
-                            4)
-                       .arg(std::max<double>(context.m_xRegionRangeStart,
-                                             context.m_xRegionRangeEnd),
-                            0,
-                            'f',
-                            4)
-                       .arg(fabs(context.m_xDelta), 0, 'f', 4)
-                       .arg(context.m_lastZ)
-                       .arg(context.m_lastMz, 0, 'f', 4)
-                       .arg(context.m_lastMr, 0, 'f', 3);
+  QString new_text =
+    QString("[%1--%2] - delta: %3 -- z: %4 - m/z: %5 - Mr: %6")
+      .arg(std::min<double>(context.m_xRegionRangeStart,
+                            context.m_xRegionRangeEnd),
+           0,
+           'f',
+           libXpertMassCore::MZ_DEC_PLACES)
+      .arg(std::max<double>(context.m_xRegionRangeStart,
+                            context.m_xRegionRangeEnd),
+           0,
+           'f',
+           libXpertMassCore::MZ_DEC_PLACES)
+      .arg(
+        fabs(context.m_xDelta), 0, 'f', libXpertMassCore::DELTA_MZ_DEC_PLACES)
+      .arg(context.m_lastZ)
+      .arg(context.m_lastMz, 0, 'f', libXpertMassCore::MZ_DEC_PLACES)
+      .arg(context.m_lastMr, 0, 'f', libXpertMassCore::MZ_DEC_PLACES);
 
   m_ui->statusLineEdit->setText(new_text);
 }
@@ -984,7 +975,7 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   // For integrations that are directed to a mass spectrum,
   // check the MassSpectracePlotWnd class !!!
 
-  qDebug().noquote() << "20250904 - context:" << context.toString();
+  // qDebug().noquote() << "context:" << context.toString();
 
   // The reference implementation is the
   // TicXicChromTracePlotCompositeWidget one. Look there for all the
@@ -994,7 +985,7 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   pappso::BasePlotContext local_context;
   local_context.initialize(context);
 
-  qDebug().noquote() << "20250904 - local context:" << local_context.toString();
+  // qDebug().noquote() << "local context:" << local_context.toString();
 
   // Check if the integration scope contains meaningful data. We are in trace
   // plot widget, so the scope might be in the form of a
@@ -1010,11 +1001,11 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       //**local_context.msp_integrationScope->convertTo1D();
       double width;
       if(!local_context.msp_integrationScope->getWidth(width))
-        qFatal("Failed to get width.");
+        qFatal() << "Failed to get width.";
 
       QPointF point;
       if(!local_context.msp_integrationScope->getPoint(point))
-        qFatal("Failed to get point.");
+        qFatal() << "Failed to get point.";
 
       local_context.msp_integrationScope =
         std::make_shared<const pappso::IntegrationScopeBase>(
@@ -1037,8 +1028,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   local_context.msp_integrationScope->range(
     pappso::Enums::Axis::x, range_start, range_end);
 
-  qDebug().noquote() << "20250904 - local context extracted X axis range:"
-                     << range_start << "-" << range_end;
+  // qDebug().noquote() << "local context extracted X axis range:"
+  //                    << range_start << "-" << range_end;
 
   // Having negative masses does not make any sense.
   if(range_start < 0 && range_end < 0)
@@ -1065,14 +1056,15 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   ProcessingFlow *temp_processing_flow_p =
     getProcessingFlowPtrForPlottable(plottable_p)->clone(nullptr);
 
-  qDebug().noquote() << "20250904 - Got processing flow from plottable:\n"
-                     << temp_processing_flow_p->toString(0, "  ");
+  // qDebug().noquote() << "Got processing flow from plottable:\n"
+  //                    << temp_processing_flow_p->toString(0, "  ");
 
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getMsRunDataSetCstSPtrForPlottable(plottable_p);
 
-  qDebug().noquote() << "20250904 - The ms run data statistics:"
-                     << ms_run_data_set_csp->getMsRunDataSetStats().toString();
+  // qDebug().noquote() << "The ms run data statistics:"
+  //                    <<
+  //                    ms_run_data_set_csp->getMsRunDataSetStats().toString();
 
   // Create a processing step to document the specifics of this new
   // integration.
@@ -1103,8 +1095,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
   // Now define the graph range for the integration operation.
   processing_step_sp->setIntegrationScope(local_context.msp_integrationScope);
 
-  qDebug() << "20250904 - Set this integration scope to the processing step:"
-           << processing_step_sp->getIntegrationScope()->toString();
+  // qDebug() << "Set this integration scope to the processing step:"
+  //          << processing_step_sp->getIntegrationScope()->toString();
 
   // We must say what is the data source processing type.
   processing_step_sp->setSrcProcessingType(pappso::Enums::Axis::x, "MZ");
@@ -1167,8 +1159,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       pappso::MzIntegrationParams *mz_integration_params_p =
         temp_processing_flow_p->getSensibleMzIntegrationParams();
 
-      qDebug().noquote() << "20250904 - Got sensible mz integration params:\n"
-                         << mz_integration_params_p->toString();
+      // qDebug().noquote() << "Got sensible mz integration params:\n"
+      //                    << mz_integration_params_p->toString();
 
       // Note that we cannot integrate mass spectra with a high resolution
       // here. We need to reduce the resolution to integer resolution.
@@ -1192,8 +1184,8 @@ MassSpecTracePlotCompositeWidget::integrationRequested(
       // Should perform automatically the conversion from non-const to const.
       temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
-      qDebug().noquote() << "20250904 - Pushed back new processing step:\n"
-                         << processing_step_sp->toString();
+      // qDebug().noquote() << "Pushed back new processing step:\n"
+      //                    << processing_step_sp->toString();
 
       // The local processing flow contains all the previous steps and the
       // last one that documents this current integration.
@@ -1279,7 +1271,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
   const QColor &color)
 {
 
-  // qDebug();
+  qDebug();
 
   // If color is not valid, we need to create one.
 
@@ -1347,8 +1339,14 @@ MassSpecTracePlotCompositeWidget::addTrace(
       // spectrum be performed, there must be a non-nullptr mz integration
       // pointer in the step.
       // Returns the pointer, not a newly allocated instance for us.
+
+      // If the user has configured that no binning is to be performed, we
+      // should get that config now (or any other, of course).
       const pappso::MzIntegrationParams *mz_integration_params_p =
-        processing_flow.mostRecentMzIntegrationParams();
+        processing_flow.getSensibleMzIntegrationParams();
+
+      // qDebug() << "The sensible MzIntegrationParams: "
+      //          << mz_integration_params_p->toString();
 
       if(mz_integration_params_p == nullptr)
         qFatal(
@@ -1367,7 +1365,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
           // qDebug() << "Adding new trace with combination requested.";
 
           // qDebug() << "The most recent mz integration parameters:"
-          //<< mz_integration_params_p->toString();
+          //          << mz_integration_params_p->toString(0, " ");
 
           if(mz_integration_params_p->getBinningType() ==
              pappso::MzIntegrationParams::BinningType::NONE)
@@ -1385,7 +1383,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
                     dest_plottable_list.at(iter);
                   pappso::Trace iter_trace =
                     static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
-                      ->toTrace(static_cast<QCPGraph *>(iter_plottable_p));
+                      ->toTrace(dynamic_cast<QCPGraph *>(iter_plottable_p));
 
                   // Initialize the receiving map trace with the trace we
                   // are iterating into.
@@ -1395,10 +1393,18 @@ MassSpecTracePlotCompositeWidget::addTrace(
 
                   if(m_newTraceHandlingMethod ==
                      NewTraceHandlingMethod::MINUS_COMBINE)
-                    trace_minus_combiner.combine(map_trace, trace);
+                    {
+                      // qDebug() << "Now minus combining without "
+                      //             "binning.";
+                      trace_minus_combiner.combine(map_trace, trace);
+                    }
                   else if(m_newTraceHandlingMethod ==
                           NewTraceHandlingMethod::PLUS_COMBINE)
-                    trace_plus_combiner.combine(map_trace, trace);
+                    {
+                      // qDebug() << "Now minus combining without "
+                      //             "binning.";
+                      trace_plus_combiner.combine(map_trace, trace);
+                    }
 
                   // Old version that was deprecated in 5.14.2
                   //
@@ -1464,30 +1470,51 @@ MassSpecTracePlotCompositeWidget::addTrace(
               pappso::MzIntegrationParams *copy_mz_integration_params_p =
                 mz_integration_params_p->clone(nullptr);
 
+              // qDebug() << "Combinining new trace into a graph trace.";
+
               for(int iter = 0; iter < dest_plottable_list.size(); ++iter)
                 {
                   QCPAbstractPlottable *iter_plottable_p =
                     dest_plottable_list.at(iter);
-                  pappso::Trace iter_trace =
+                  pappso::Trace iter_dest_trace =
                     static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
                       ->toTrace(static_cast<QCPGraph *>(iter_plottable_p));
 
                   // Initialize the receiving map trace with the trace we
                   // are iterating into.
-                  pappso::MapTrace map_trace(iter_trace);
+                  pappso::MapTrace map_trace(iter_dest_trace);
 
-                  double smallest_mz_step =
-                    std::min<double>(iter_trace.front().x, trace.front().x);
-                  copy_mz_integration_params_p->setSmallestMz(smallest_mz_step);
+                  // In order to maintain the phasing of bins, we should get the
+                  // first m/z value of the destination trace and use it as an
+                  // anchor point to the creation of the bins.
 
-                  double greatest_mz_step =
-                    std::max<double>(iter_trace.back().x, trace.back().x);
-                  copy_mz_integration_params_p->setGreatestMz(greatest_mz_step);
+                  double src_smallest_mz  = trace.front().x;
+                  double dest_smallest_mz = iter_dest_trace.front().x;
+
+                  copy_mz_integration_params_p->setSmallestMz(src_smallest_mz);
+                  copy_mz_integration_params_p->setLowerAnchorMz(
+                    dest_smallest_mz);
+
+                  double src_greatest_mz  = trace.back().x;
+                  double dest_greatest_mz = iter_dest_trace.back().x;
+
+                  copy_mz_integration_params_p->setGreatestMz(src_greatest_mz);
+                  copy_mz_integration_params_p->setUpperAnchorMz(
+                    dest_greatest_mz);
+
+                  // qDebug()
+                  //   << "At this point, the mz integration params:"
+                  //   << copy_mz_integration_params_p->toString(0, " ");
 
                   // At this point we can ask the bins to be computed.
                   std::vector<double> bins =
                     copy_mz_integration_params_p->createBins();
 
+                  // qDebug() << "Prepared bins with " << bins.size() <<
+                  // "elements."
+                  // << "starting with mz" << bins.front() << "ending with mz"
+                  // << bins.back();
+
                   // Now set the bins to the combiner.
 
                   if(m_newTraceHandlingMethod ==
@@ -1496,21 +1523,6 @@ MassSpecTracePlotCompositeWidget::addTrace(
                       // qDebug() <<
                       // "NewTraceHandlingMethod::MINUS_COMBINE";
                       mass_spectrum_minus_combiner.setBins(bins);
-                    }
-                  else if(m_newTraceHandlingMethod ==
-                          NewTraceHandlingMethod::PLUS_COMBINE)
-                    {
-                      // qDebug() <<
-                      // "NewTraceHandlingMethod::PLUS_COMBINE";
-                      mass_spectrum_plus_combiner.setBins(bins);
-                    }
-
-                  // At this point we can perform the combination.
-                  if(m_newTraceHandlingMethod ==
-                     NewTraceHandlingMethod::MINUS_COMBINE)
-                    {
-                      // qDebug() <<
-                      // "NewTraceHandlingMethod::MINUS_COMBINE";
                       mass_spectrum_minus_combiner.combine(map_trace, trace);
                     }
                   else if(m_newTraceHandlingMethod ==
@@ -1518,9 +1530,11 @@ MassSpecTracePlotCompositeWidget::addTrace(
                     {
                       // qDebug() <<
                       // "NewTraceHandlingMethod::PLUS_COMBINE";
+                      mass_spectrum_plus_combiner.setBins(bins);
                       mass_spectrum_plus_combiner.combine(map_trace, trace);
                     }
 
+
                   // Since the combination is terminated, set the new data
                   // to the graph (the data are sorted, thus the true
                   // below).
@@ -1566,11 +1580,164 @@ MassSpecTracePlotCompositeWidget::addTrace(
                   static_cast<QCPGraph *>(iter_plottable_p)
                     ->setData(key_vector, value_vector, true);
                 }
+              // End of
+              // for(int iter = 0; iter < dest_plottable_list.size(); ++iter)
 
               // Note how we do not change neither the sample name text nor its
               // color. He we just increment/decrement a trace. We do not set a
               // new trace.
             }
+          else if(mz_integration_params_p->getBinningType() ==
+                  pappso::MzIntegrationParams::BinningType::DATA_BASED)
+            {
+              // The existing trace should serve as a data template to construct
+              // bins for our new trace to be combined to the existing one.
+
+              qDebug() << "Binning type data-based.";
+
+              pappso::MassSpectrumMinusCombiner mass_spectrum_minus_combiner;
+              pappso::MassSpectrumPlusCombiner mass_spectrum_plus_combiner;
+
+              // There is a requirement to perform a binning. We thus need
+              // to create the bins. The smallest mz step needs to be the
+              // smallest of the trace we get as a parameter and of the
+              // trace we got for the receiving graph.
+
+              // We'll need the mz integration parameters from the
+              // processing flow we  get as parameters. Make a copy of
+              // them as we'll need to set the mz smallest and greatest
+              // values to them.
+
+              pappso::MzIntegrationParams *copy_mz_integration_params_p =
+                mz_integration_params_p->clone(nullptr);
+
+              // qDebug() << "Combinining new trace into a graph trace.";
+
+              for(int iter = 0; iter < dest_plottable_list.size(); ++iter)
+                {
+                  QCPAbstractPlottable *iter_plottable_p =
+                    dest_plottable_list.at(iter);
+                  pappso::Trace iter_dest_trace =
+                    static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
+                      ->toTrace(static_cast<QCPGraph *>(iter_plottable_p));
+
+                  // Initialize the receiving map trace with the trace we
+                  // are iterating into.
+                  pappso::MapTrace map_trace(iter_dest_trace);
+
+                  // In order to maintain the phasing of bins, we should get the
+                  // first m/z value of the destination trace and use it as an
+                  // anchor point to the creation of the bins.
+
+                  double src_smallest_mz = trace.front().x;
+                  copy_mz_integration_params_p->setSmallestMz(src_smallest_mz);
+
+                  double src_greatest_mz = trace.back().x;
+                  copy_mz_integration_params_p->setGreatestMz(src_greatest_mz);
+
+                  qDebug() << qSetRealNumberPrecision(6)
+                           << "The source plot trace has left m/z:"
+                           << src_smallest_mz
+                           << "and right m/z:" << src_greatest_mz;
+
+                  pappso::MassSpectrumCstSPtr dest_mass_spectrum_csp =
+                    std::make_shared<const pappso::MassSpectrum>(
+                      iter_dest_trace);
+
+                  qDebug() << qSetRealNumberPrecision(6)
+                           << "The destination plot trace has left m/z:"
+                           << dest_mass_spectrum_csp->minX() << "and right m/z:"
+                           << dest_mass_spectrum_csp->maxX();
+
+                  // qDebug()
+                  //   << "At this point, the mz integration params:"
+                  //   << copy_mz_integration_params_p->toString(0, " ");
+
+                  // At this point we can ask the bins to be computed.
+                  // These bins should be phased with the bins in
+                  // iter_dest_trace.
+                  std::vector<double> bins =
+                    copy_mz_integration_params_p->createBins(
+                      dest_mass_spectrum_csp);
+
+                  // qDebug() << "Prepared bins with " << bins.size() <<
+                  // "elements."
+                  // << "starting with mz" << bins.front() << "ending with mz"
+                  // << bins.back();
+
+                  // Now set the bins to the combiner.
+
+                  if(m_newTraceHandlingMethod ==
+                     NewTraceHandlingMethod::MINUS_COMBINE)
+                    {
+                      // qDebug() <<
+                      // "NewTraceHandlingMethod::MINUS_COMBINE";
+                      mass_spectrum_minus_combiner.setBins(bins);
+                      mass_spectrum_minus_combiner.combine(map_trace, trace);
+                    }
+                  else if(m_newTraceHandlingMethod ==
+                          NewTraceHandlingMethod::PLUS_COMBINE)
+                    {
+                      // qDebug() <<
+                      // "NewTraceHandlingMethod::PLUS_COMBINE";
+                      mass_spectrum_plus_combiner.setBins(bins);
+                      mass_spectrum_plus_combiner.combine(map_trace, trace);
+                    }
+
+
+                  // Since the combination is terminated, set the new data
+                  // to the graph (the data are sorted, thus the true
+                  // below).
+
+                  // Old version that was deprecated in 5.14.2
+                  //
+                  // static_cast<QCPGraph *>(iter_plottable_p)
+                  //->setData(
+                  // QVector<double>::fromStdVector(map_trace.firstToVector()),
+                  // QVector<double>::fromStdVector(
+                  // map_trace.secondToVector()),
+                  // true);
+
+                  QVector<double> key_vector;
+                  QVector<double> value_vector;
+
+                  // Apparently, as of 20210928, that bug is fixed.
+                  // #pragma GCC warning "Filippo Rusconi: Please check if
+                  // the
+                  // bug was fixed in Qt"
+
+                  // Now replace the graph's data. Note that the data are
+                  // inherently sorted (true below).
+
+                  // The begin() -- end() ranges constructor did not work
+                  // as of Qt 5.14.2 this day: 20200721 -- and still does
+                  // not work 20211018.
+
+
+                  // key_vector   = QVector(map_trace.xValues().begin(),
+                  // map_trace.xValues().end());
+                  // value_vector = QVector(map_trace.yValues().begin(),
+                  // map_trace.yValues().end());
+
+                  // This is the workaround fix.
+
+                  for(auto &value : map_trace.xValues())
+                    key_vector.push_back(value);
+
+                  for(auto &value : map_trace.yValues())
+                    value_vector.push_back(value);
+
+                  static_cast<QCPGraph *>(iter_plottable_p)
+                    ->setData(key_vector, value_vector, true);
+                }
+              // End of
+              // for(int iter = 0; iter < dest_plottable_list.size(); ++iter)
+            }
+          else
+            {
+              qFatal()
+                << "Programming error. This line should never be reached.";
+            }
         }
       // End of
       // else of if(!graph_count), that if there are graphs in the plot
@@ -1679,7 +1846,10 @@ QString
 MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
   const pappso::MassSpecTracePlotContext &context)
 {
-  // qDebug();
+  // qDebug().noquote() << "With context:" << context.toString();
+  // qDebug().noquote()
+  //   << "We get from the base class stanza work the following text:"
+  //   << m_analysisStanza;
 
   QCPAbstractPlottable *plottable_p = plottableToBeUsedAsIntegrationSource();
 
@@ -1705,226 +1875,148 @@ MassSpecTracePlotCompositeWidget::craftAnalysisStanza(
       return QString();
     }
 
+  // qDebug() << "Plottable:" << plottable_p;
+
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     getCstProcessingFlowPtrForPlottable(plottable_p)->getMsRunDataSetCstSPtr();
 
-  QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
+  // We do only handle here the specialty format elements: %z and %M.
+  // Note that %M is a double value that may accept a precision format string
+  // like this:
+  // %M.3 to indicate that the molecular mass should be printed out with three
+  // decimals.
 
-  // Craft the analysis stanza by copying the m_analysisStanza that was
-  // partially filled-in by the base classes and go on filling-in fields
-  // still marked with "%<char>" format patterns.
+  // The m_analysisStanza member has been filled-in by the base class and
+  // the specialty format strings %z and %M have been let untouched, so we can
+  // now work on them.
+
+  // So, in fact, the m_analysisStanza behaves like a format string itself.
+
+  QString formatString = m_analysisStanza;
+
+  static const QRegularExpression re("%([zM])(\\.(\\d+))?");
+
+  // Not all the format specifications are for number, specify which are
+  static const QSet<QChar> floatKeys   = {'M'};
+  static const QSet<QChar> integerKeys = {'z'};
+  static const QSet<QChar> stringKeys  = {};
+
+  QHash<QChar, QVariant> replacements;
+
+  /////////////////// THE z charge value //////////////////////
+
+  if(!qIsNaN(context.m_lastMz))
+    replacements['M'] = context.m_lastMr;
+
+  if(context.m_lastZ != std::numeric_limits<quint16>::max())
+    replacements['z'] = context.m_lastZ;
 
-  QString orig_stanza = m_analysisStanza;
   QString stanza;
+  stanza.reserve(formatString.size());
 
-  QChar prevChar = ' ';
+  int lastIndex = 0;
+  auto it       = re.globalMatch(formatString);
 
-  for(int iter = 0; iter < orig_stanza.size(); ++iter)
+  while(it.hasNext())
     {
-      QChar curChar = orig_stanza.at(iter);
+      QRegularExpressionMatch m = it.next();
 
-      // qDebug() << "Current char:" << curChar;
+      int start = m.capturedStart();
+      int end   = m.capturedEnd();
 
-      if(curChar == '\\')
+      // Copy text up to this match
+      stanza += formatString.mid(lastIndex, start - lastIndex);
+
+      const QChar key = m.captured(1)[0];
+
+      qDebug() << "Captured key: " << key;
+
+      const QString precision_spec_string = m.captured(3); // just the digits
+      bool ok                             = false;
+      int precision_spec                  = precision_spec_string.toInt(&ok);
+
+      if(!ok)
+        precision_spec = 0;
+
+      if(!replacements.contains(key))
         {
-          if(prevChar == '\\')
-            {
-              stanza   += '\\';
-              prevChar  = ' ';
-              continue;
-            }
-          else
-            {
-              prevChar = '\\';
-              continue;
-            }
-        }
+          QString untouched = m.captured(0);
 
-      if(curChar == '%')
-        {
-          if(prevChar == '\\')
-            {
-              stanza   += '%';
-              prevChar  = ' ';
-              continue;
-            }
-          else
-            {
-              prevChar = '%';
-              continue;
-            }
-        }
-
-      if(curChar == 'n')
-        {
-          if(prevChar == '\\')
-            {
-              stanza += QString("\n");
-
-              // Because a newline only works if it is followed by
-              // something, and if the user wants a termination newline,
-              // then we need to duplicate that new line char if we are at
-              // the end of the string.
-
-              if(iter == orig_stanza.size() - 1)
-                {
-                  // This is the last character of the line, then,
-                  // duplicate the newline so that it actually creates a
-                  // new line in the text.
-
-                  stanza += QString("\n");
-                }
-
-              prevChar = ' ';
-              continue;
-            }
-        }
-
-      if(prevChar == '%')
-        {
-          // The current character might have a specific signification.
-          if(curChar == 'f')
-            {
-              QFileInfo fileInfo(sample_name);
-              if(fileInfo.exists())
-                stanza += fileInfo.fileName();
-              else
-                stanza += "Untitled";
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 's')
-            {
-
-              QFileInfo fileInfo(sample_name);
-              if(fileInfo.exists())
-                stanza += fileInfo.fileName();
-              else
-                stanza += "Untitled";
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'X')
-            {
-              // If the deconvolution was successful, then lastMz is the
-              // right value. Otherwise it is the lastCursorHoveredPoint.
-
-              if(context.m_lastMz != std::numeric_limits<double>::min())
-                {
-                  stanza += QString("%1").arg(context.m_lastMz, 0, 'g', 6);
-                }
-              else
-                {
-                  stanza += QString("%1").arg(
-                    context.m_lastCursorHoveredPoint.x(), 0, 'g', 6);
-                }
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'Y')
-            {
-              // We need to get the value of the intensity for the graph,
-              // but not as an integration to INT, but simply as the y
-              // coordinate of the point at X *on the curve*.
-
-              double x_value = 0;
-
-              if(context.m_lastMz != std::numeric_limits<double>::min())
-                x_value = context.m_lastMz;
-              else
-                x_value = context.m_lastCursorHoveredPoint.x();
-
-              stanza += QString("%1").arg(
-                static_cast<pappso::MassSpecTracePlotWidget *>(mp_plotWidget)
-                  ->getYatX(x_value, dynamic_cast<QCPGraph *>(plottable_p)),
-                0,
-                'g',
-                6);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'x')
-            {
-              stanza   += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
-              prevChar  = ' ';
-              continue;
-            }
-          if(curChar == 'y')
-            {
-              stanza += "this is the mass spec count delta y";
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'z')
-            {
-              if(context.m_lastZ >= 1)
-                {
-                  stanza += QString("%1").arg(context.m_lastZ);
-
-                  prevChar = ' ';
-                }
-              continue;
-            }
-          if(curChar == 'M')
-            {
-              if(context.m_lastMr != std::numeric_limits<double>::min())
-                {
-                  stanza += QString("%1").arg(context.m_lastMr, 0, 'f', 6);
-
-                  prevChar = ' ';
-                }
-              continue;
-            }
-          if(curChar == 'I')
-            {
-              stanza += QString("%1").arg(m_lastTicIntensity, 0, 'g', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'b')
-            {
-              stanza +=
-                QString("%1").arg(context.m_xRegionRangeStart, 0, 'f', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'e')
-            {
-              stanza += QString("%1").arg(context.m_xRegionRangeEnd, 0, 'f', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          // At this point the '%' is not followed by any special
-          // character above, so we skip them both from the text. If the
-          // '%' is to be printed, then it needs to be escaped. We do this
-          // because we do not expect that derived classes will do the
-          // format-based field-filling work later.
+          qDebug() << "Adding new untouched string element:" << untouched;
 
+          stanza    += untouched;
+          lastIndex  = end;
           continue;
         }
-      // End of
-      // if(prevChar == '%')
 
-      // The character prior this current one was not '%' so we just
-      // append the current character.
-      stanza += curChar;
+      const QVariant &v = replacements[key];
+
+      if(floatKeys.contains(key))
+        {
+          // ---- FLOAT TOKENS ----
+          double d = 0.0;
+
+          if(v.canConvert<double>())
+            d = v.toDouble(); // integer or float → OK
+          else
+            {
+              stanza    += "<NaN>"; // or keep literal, your choice
+              lastIndex  = end;
+              continue;
+            }
+
+          stanza += QString::number(d, 'f', precision_spec);
+        }
+      else if(integerKeys.contains(key))
+        {
+          // ---- INTEGER TOKENS ----
+          qlonglong i = 0;
+
+          // INTEGER tokens should accept:
+          // int, uint, qint64, quint64        (ideal case)
+          // double or float                    (we can convert by
+          // truncation) string with digits                 (allowed at your
+          // discretion)
+
+          if(v.canConvert<qlonglong>())
+            i = v.toLongLong();
+          else
+            {
+              stanza    += "<NaI>"; // Not-an-Integer marker (or use literal)
+              lastIndex  = end;
+              continue;
+            }
+
+          stanza += QString::number(i);
+        }
+
+      else if(stringKeys.contains(key))
+        {
+          // ---- STRING TOKENS ----
+          if(v.canConvert<QString>())
+            stanza += v.toString();
+          else
+            stanza += "<NaS>"; // Not-a-String
+        }
+
+      lastIndex = end;
     }
-  // End of
-  // for (int iter = 0; iter < pattern.size(); ++iter)
 
-  // Finally copy the result into the member datum.
+  // trailing literal data
+  stanza += formatString.mid(lastIndex);
+
+  // Finally, set the stanza to the member datum and return it.
+  // We want to keep it as a member datum, because derived classes
+  // can build upon it with specialized data elements.
   m_analysisStanza = stanza;
 
-  // qDebug() << "Returning analysis stanza:"  << m_analysisStanza;
+  // qDebug() << "Returning m_analysisStanza:" << m_analysisStanza;
 
-  return stanza;
+  // Note that each time a stanza has been crafted, we need to reset the tic
+  // intensity value to 0 so that we do not craft two stanzas with the same
+  // value if no single intensity calculation was performed between them.
+
+  return m_analysisStanza;
 }
 
 void
