@@ -50,13 +50,12 @@
 /////////////////////// Local includes
 #include "BaseTracePlotCompositeWidget.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
 {
 
-class MassSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
+class MassSpecTracePlotCompositeWidget: public BaseTracePlotCompositeWidget
 {
   Q_OBJECT
 
@@ -96,8 +95,6 @@ class MassSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
 
   void gaussianFitOnVisibleMaxima();
 
-  void mainMenuPushButtonClicked();
-
   virtual QCPGraph *addTrace(const pappso::Trace &trace,
                              QCPAbstractPlottable *parent_plottable_p,
                              MsRunDataSetCstSPtr ms_run_data_set_csp,
@@ -111,7 +108,7 @@ class MassSpecTracePlotCompositeWidget : public BaseTracePlotCompositeWidget
   signals:
 
   protected:
-  virtual void createMainMenu() override;
+   void createMainMenu() ;
 
   QString craftAnalysisStanza(const pappso::MassSpecTracePlotContext &context);
 
