@@ -88,7 +88,7 @@ MassSpecTracePlotWnd::extendMainMenu()
   // Extend the tool bar menu with some mass spec-specific submenus.
 
   if(mp_mainMenu == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // The toolbar menu button
 
@@ -98,13 +98,13 @@ MassSpecTracePlotWnd::extendMainMenu()
   mp_deconvolutionsMenu = new QMenu("Deconvolutions");
 
   if(mp_beforePlotWidgetManagementSeparatorAction == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   QAction *menu_action_p = mp_mainMenu->insertMenu(
     mp_beforePlotWidgetManagementSeparatorAction, mp_deconvolutionsMenu);
 
   if(menu_action_p == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
 
   QAction *mp_setMinimalChargeFractionalPartAction = new QAction(
@@ -188,8 +188,41 @@ MassSpecTracePlotWnd::addTracePlot(
   MassSpecTracePlotCompositeWidget *composite_widget_p =
     new MassSpecTracePlotCompositeWidget(this, "m/z", "counts (a.u.)");
 
-  return finalNewTracePlotConfiguration(
+  QCPGraph *new_graph_p = finalNewTracePlotConfiguration(
     composite_widget_p, trace, processing_flow, color, parent_plottable_p);
+
+  // Make sure we do create a new JS item for both the plot widget and the
+  // graph.
+
+  QJSValue returned_js_value;
+
+  getProgramWindow()
+    ->getScriptingWnd()
+    ->getScriptingEnvironment()
+    ->exposeQObject("plotWidget" /*name*/,
+                    QString() /*alias*/,
+                    "The newly created MassSpecTracePlot widget.\n",
+                    dynamic_cast<QObject *>(composite_widget_p),
+                    dynamic_cast<QObject *>(this),
+                    returned_js_value,
+                    QJSEngine::CppOwnership);
+
+  QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
+
+  // qDebug() << "The color:" << color;
+
+  getProgramWindow()
+    ->getScriptingWnd()
+    ->getScriptingEnvironment()
+    ->exposeQObject("plotGraph" /*name*/,
+                    sample_name /*alias*/,
+                    "The newly created MassSpecTracePlot graph.",
+                    dynamic_cast<QObject *>(new_graph_p),
+                    dynamic_cast<QObject *>(composite_widget_p),
+                    returned_js_value,
+                    QJSEngine::CppOwnership);
+
+  return new_graph_p;
 }
 
 void
@@ -199,15 +232,15 @@ MassSpecTracePlotWnd::integrateToMz(
     qualified_mass_spectra_sp,
   const ProcessingFlow &processing_flow)
 {
-  qDebug().noquote() << "20250904 - Integrating to mz with processing flow:"
-                     << processing_flow.toString(0, "  ");
+  // qDebug().noquote() << "Integrating to mz with processing flow:"
+  //                    << processing_flow.toString(0, "  ");
 
   // Get the ms run data set for the graph that we are going to base the
   // integration on.
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
@@ -231,9 +264,9 @@ MassSpecTracePlotWnd::integrateToMz(
           "Programming error: the data have a problematic ProcessingFlow.");
     }
 
-  qDebug() << qSetRealNumberPrecision(10)
-           << "20250904 - Innermost RT range:" << range_pair.first << "-"
-           << range_pair.second;
+  // qDebug() << qSetRealNumberPrecision(10)
+  //          << "Innermost RT range:" << range_pair.first << "-"
+  //          << range_pair.second;
 
   // bool integration_dt = processing_flow.innermostRange("ANY_DT", range_pair);
   // if(integration_dt)
@@ -255,8 +288,8 @@ MassSpecTracePlotWnd::integrateToMz(
   // mz integration params to reflect the m/z range to be integrated ?
   // Question question
 
-  qDebug().noquote() << "20250904 - Got sensible m/z integration params:\n"
-                     << mz_integration_params_p->toString(0, "  ");
+  // qDebug().noquote() << "Got sensible m/z integration params:\n"
+  //                    << mz_integration_params_p->toString(0, "  ");
 
   if(mz_integration_params_p == nullptr || !mz_integration_params_p->isValid())
     qFatal(
@@ -271,9 +304,9 @@ MassSpecTracePlotWnd::integrateToMz(
   std::size_t qualified_mass_spectra_count = fillInQualifiedMassSpectraVector(
     ms_run_data_set_csp, qualified_mass_spectra_sp, processing_flow);
 
-  qDebug() << "20250904 - The number of selected mass spectra on the basis of "
-              "rough RT/DT values:"
-           << qualified_mass_spectra_count;
+  // qDebug() << "The number of selected mass spectra on the basis of "
+  //             "rough RT/DT values:"
+  //          << qualified_mass_spectra_count;
 
   if(!qualified_mass_spectra_count)
     return;
@@ -515,7 +548,7 @@ MassSpecTracePlotWnd::integrateToRt(QCPAbstractPlottable *parent_plottable_p,
                                     const ProcessingFlow &processing_flow)
 {
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToRt(parent_plottable_p, nullptr, processing_flow);
 }
@@ -525,7 +558,7 @@ MassSpecTracePlotWnd::integrateToDt(QCPAbstractPlottable *parent_plottable_p,
                                     const ProcessingFlow &processing_flow)
 {
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToDt(parent_plottable_p, nullptr, processing_flow);
 }
@@ -535,7 +568,7 @@ MassSpecTracePlotWnd::integrateToMzRt(QCPAbstractPlottable *plottable_p,
                                       const ProcessingFlow &processing_flow)
 {
   if(plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToMzRt(plottable_p, nullptr, processing_flow);
 }
@@ -545,7 +578,7 @@ MassSpecTracePlotWnd::integrateToDtMz(QCPAbstractPlottable *plottable_p,
                                       const ProcessingFlow &processing_flow)
 {
   if(plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToDtMz(plottable_p, nullptr, processing_flow);
 }
@@ -555,7 +588,7 @@ MassSpecTracePlotWnd::integrateToDtRt(QCPAbstractPlottable *plottable_p,
                                       const ProcessingFlow &processing_flow)
 {
   if(plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToDtRt(plottable_p, nullptr, processing_flow);
 }
@@ -599,7 +632,7 @@ MassSpecTracePlotWnd::handleReceivedData(const QByteArray &byte_array)
     }
 
   pappso::Trace trace = cbor_handler.getTrace();
-  qDebug() << "20250904 - Received trace of size:" << trace.size();
+  // qDebug() << "Received trace of size:" << trace.size();
 
   QString title               = cbor_handler.getTitle();
   QByteArray color_byte_array = cbor_handler.getTraceColor();
@@ -620,8 +653,8 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 
   // Create a new ms run data set piece by piece.
 
-  qDebug() << "20250904 -  Handling received data, create a ms run data set "
-              "piecemeal.";
+  // qDebug() << " Handling received data, create a ms run data set "
+  //             "piecemeal.";
 
   pappso::MsRunIdSPtr ms_run_id_sp = std::make_shared<pappso::MsRunId>();
   ms_run_id_sp->setSampleName(title);
@@ -638,20 +671,21 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 
   // Now create the mass spectrum with the trace.
 
-  qDebug() << "20250904 - The trace's first point:"
-           << trace_sp->minXDataPoint().x;
-  qDebug() << "20250904 - The trace's last point:"
-           << trace_sp->maxXDataPoint().x;
+  qDebug() << "The trace's first point:" << trace_sp->minXDataPoint().x;
+  qDebug() << "The trace's last point:" << trace_sp->maxXDataPoint().x;
 
   pappso::MassSpectrumSPtr mass_spectrum_sp =
     std::make_shared<pappso::MassSpectrum>(*trace_sp);
 
-  qDebug().noquote()
-    << "20250904 - Before computing statistics for ms run data set:"
-    << ms_run_data_set_sp->getMsRunDataSetStats().toString();
+  // qDebug().noquote()
+  //   << "Before computing statistics for ms run data set:"
+  //   << ms_run_data_set_sp->getMsRunDataSetStats().toString();
+
   ms_run_data_set_sp->incrementStatistics(mass_spectrum_sp);
-  qDebug().noquote() << "20250904 - After:"
-                     << ms_run_data_set_sp->getMsRunDataSetStats().toString();
+
+  // qDebug().noquote() << "After:"
+  //                    <<
+  //                    ms_run_data_set_sp->getMsRunDataSetStats().toString();
 
   // Now create the qualified mass spectrum that we'll add to the ms run data
   // set.
@@ -667,8 +701,8 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
 
   ms_run_data_set_sp->mapMassSpectrum(qualified_mass_spectrum_sp);
 
-  qDebug().noquote() << "20250904 - Mapped the mass spectrum to the data set:"
-                     << qualified_mass_spectrum_sp->toString();
+  // qDebug().noquote() << "Mapped the mass spectrum to the data set:"
+  //                    << qualified_mass_spectrum_sp->toString();
 
   // We will need the MzIntegrationParams and we set them specifically
   // for this MsRunDataSet:
@@ -676,6 +710,9 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   pappso::MzIntegrationParams *ms_run_data_set_mz_integration_params_p =
     ms_run_data_set_sp->craftMzIntegrationParams();
 
+  // qDebug().noquote() << "The MzIntegrationParams from the data set:"
+  //                    << ms_run_data_set_mz_integration_params_p->toString();
+
   // Create a temporary ProcessingFlow with nullptr parent because we'll
   // pass it to downstream code as a reference. That will be used to allocate
   // a new instance with proper parentship. We'll delete the temporary
@@ -701,9 +738,9 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   // rt_point with a width of 1 on the horizontal axis).
   pappso::IntegrationScopeBaseCstSPtr integration_scope_csp =
     std::make_shared<pappso::IntegrationScope>(rt_point, width);
-  qDebug() << "Created integration scope. Is it 1D ?:"
-           << integration_scope_csp->is1D()
-           << "is it 2D ?:" << integration_scope_csp->is2D();
+  // qDebug() << "Created integration scope. Is it 1D ?:"
+  //          << integration_scope_csp->is1D()
+  //          << "is it 2D ?:" << integration_scope_csp->is2D();
   // Finally, set the IntegrationScope to the step.
   new_step_sp->setIntegrationScope(integration_scope_csp);
   // Should perform automatically the conversion from non-const to const.
@@ -721,9 +758,9 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   // mz_point with a width of m/z full range on the horizontal axis).
   integration_scope_csp =
     std::make_shared<pappso::IntegrationScope>(mz_point, width);
-  qDebug() << "Created integration scope. Is it 1D ?:"
-           << integration_scope_csp->is1D()
-           << "is it 2D ?:" << integration_scope_csp->is2D();
+  // qDebug() << "Created integration scope. Is it 1D ?:"
+  //          << integration_scope_csp->is1D()
+  //          << "is it 2D ?:" << integration_scope_csp->is2D();
   // Finally, set the IntegrationScope to the step.
   new_step_sp->setIntegrationScope(integration_scope_csp);
   new_step_sp->setMzIntegrationParams(*ms_run_data_set_mz_integration_params_p);
@@ -771,15 +808,15 @@ MassSpecTracePlotWnd::handleReceivedData(const QString &title,
   // We have used that object twice, we do not need it anymore.
   delete ms_run_data_set_mz_integration_params_p;
 
-#ifndef NDEBUG
+  // #ifndef NDEBUG
   ms_run_data_set_mz_integration_params_p =
     temp_processing_flow_p->getDefaultMzIntegrationParams();
   // We have set them above, they must be found!
   Q_ASSERT(ms_run_data_set_mz_integration_params_p);
-  qDebug().noquote()
-    << "The mz integration params set to the processing flow:\n"
-    << ms_run_data_set_mz_integration_params_p->toString(0, "  ");
-#endif
+  // qDebug().noquote()
+  //   << "The mz integration params set to the processing flow:\n"
+  //   << ms_run_data_set_mz_integration_params_p->toString(0, "  ");
+  // #endif
 
 
   // Let's see the usage count of the MsRunDataSetCstSPtr.
