@@ -65,12 +65,11 @@ MsFragmentationSpecDlg::MsFragmentationSpecDlg(QWidget *parent)
   : QDialog(parent), m_ui(new ::Ui::MsFragmentationSpecDlg)
 {
   if(parent == Q_NULLPTR)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   m_ui->setupUi(this);
 }
 
-
 MsFragmentationSpecDlg::MsFragmentationSpecDlg(
   QWidget *parent,
   const MsFragmentationSpec &ms_fragmentation_spec,
@@ -80,7 +79,7 @@ MsFragmentationSpecDlg::MsFragmentationSpecDlg(
     m_color(color)
 {
   if(parent == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug().noquote() << "The ms fragmentation spec at dialog construction:"
   //<< m_msFragmentationSpec.toString();
@@ -90,14 +89,12 @@ MsFragmentationSpecDlg::MsFragmentationSpecDlg(
   setupWidget();
 }
 
-
 //! Destruct \c this MsFragmentationSpecDlg instance.
 MsFragmentationSpecDlg::~MsFragmentationSpecDlg()
 {
   writeSettings();
 }
 
-
 //! Handle the close event.
 void
 MsFragmentationSpecDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
@@ -107,7 +104,6 @@ MsFragmentationSpecDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
   emit msFragmentationSpecDlgShouldBeDestroyedSignal();
 }
 
-
 //! Write the settings to as to restore the window geometry later.
 void
 MsFragmentationSpecDlg::writeSettings()
@@ -122,7 +118,6 @@ MsFragmentationSpecDlg::writeSettings()
   settings.endGroup();
 }
 
-
 //! Read the settings to as to restore the window geometry.
 void
 MsFragmentationSpecDlg::readSettings()
@@ -137,7 +132,6 @@ MsFragmentationSpecDlg::readSettings()
   settings.endGroup();
 }
 
-
 void
 MsFragmentationSpecDlg::setupWidget()
 {
@@ -187,10 +181,11 @@ MsFragmentationSpecDlg::setupWidget()
   mp_precisionWidget->setToolTip(
     "Set the tolerance with which the m/z value match is performed.");
 
-  connect(
-    mp_precisionWidget,
-    &pappso::PrecisionWidget::precisionChanged,
-    [this](pappso::PrecisionPtr precision_p) { mp_precision = precision_p; });
+  connect(mp_precisionWidget,
+          &pappso::PrecisionWidget::precisionChanged,
+          [this](pappso::PrecisionPtr precision_p) {
+            mp_precision = precision_p;
+          });
 
   // When the user clicks Apply, the member specification is updated with the
   // data from the widgets.
@@ -212,14 +207,12 @@ MsFragmentationSpecDlg::setupWidget()
   readSettings();
 }
 
-
 QString
 MsFragmentationSpecDlg::toString() const
 {
   return m_msFragmentationSpec.toString();
 }
 
-
 void
 MsFragmentationSpecDlg::keyPressEvent(QKeyEvent *event)
 {
@@ -232,7 +225,6 @@ MsFragmentationSpecDlg::keyPressEvent(QKeyEvent *event)
     }
 }
 
-
 void
 MsFragmentationSpecDlg::show()
 {
@@ -241,7 +233,6 @@ MsFragmentationSpecDlg::show()
   QDialog::show();
 }
 
-
 void
 MsFragmentationSpecDlg::clearAllPushButtonClicked(void)
 {
@@ -250,7 +241,6 @@ MsFragmentationSpecDlg::clearAllPushButtonClicked(void)
   m_ui->precursorSpectrumIndexPlainTextEdit->setPlainText("");
 }
 
-
 bool
 MsFragmentationSpecDlg::validateInputData()
 {
@@ -299,8 +289,9 @@ MsFragmentationSpecDlg::validateInputData()
             "Please check the precursors list: error(s) encountered");
 
           // Leave the status message for 2 seconds and then erase it.
-          QTimer::singleShot(2000,
-                             [this]() { m_ui->statusLineEdit->setText(""); });
+          QTimer::singleShot(2000, [this]() {
+            m_ui->statusLineEdit->setText("");
+          });
 
           return false;
         }
@@ -348,8 +339,9 @@ MsFragmentationSpecDlg::validateInputData()
             "encountered");
 
           // Leave the status message for 2 seconds and then erase it.
-          QTimer::singleShot(2000,
-                             [this]() { m_ui->statusLineEdit->setText(""); });
+          QTimer::singleShot(2000, [this]() {
+            m_ui->statusLineEdit->setText("");
+          });
 
           return false;
         }
@@ -383,7 +375,6 @@ MsFragmentationSpecDlg::validateInputData()
   return true;
 }
 
-
 bool
 MsFragmentationSpecDlg::applyPushButtonClicked()
 {
@@ -396,7 +387,9 @@ MsFragmentationSpecDlg::applyPushButtonClicked()
   m_ui->statusLineEdit->setText("Validation successful.");
 
   // Leave the status message for 2 seconds and then erase it.
-  QTimer::singleShot(2000, [this]() { m_ui->statusLineEdit->setText(""); });
+  QTimer::singleShot(2000, [this]() {
+    m_ui->statusLineEdit->setText("");
+  });
 
   // qDebug().noquote() << "The newly set parameters:" << toString();
 
