@@ -48,7 +48,6 @@
 #include "MsRunDataSetTableViewItem.hpp"
 #include "../nongui/ProcessingStep.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -84,12 +83,10 @@ MsRunDataSetTableViewProxyModel::MsRunDataSetTableViewProxyModel(
     std::numeric_limits<std::size_t>::min());
 }
 
-
 MsRunDataSetTableViewProxyModel::~MsRunDataSetTableViewProxyModel()
 {
 }
 
-
 std::pair<size_t, size_t>
 MsRunDataSetTableViewProxyModel::parseSizeTString(const QString &text,
                                                   size_t accepted_lower_value)
@@ -457,7 +454,6 @@ MsRunDataSetTableViewProxyModel::parseSizeTString(const QString &text,
     std::numeric_limits<std::size_t>::max());
 }
 
-
 std::pair<double, double>
 MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
                                                    double accepted_lower_value)
@@ -728,7 +724,6 @@ MsRunDataSetTableViewProxyModel::parseDoubleString(const QString &text,
                                    std::numeric_limits<double>::min());
 }
 
-
 bool
 MsRunDataSetTableViewProxyModel::convertFilteringStrings(
   std::size_t ms_level,
@@ -870,7 +865,6 @@ MsRunDataSetTableViewProxyModel::convertFilteringStrings(
   return true;
 }
 
-
 void
 MsRunDataSetTableViewProxyModel::setPrecision(pappso::PrecisionPtr precision_p)
 {
@@ -879,7 +873,6 @@ MsRunDataSetTableViewProxyModel::setPrecision(pappso::PrecisionPtr precision_p)
   mp_precision = precision_p;
 }
 
-
 bool
 MsRunDataSetTableViewProxyModel::isValidFilterPair(
   const std::pair<std::size_t, std::size_t> &pair) const
@@ -887,7 +880,6 @@ MsRunDataSetTableViewProxyModel::isValidFilterPair(
   return (pair.first != std::numeric_limits<std::size_t>::max());
 }
 
-
 bool
 MsRunDataSetTableViewProxyModel::isValidFilterPair(
   const std::pair<double, double> &pair) const
@@ -895,7 +887,6 @@ MsRunDataSetTableViewProxyModel::isValidFilterPair(
   return (pair.first != std::numeric_limits<double>::max());
 }
 
-
 bool
 MsRunDataSetTableViewProxyModel::filterAcceptsRow(
   int source_row, const QModelIndex &source_parent) const
@@ -931,7 +922,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
       std::size_t cell_value = data.toULongLong(&ok);
 
       if(!ok)
-        qFatal("Failed to convert variant to std::size_t.");
+        qFatal() << "Failed to convert variant to std::size_t.";
 
       if(cell_value < m_indicesPair.first || cell_value > m_indicesPair.second)
         return false;
@@ -968,7 +959,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
       std::size_t cell_value = cell_data.toULongLong(&ok);
 
       if(!ok)
-        qFatal("Failed to convert variant to std::size_t.");
+        qFatal() << "Failed to convert variant to std::size_t.";
 
       if(cell_value != m_msLevel)
         return false;
@@ -989,7 +980,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
       double cell_value = data.toDouble(&ok);
 
       if(!ok)
-        qFatal("Failed to convert variant to std::size_t.");
+        qFatal() << "Failed to convert variant to std::size_t.";
 
       if(cell_value < m_rtValuesPair.first ||
          cell_value > m_rtValuesPair.second)
@@ -1011,7 +1002,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
       double cell_value = data.toDouble(&ok);
 
       if(!ok)
-        qFatal("Failed to convert variant to std::size_t.");
+        qFatal() << "Failed to convert variant to std::size_t.";
 
       if(cell_value < m_dtValuesPair.first ||
          cell_value > m_dtValuesPair.second)
@@ -1038,7 +1029,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
           std::size_t cell_value = data.toULongLong(&ok);
 
           if(!ok)
-            qFatal("Failed to convert variant to std::size_t.");
+            qFatal() << "Failed to convert variant to std::size_t.";
 
           if(cell_value < m_precursorIndexPair.first ||
              cell_value > m_precursorIndexPair.second)
@@ -1123,7 +1114,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
                       // We need to account for the precision/tolerance.
 
                       if(mp_precision == nullptr)
-                        qFatal("mp_precision is nullptr.");
+                        qFatal() << "mp_precision is nullptr.";
 
                       double delta_first =
                         mp_precision->delta(m_precursorMzValuesPair.first);
@@ -1206,7 +1197,7 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
                   std::size_t z_value = iter->toULongLong(&ok);
 
                   if(!ok)
-                    qFatal("Failed to convert string to std::size_t");
+                    qFatal() << "Failed to convert string to std::size_t";
 
                   cell_data_z_value_vector.push_back(z_value);
                 }
@@ -1242,7 +1233,6 @@ MsRunDataSetTableViewProxyModel::filterAcceptsRow(
   return should_accept_row;
 }
 
-
 bool
 MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
                                           const QModelIndex &right) const
@@ -1325,11 +1315,11 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
 
       std::size_t left_value = left_value_string.toUInt(&ok);
       if(!ok)
-        qFatal("Failed to convert charge string to std::size_t");
+        qFatal() << "Failed to convert charge string to std::size_t";
 
       std::size_t right_value = right_value_string.toUInt(&ok);
       if(!ok)
-        qFatal("Failed to convert charge string to std::size_t");
+        qFatal() << "Failed to convert charge string to std::size_t";
 
       return left_value < right_value;
     }
@@ -1340,11 +1330,11 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
 
       double left_value = leftData.toDouble(&ok);
       if(!ok)
-        qFatal("Failed to convert RT|DT string to double.");
+        qFatal() << "Failed to convert RT|DT string to double.";
 
       double right_value = rightData.toDouble(&ok);
       if(!ok)
-        qFatal("Failed to convert RT|DT string to double.");
+        qFatal() << "Failed to convert RT|DT string to double.";
 
       // qDebug() << "left_value:" << left_value << "right_value:" <<
       // right_value
@@ -1402,7 +1392,10 @@ MsRunDataSetTableViewProxyModel::lessThan(const QModelIndex &left,
       return left_value < right_value;
     }
   else
-    qFatal("Should never reach this point.");
+    qFatal() << "Should never reach this point.";
+
+  // To avoid warning.
+  return false;
 }
 
 } // namespace MineXpert
