@@ -76,12 +76,12 @@ MsRunDataSetTableViewWnd::MsRunDataSetTableViewWnd(
     m_ui(new ::Ui::MsRunDataSetTableViewWnd)
 {
   if(program_window_p == Q_NULLPTR)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   m_ui->setupUi(dynamic_cast<QMainWindow *>(this));
 
   if(!initialize())
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // Note that we need to set the processing_flow mz integration parameters to
   // the ones found in the file during file load:
@@ -252,72 +252,260 @@ MsRunDataSetTableViewWnd::initialize()
 
   connect(mp_precisionWidget,
           &pappso::PrecisionWidget::precisionChanged,
+          this,
           [this](pappso::PrecisionPtr precision_p) {
             mp_precision = precision_p;
             mp_msRunDataSetTableViewProxyModel->setPrecision(mp_precision);
           });
 
-  connect(m_ui->executeFilteringPushButton, &QPushButton::clicked, [this]() {
+  connect(m_ui->executeFilteringPushButton, &QPushButton::clicked, this, [&]() {
     executeFilteringPushButtonClicked();
   });
 
-  connect(m_ui->integrateToDtPushButton, &QPushButton::clicked, [this]() {
+  ////////////////////// THE INTEGRATION BUTTONS ////////////////////////
+  ////////
+
+  // We will perform the connection between QAction instances and the buttons
+  // arranged below the table widget. The QAction might exist already in the
+  // form of an ActionId associated to a shortcut. This is handled by the
+  // ActionManager (installAction()).
+
+  // Since a given action might have been set at different places in the
+  // program, when doing the connection to a given button, in the lambda, we
+  // ensure that the current window is effectively active. Otherwise, when the
+  // QAction triggers, the connected lamba code goes off in all the connected
+  // places!
+
+  // The code below was used to check the working of the ActionID/QAction-based
+  // strategy used here. Indeed, I only understood that later tha the QAction
+  // needs to be added to the button for the trigger to actually work.
+  // The shortcut strategy below works even without adding anything.
+
+#if 0
+  // This works by itself. I tested this because at first the QAction-based
+  // code above did not work until I actually added the action to the button.
+  QShortcut *directShortcut = new QShortcut(QKeySequence("Ctrl+I, M"), this);
+  connect(directShortcut, &QShortcut::activated, this, [&]() {
+    qDebug() << "Direct shortcut activated!";
+    m_ui->integrateToMzPushButton->click();
+  });
+#endif
+
+
+  //////////// The variables we will need to perform each button configuration
+  ProgramWindow *program_window_p =
+    static_cast<Application *>(qApp)->getProgramWindow();
+  QKeySequence key_sequence;
+  QString action_label;
+  libXpertMassGui::ActionId action_id;
+  QAction *action_p = nullptr;
+
+  /////////// Integrate to DT
+  ///
+  // First the button.
+  connect(m_ui->integrateToDtPushButton, &QPushButton::clicked, this, [this]() {
     integrate("TO_DT");
   });
+  // And now the action represented by a shortcut.
+  action_label = "Integrate to an ion mobility spectrum";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, D"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToDtPushButton->addAction(action_p);
+  m_ui->integrateToDtPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger" << static_cast<QAction *>(QObject::sender())->text();
+    // This action is set to may different buttons all over the windows,
+    // we do not want that the action be triggered for any other window than
+    // this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToDtPushButton->click();
+  });
 
-  connect(m_ui->integrateToMzPushButton, &QPushButton::clicked, [this]() {
+  /////////// Integrate to MZ
+  ///
+  // First the button.
+  connect(m_ui->integrateToMzPushButton, &QPushButton::clicked, this, [&]() {
     integrate("TO_MZ");
   });
+  // And now the action represented by a shortcut.
+  action_label = "Integrate to a mass spectrum";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, M"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToMzPushButton->addAction(action_p);
+  m_ui->integrateToMzPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger" << static_cast<QAction *>(QObject::sender())->text();
+    // This action is set to may different buttons all over the windows,
+    // we do not want that the action be triggered for any other window than
+    // this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToMzPushButton->click();
+  });
 
-  connect(m_ui->integrateToRtPushButton, &QPushButton::clicked, [this]() {
+  /////////// Integrate to RT
+  ///
+  // First the button.
+  connect(m_ui->integrateToRtPushButton, &QPushButton::clicked, this, [&]() {
     integrate("TO_RT");
   });
+  // And now the action represented by a shortcut.
+  action_label = "Integrate to a TIC/XIC chromatogram";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, R"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToRtPushButton->addAction(action_p);
+  m_ui->integrateToRtPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger" << static_cast<QAction *>(QObject::sender())->text();
+    // This action is set to may different buttons all over the windows,
+    // we do not want that the action be triggered for any other window than
+    // this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToRtPushButton->click();
+  });
 
-  connect(m_ui->integrateToIntPushButton, &QPushButton::clicked, [this]() {
+  /////////// Integrate to INT
+  ///
+  // First the button.
+  connect(m_ui->integrateToIntPushButton, &QPushButton::clicked, this, [&]() {
     integrate("TO_INT");
   });
+  // And now the action represented by a shortcut.
+  action_label = "Integrate to a TIC intensity value";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, I"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToIntPushButton->addAction(action_p);
+  m_ui->integrateToIntPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger" << static_cast<QAction *>(QObject::sender())->text();
+    // This action is set to may different buttons all over the windows,
+    // we do not want that the action be triggered for any other window than
+    // this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToIntPushButton->click();
+  });
 
-  connect(m_ui->integrateToDtMzPushButton, &QPushButton::clicked, [this]() {
+  /////////// Integrate to TO_DT_MZ
+  ///
+  // First the button.
+  connect(m_ui->integrateToDtMzPushButton, &QPushButton::clicked, this, [&]() {
     integrate("TO_DT_MZ");
   });
-
-  connect(m_ui->integrateToDtRtPushButton, &QPushButton::clicked, [this]() {
-    integrate("TO_DT_RT");
+  // And now the action represented by a shortcut.
+  action_label = "Integrate to an ion mobility / mass spectrum color map";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, Ctrl+D"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToDtMzPushButton->addAction(action_p);
+  m_ui->integrateToDtMzPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger" << static_cast<QAction *>(QObject::sender())->text();
+    // This action is set to may different buttons all over the windows,
+    // we do not want that the action be triggered for any other window than
+    // this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToDtMzPushButton->click();
   });
 
-  connect(m_ui->integrateToMzRtPushButton, &QPushButton::clicked, [this]() {
+  /////////// Integrate to TO_DT_RT
+  ///
+  // First the button.
+  connect(m_ui->integrateToDtRtPushButton, &QPushButton::clicked, this, [&]() {
+    integrate("TO_DT_RT");
+  });
+  // And now the action represented by a shortcut.
+  action_label = "Integrate to an ion mobility / TIC chromatogram color map";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, Ctrl+R"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToDtRtPushButton->addAction(action_p);
+  m_ui->integrateToDtRtPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger" << static_cast<QAction *>(QObject::sender())->text();
+    // This action is set to may different buttons all over the windows,
+    // we do not want that the action be triggered for any other window than
+    // this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToDtRtPushButton->click();
+  });
+
+  /////////// Integrate to TO_MZ_RT
+  ///
+  // First the button.
+  connect(m_ui->integrateToMzRtPushButton, &QPushButton::clicked, this, [&]() {
     integrate("TO_MZ_RT");
   });
+  // And now the action represented by a shortcut.
+  action_label = "Integrate to a mass spectrum / TIC chromatogram color map";
+  action_id.initialize("Global", "Integrations", "Any", action_label);
+  action_p = program_window_p->getActionManager()->installAction(
+    action_id, QKeySequence("Ctrl+I, Ctrl+M"));
+  // qDebug() << "Installed action:" << action_p->text()
+  //          << "label:" << action_p->shortcut();
+  m_ui->integrateToMzRtPushButton->addAction(action_p);
+  m_ui->integrateToMzRtPushButton->setToolTip(action_p->text());
+  connect(action_p, &QAction::triggered, this, [&]() {
+    qDebug() << "Trigger" << static_cast<QAction *>(QObject::sender())->text();
+    // This action is set to may different buttons all over the windows,
+    // we do not want that the action be triggered for any other window than
+    // this one!
+    if(!isActiveWindow())
+      return;
+    m_ui->integrateToMzRtPushButton->click();
+  });
 
   // When the filtering group box is unchecked, reset the filters and show
   // everything
 
-  connect(
-    m_ui->filteringOptionsGroupBox, &QGroupBox::clicked, [this](bool checked) {
-      if(!checked)
-        {
-          // Deactivate the filtering.
-          mp_msRunDataSetTableViewProxyModel->convertFilteringStrings(
-            0, "", "", "", "", "", "");
+  connect(m_ui->filteringOptionsGroupBox,
+          &QGroupBox::clicked,
+          this,
+          [&](bool checked) {
+            if(!checked)
+              {
+                // Deactivate the filtering.
+                mp_msRunDataSetTableViewProxyModel->convertFilteringStrings(
+                  0, "", "", "", "", "", "");
 
-          // Force filtering.
-          mp_msRunDataSetTableViewProxyModel->invalidate();
+                // Force filtering.
+                mp_msRunDataSetTableViewProxyModel->invalidate();
 
-          // Now that we have force the "defiltering", we can display the number
-          // of spectra in the status bar.
+                // Now that we have force the "defiltering", we can display the
+                // number of spectra in the status bar.
 
-          std::size_t row_count =
-            mp_msRunDataSetTableViewProxyModel->rowCount();
+                std::size_t row_count =
+                  mp_msRunDataSetTableViewProxyModel->rowCount();
 
-          // Do not set a time out for this status bar message.
-          statusBar()->showMessage(
-            QString("%1 %2 in the mass spectral data set.")
-              .arg(row_count)
-              .arg(row_count > 1 ? "spectra" : "spectrum"));
-        }
+                // Do not set a time out for this status bar message.
+                statusBar()->showMessage(
+                  QString("%1 %2 in the mass spectral data set.")
+                    .arg(row_count)
+                    .arg(row_count > 1 ? "spectra" : "spectrum"));
+              }
 
-      m_ui->filteringOptionsFrame->setVisible(checked);
-    });
+            m_ui->filteringOptionsFrame->setVisible(checked);
+          });
 
   readSettings();
 
@@ -335,7 +523,7 @@ MsRunDataSetTableViewWnd::show()
 void
 MsRunDataSetTableViewWnd::executeFilteringPushButtonClicked()
 {
-  // qDebug();
+  qDebug();
 
   // We need to get all the strings from the various line edit widgets.
   std::size_t ms_level           = m_ui->msLevelSpinBox->value();
@@ -497,20 +685,30 @@ MsRunDataSetTableViewWnd::createMainMenu()
   mp_mainMenuPushButton = new QPushButton(main_menu_icon, QString(""), this);
 
   // When the main menu push button is clicked, the menu show up.
-  connect(mp_mainMenuPushButton, &QPushButton::clicked, [this]() {
+  connect(mp_mainMenuPushButton, &QPushButton::clicked, this, [&]() {
     mp_mainMenu->show();
   });
 
-  QAction *show_mz_integration_params_dlg_action_p = new QAction(
-    "Open m/z integration params dialog", dynamic_cast<QObject *>(this));
-  show_mz_integration_params_dlg_action_p->setShortcut(
-    QKeySequence("Ctrl+O, I"));
-  show_mz_integration_params_dlg_action_p->setStatusTip(
-    "Open m/z integration params dialog");
-  connect(show_mz_integration_params_dlg_action_p,
-          &QAction::triggered,
-          this,
-          &MsRunDataSetTableViewWnd::showMzIntegrationParamsDlg);
+  QKeySequence key_sequence("Ctrl+O, I");
+  QString action_label = QString("Open m/z integration parameters dialog");
+  libXpertMassGui::ActionId action_id(
+    "Global", "Integrations", "OpenMzIntegrationParams", action_label);
+
+  ProgramWindow *program_window_p =
+    static_cast<Application *>(qApp)->getProgramWindow();
+
+  QAction *show_mz_integration_params_dlg_action_p =
+    program_window_p->getActionManager()->installAction(action_id,
+                                                        key_sequence);
+  show_mz_integration_params_dlg_action_p->setStatusTip(action_label);
+  connect(
+    show_mz_integration_params_dlg_action_p, &QAction::triggered, this, [&]() {
+      // We do not want that this action when triggered in another window
+      // that is actually active, also triggers this one. So, we only
+      // show the dialog window if this window is actually active.
+      if(isActiveWindow())
+        MsRunDataSetTableViewWnd::showMzIntegrationParamsDlg();
+    });
 
   mp_mainMenu->addAction(show_mz_integration_params_dlg_action_p);
 
@@ -581,14 +779,14 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
           source_index.internalPointer());
 
       if(view_item_p == nullptr)
-        qFatal("Pointer cannot be nullptr.");
+        qFatal() << "Pointer cannot be nullptr.";
 
       pappso::QualifiedMassSpectrumCstSPtr qualified_mass_spectrum_csp =
         view_item_p->getQualifiedMassSpectrum();
 
       if(qualified_mass_spectrum_csp == nullptr ||
          qualified_mass_spectrum_csp.get() == nullptr)
-        qFatal("Pointer cannot be nullptr");
+        qFatal() << "Pointer cannot be nullptr";
 
       // Try to get the data.
 
@@ -625,7 +823,8 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
               ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
               if(!ok)
                 {
-                  qFatal("Failed to convert QVariant 1/K0 value to double.");
+                  qFatal()
+                    << "Failed to convert QVariant 1/K0 value to double.";
                 }
             }
         }
@@ -808,7 +1007,7 @@ MsRunDataSetTableViewWnd::recordQualifiedMassSpectraToIntegrate(
   else if(integration_type == "TO_MZ_RT")
     processing_step.setDestProcessingType("MZ_RT");
   else
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug() << "Finally configured step:" << processing_step.toString();
 }
@@ -904,7 +1103,7 @@ MsRunDataSetTableViewWnd::integrate(const QString &integration_type)
     mp_programWindow->integrateToMzRt(
       nullptr, vector_of_qualified_mass_spectra_sp, local_processing_flow);
   else
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 }
 
 
