@@ -78,18 +78,17 @@ MsRunProbeInfoViewerDlg::MsRunProbeInfoViewerDlg(
     m_ui(new ::Ui::MsRunProbeInfoViewerDlg)
 {
   if(parent == Q_NULLPTR)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   if(ms_run_id_csp == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   m_ui->setupUi(this);
 
   if(!initialize())
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 }
 
-
 //! Destruct \c this MsRunProbeInfoViewerDlg instance.
 MsRunProbeInfoViewerDlg::~MsRunProbeInfoViewerDlg()
 {
@@ -97,7 +96,6 @@ MsRunProbeInfoViewerDlg::~MsRunProbeInfoViewerDlg()
   writeSettings();
 }
 
-
 //! Write the settings to as to restore the window geometry later.
 void
 MsRunProbeInfoViewerDlg::writeSettings()
@@ -115,7 +113,6 @@ MsRunProbeInfoViewerDlg::writeSettings()
   settings.endGroup();
 }
 
-
 //! Read the settings to as to restore the window geometry.
 void
 MsRunProbeInfoViewerDlg::readSettings()
@@ -137,7 +134,6 @@ MsRunProbeInfoViewerDlg::readSettings()
   settings.endGroup();
 }
 
-
 //! Handle the close event.
 void
 MsRunProbeInfoViewerDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
@@ -147,14 +143,12 @@ MsRunProbeInfoViewerDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
   QDialog::reject();
 }
 
-
 ProgramWindow *
 MsRunProbeInfoViewerDlg::getProgramWindow()
 {
   return mp_programWindow;
 }
 
-
 //! Initialize the window.
 bool
 MsRunProbeInfoViewerDlg::initialize()
@@ -293,7 +287,9 @@ MsRunProbeInfoViewerDlg::initialize()
       // data file by 60.
       std::for_each(tic_chrom_trace.begin(),
                     tic_chrom_trace.end(),
-                    [](pappso::DataPoint &dp) { dp.x /= 60; });
+                    [](pappso::DataPoint &dp) {
+                      dp.x /= 60;
+                    });
     }
 
   mp_plotWidget->addTrace(tic_chrom_trace, QColor(180, 0, 0));
@@ -400,7 +396,6 @@ MsRunProbeInfoViewerDlg::initialize()
   return true;
 }
 
-
 void
 MsRunProbeInfoViewerDlg::show()
 {
@@ -416,7 +411,6 @@ MsRunProbeInfoViewerDlg::show()
   QDialog::show();
 }
 
-
 void
 MsRunProbeInfoViewerDlg::showWindow()
 {
