@@ -57,7 +57,7 @@ MzIntegrationParamsDlg::MzIntegrationParamsDlg(QWidget *parent)
     m_ui(new ::Ui::MzIntegrationParamsDlg)
 {
   if(parent == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   m_ui->setupUi(this);
 
@@ -76,13 +76,13 @@ MzIntegrationParamsDlg::MzIntegrationParamsDlg(
     m_ui(new ::Ui::MzIntegrationParamsDlg)
 {
   if(parent == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
-  qDebug().noquote() << "The mz integration params at dialog construction:"
+  qDebug().noquote() << "The mz integration params at dialog construction:\n"
                      << mp_mzIntegrationParams->toString();
 
   if(!m_color.isValid())
-    qFatal("The color is not valid.");
+    qFatal() << "The color is not valid.";
 
   m_ui->setupUi(this);
 
@@ -138,56 +138,48 @@ MzIntegrationParamsDlg::readSettings()
 void
 MzIntegrationParamsDlg::setupWidget()
 {
-
-  // Set the right color to the line "tag" to help the user determine for which
-  // graph the parameters were initialized.
-
-  // qDebug() << "The color is:" << m_color;
-
-#if 0
-  // This was the gradient version that I find too heavy on the eye
-
-  // This one is the top color in the groupBox and is deemed to be more intense
-  QColor hsv_stop1_color = m_color.toHsv();
-  hsv_stop1_color.setHsv(hsv_stop1_color.hsvHue(),
-                         hsv_stop1_color.hsvSaturation(),
-                         hsv_stop1_color.value());
-
-  // This one is the bottom color in the groupBox and is deemed to be more light
-  QColor hsv_stop2_color = m_color.toHsv();
-  hsv_stop2_color.setHsv(hsv_stop2_color.hsvHue(),
-                         hsv_stop2_color.hsvSaturation() * 0.1,
-                         hsv_stop2_color.value());
-
-  QString color_stop1_hexrgb_name = hsv_stop1_color.name();
-  // qDebug() << color_stop1_hexrgb_name;
-  QString color_stop2_hexrgb_name = hsv_stop2_color.name();
-  // qDebug() << color_stop2_hexrgb_name;
-
-  QString style = QString(
-                    "QGroupBox {"
-                    "background-color: qlineargradient(x1: 0, y1: 0, x2: 0, "
-                    "y2: 1, stop: 0 %1, stop: 1 %2);"
-                    "border: 2px solid gray;"
-                    "}")
-                    .arg(color_stop1_hexrgb_name)
-                    .arg(color_stop2_hexrgb_name);
-#endif
-
-  QString style =
-    QString("QGroupBox {border: 2px solid %1;}").arg(m_color.name());
-  m_ui->groupBox->setStyleSheet(style);
-
-  // Now update all the values in the different controls.
-
   // qDebug() << "Setting up the dialog with these mz integration params:"
   // << m_mzIntegrationParams.toString();
 
-  m_ui->decimalPlacesSpinBox->setValue(
-    mp_mzIntegrationParams->getDecimalPlaces());
+  // Set the right color to the frame to help the user determine for which
+  // graph the parameters were initialized.
+  // qDebug() << "The frame color is:" << m_color;
+
+  QString style =
+    QString("#mainFrame {border: 2px solid %1;}").arg(m_color.name());
+  m_ui->mainFrame->setStyleSheet(style);
+
+  // Prepare the exclusion logic of the radio button widgets.
+
+  // One important thing is that whenever the data-based binning radio button is
+  // clicked, it won't be possible to store the settings as default. Indeed,
+  // data-based binning is rare, and is used when combinining mass data into an
+  // existing graph already plotted inside a plot widget.
+
+  connect(m_ui->dataBasedBinningRadioButton, &QRadioButton::clicked, [this]() {
+    m_ui->setAsDefaultParamsCheckBox->setChecked(false);
+  });
+
+  connect(m_ui->setAsDefaultParamsCheckBox,
+          &QCheckBox::checkStateChanged,
+          [this](Qt::CheckState check_state) {
+            if(check_state == Qt::CheckState::Checked)
+              m_ui->dataBasedBinningRadioButton->setChecked(false);
+          });
+
+  // The precision widget required to specify the logic with which the bins
+  // are calculated.
+
+  // The precision widget that is used to set the bin size (Dalton|Res|Ppm) must
+  // be made active when the arbitrary binning radio button is clicked but not
+  // otherwise.
+
+  connect(m_ui->arbitraryBinningRadioButton,
+          &QRadioButton::toggled,
+          [this](bool checked) {
+            mp_binSizeModelWidget->setEnabled(checked);
+          });
 
-  // The precision widget required to specify the precursor m/z values
-  // search tolerance.
   mp_binSizeModelWidget = new pappso::PrecisionWidget(this);
   m_ui->precisionWidgetHorizontalLayout->addWidget(mp_binSizeModelWidget);
   mp_binSizeModelWidget->setToolTip("Set the size of the m/z bins");
@@ -201,18 +193,51 @@ MzIntegrationParamsDlg::setupWidget()
             m_ui->arbitraryBinningRadioButton->setChecked(true);
           });
 
-  m_ui->noBinningRadioButton->setChecked(
-    mp_mzIntegrationParams->getBinningType() ==
-    pappso::MzIntegrationParams::BinningType::NONE);
-  m_ui->arbitraryBinningRadioButton->setChecked(
-    mp_mzIntegrationParams->getBinningType() ==
-    pappso::MzIntegrationParams::BinningType::ARBITRARY);
+  connect(m_ui->binCreationStrategyGroupBox,
+          &QGroupBox::toggled,
+          this,
+          &MzIntegrationParamsDlg::binCreationStrategyGroupBoxToggled);
 
-  connect(m_ui->arbitraryBinningRadioButton,
-          &QRadioButton::toggled,
-          [this](bool checked) {
-            mp_binSizeModelWidget->setEnabled(checked);
-          });
+  // Now, if any kind of binning is required, just activate the
+  // groupbox and the connected signal will make the work.
+
+  if(mp_mzIntegrationParams->getBinningType() ==
+     pappso::MzIntegrationParams::BinningType::NONE)
+    {
+      // qDebug() << "The MzIntegrationParams binning type is NONE.";
+
+      m_ui->binCreationStrategyGroupBox->setChecked(false);
+      // The connected slot will handle all the setting up of the
+      // widgets.
+    }
+  else
+    {
+      m_ui->binCreationStrategyGroupBox->setChecked(true);
+
+      if(mp_mzIntegrationParams->getBinningType() ==
+         pappso::MzIntegrationParams::BinningType::DATA_BASED)
+        {
+          m_ui->dataBasedBinningRadioButton->setChecked(true);
+          qDebug() << "The MzIntegrationParams binning type is DATA_BASED.";
+        }
+      else if(mp_mzIntegrationParams->getBinningType() ==
+              pappso::MzIntegrationParams::BinningType::ARBITRARY)
+        {
+          m_ui->arbitraryBinningRadioButton->setChecked(true);
+          qDebug() << "The MzIntegrationParams binning type is ARBITRARY.";
+        }
+      else
+        qFatal() << "Programming error. Ran out of integration methods...";
+    }
+
+  // If the binCreationStrategyGroupBox is not checked, then no binning
+  // is required.
+
+  // We have a member MzIntegrationParams object that we need to
+  // represent in the various widgets of this dialog window.
+
+  m_ui->decimalPlacesSpinBox->setValue(
+    mp_mzIntegrationParams->getDecimalPlaces());
 
   m_ui->removeZeroValueCheckBox->setCheckState(
     mp_mzIntegrationParams->isRemoveZeroValDataPoints() ? Qt::Checked
@@ -222,28 +247,45 @@ MzIntegrationParamsDlg::setupWidget()
           this,
           &MzIntegrationParamsDlg::applyPushButtonClicked);
 
+  m_ui->binSizeDivisorSpinBox->setValue(
+    mp_mzIntegrationParams->getBinSizeDivisor());
+
   readSettings();
 }
 
 void
-MzIntegrationParamsDlg::binningRadioButtonToggled(bool checked)
+MzIntegrationParamsDlg::binCreationStrategyGroupBoxToggled(bool checked)
 {
-  QRadioButton *radioButton = static_cast<QRadioButton *>(QObject::sender());
+  qDebug() << "The bin creation strategy group box is checked or not?"
+           << checked;
 
-  if(radioButton == m_ui->noBinningRadioButton)
+  if(checked)
     {
-      if(checked == true)
-        mp_mzIntegrationParams->setBinningType(
-          pappso::MzIntegrationParams::BinningType::NONE);
+      // The user is willing to configure bin creation.
+      // Set the values as we have them in the member MzIntegrationParams.
+
+      if(mp_mzIntegrationParams->getBinningType() ==
+         pappso::MzIntegrationParams::BinningType::DATA_BASED)
+        {
+          m_ui->dataBasedBinningRadioButton->setChecked(true);
+          // When data based binning is selected, that can never become
+          // a default. See the connect lambda above.
+        }
+      else if(mp_mzIntegrationParams->getBinningType() ==
+              pappso::MzIntegrationParams::BinningType::ARBITRARY)
+        {
+          m_ui->arbitraryBinningRadioButton->setChecked(true);
+        }
+      else
+        {
+          // Cannot say qFatal() here because at this stage,
+          // mp_mzIntegrationParams is still set to ::NONE.
+
+          // Then, by default,
+          qDebug() << "Setting the default binning logic: arbitrary.";
+          m_ui->arbitraryBinningRadioButton->setChecked(true);
+        }
     }
-  else if(radioButton == m_ui->arbitraryBinningRadioButton)
-    {
-      if(checked == true)
-        mp_mzIntegrationParams->setBinningType(
-          pappso::MzIntegrationParams::BinningType::ARBITRARY);
-    }
-  else
-    qFatal("Programming error.");
 }
 
 QString
@@ -257,11 +299,22 @@ MzIntegrationParamsDlg::setBinningType(
   pappso::MzIntegrationParams::BinningType binningType)
 {
   if(binningType == pappso::MzIntegrationParams::BinningType::NONE)
-    m_ui->noBinningRadioButton->setChecked(true);
+    {
+      m_ui->binCreationStrategyGroupBox->setChecked(false);
+    }
+
   else if(binningType == pappso::MzIntegrationParams::BinningType::ARBITRARY)
-    m_ui->arbitraryBinningRadioButton->setChecked(true);
+    {
+      m_ui->binCreationStrategyGroupBox->setChecked(true);
+      m_ui->arbitraryBinningRadioButton->setChecked(true);
+    }
+  else if(binningType == pappso::MzIntegrationParams::BinningType::DATA_BASED)
+    {
+      m_ui->binCreationStrategyGroupBox->setChecked(true);
+      m_ui->dataBasedBinningRadioButton->setChecked(true);
+    }
   else
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 }
 
 void
@@ -283,6 +336,14 @@ MzIntegrationParamsDlg::setDecimalPlaces(int decimal_places)
   m_ui->decimalPlacesSpinBox->setValue(decimal_places);
 }
 
+void
+MzIntegrationParamsDlg::setBinSizeDivisor(int divisor)
+{
+  Q_ASSERT(divisor > 0);
+
+  m_ui->binSizeDivisorSpinBox->setValue(divisor);
+}
+
 void
 MzIntegrationParamsDlg::keyPressEvent(QKeyEvent *event)
 {
@@ -309,38 +370,51 @@ MzIntegrationParamsDlg::applyPushButtonClicked()
 {
   // qDebug();
 
-  // We need to check all the widgets, extract their information and then craft
-  // a pappso::MzIntegrationParams instance that we'll pass to any widget (the
-  // trace plot composite widget) that might be listening. We make a new
-  // instance by copying the member instance because that member instance has
-  // data that are not configured in this dialog. We would loose those data if
-  // we created a default mz integration params instance.
+  // We need to check all the widgets, extract their information and then
+  // craft a pappso::MzIntegrationParams instance that we'll pass to any
+  // widget (the trace plot composite widget) that might be listening. We make
+  // a new instance by copying the member instance because that member
+  // instance has data that are not configured in this dialog. We would loose
+  // those data if we created a default mz integration params instance.
 
   pappso::MzIntegrationParams mz_integration_params;
   mz_integration_params.initialize(*mp_mzIntegrationParams);
 
   // qDebug().noquote() << "Before reading all the widgets' values::"
-  //<< mz_integration_params.toString();
+  //                    << mz_integration_params.toString(0, " ");
 
-  if(m_ui->noBinningRadioButton->isChecked())
-    mz_integration_params.setBinningType(
-      pappso::MzIntegrationParams::BinningType::NONE);
+  if(!m_ui->binCreationStrategyGroupBox->isChecked())
+    {
+      mz_integration_params.setBinningType(
+        pappso::MzIntegrationParams::BinningType::NONE);
+    }
   else if(m_ui->arbitraryBinningRadioButton->isChecked())
-    mz_integration_params.setBinningType(
-      pappso::MzIntegrationParams::BinningType::ARBITRARY);
+    {
+      mz_integration_params.setBinningType(
+        pappso::MzIntegrationParams::BinningType::ARBITRARY);
+    }
+  else if(m_ui->dataBasedBinningRadioButton->isChecked())
+    {
+      mz_integration_params.setBinningType(
+        pappso::MzIntegrationParams::BinningType::DATA_BASED);
+    }
+  else
+    qFatal() << "Programming error.";
 
   mz_integration_params.setBinSizeModel(mp_binSizeModel);
 
   mz_integration_params.setDecimalPlaces(m_ui->decimalPlacesSpinBox->value());
 
+  mz_integration_params.setBinSizeDivisor(m_ui->binSizeDivisorSpinBox->value());
+
   mz_integration_params.setRemoveZeroValDataPoints(
     m_ui->removeZeroValueCheckBox->isChecked());
 
   // Finally set back to the member datum the elaborated params.
   mp_mzIntegrationParams->initialize(mz_integration_params);
 
-  qDebug().noquote() << "MzIntegrationParamsDlg: the newly set parameters:"
-                     << toString();
+  // qDebug().noquote() << "MzIntegrationParamsDlg: the newly set parameters:"
+  //                    << mp_mzIntegrationParams->toString(0, " ");
 
   // Now handle the saving
 
