@@ -42,18 +42,16 @@
 #include <QMouseEvent>
 #include <QDebug>
 
-
 /////////////////////// Local includes
 #include "PlotAreaOverlay.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
 {
 
 
-PlotAreaOverlay::PlotAreaOverlay(QWidget *parent) : QWidget(parent)
+PlotAreaOverlay::PlotAreaOverlay(QWidget *parent): QWidget(parent)
 {
   // qDebug();
 
@@ -70,36 +68,32 @@ PlotAreaOverlay::PlotAreaOverlay(QWidget *parent) : QWidget(parent)
   setAttribute(Qt::WA_TransparentForMouseEvents);
 }
 
-
 PlotAreaOverlay::~PlotAreaOverlay()
 {
 }
 
-
 void
-PlotAreaOverlay::setVertRulerVisible(bool is_visible)
+PlotAreaOverlay::setVertRuleVisible(bool is_visible)
 {
   m_isVertRulerVisible = is_visible;
 }
 
-
 bool
 PlotAreaOverlay::isVertRulerVisible()
 {
   return m_isVertRulerVisible;
 }
 
-
 void
 PlotAreaOverlay::setLastHorSliderValue(int value)
 {
   m_horSliderValue = value;
 }
 
-
 void
 PlotAreaOverlay::paintEvent([[maybe_unused]] QPaintEvent *paint_event)
 {
+
   if(m_isVertRulerVisible)
     {
       raise();
