@@ -42,14 +42,13 @@
 #include <QPointer>
 #include <QEvent>
 
-
 namespace MsXpS
 {
 namespace MineXpert
 {
 
 
-class PlotAreaOverlay : public QWidget
+class PlotAreaOverlay: public QWidget
 {
   Q_OBJECT
 
@@ -60,7 +59,7 @@ class PlotAreaOverlay : public QWidget
   explicit PlotAreaOverlay(QWidget *parent = nullptr);
   virtual ~PlotAreaOverlay();
 
-  void setVertRulerVisible(bool is_visible);
+  void setVertRuleVisible(bool is_visible);
   bool isVertRulerVisible();
 
   void setLastHorSliderValue(int value);
