@@ -62,7 +62,7 @@ ProcessingFlowViewerDlg::ProcessingFlowViewerDlg(BasePlotWnd *base_plot_wnd_p,
     m_ui(new ::Ui::ProcessingFlowViewerDlg)
 {
   if(base_plot_wnd_p == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // NO, we have one instance that gets hidden but not destroyed.
   // We want to destroy the dialog when it is closed.
@@ -74,19 +74,16 @@ ProcessingFlowViewerDlg::ProcessingFlowViewerDlg(BasePlotWnd *base_plot_wnd_p,
   setupDialog();
 }
 
-
 void
 ProcessingFlowViewerDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
 {
 }
 
-
 ProcessingFlowViewerDlg::~ProcessingFlowViewerDlg()
 {
   writeSettings();
 }
 
-
 //! Save the settings to later restore the window in its same position.
 void
 ProcessingFlowViewerDlg::writeSettings()
@@ -101,7 +98,6 @@ ProcessingFlowViewerDlg::writeSettings()
   settings.endGroup();
 }
 
-
 //! Read the settings to restore the window in its last position.
 void
 ProcessingFlowViewerDlg::readSettings()
@@ -116,7 +112,6 @@ ProcessingFlowViewerDlg::readSettings()
   settings.endGroup();
 }
 
-
 bool
 ProcessingFlowViewerDlg::setupDialog()
 {
@@ -128,7 +123,6 @@ ProcessingFlowViewerDlg::setupDialog()
   return true;
 }
 
-
 void
 ProcessingFlowViewerDlg::updateTraceColor(const QColor &color)
 {
@@ -140,7 +134,6 @@ ProcessingFlowViewerDlg::updateTraceColor(const QColor &color)
   m_ui->plainTextEdit->setStyleSheet(style);
 }
 
-
 void
 ProcessingFlowViewerDlg::setProcessingFlowText(
   const QString &processing_flow_text)
