@@ -38,6 +38,7 @@
 
 /////////////////////// Qt includes
 #include <QMainWindow>
+#include <QObject>
 #include <QDir>
 
 
@@ -50,60 +51,40 @@
 /////////////////////// libXpertMass includes
 #include <MsXpS/libXpertMassCore/MassDataServer.hpp>
 #include <MsXpS/libXpertMassCore/MassDataClient.hpp>
-#include <MsXpS/libXpertMassGui/ScriptingEnginesBridge.hpp>
+#include <MsXpS/libXpertMassCore/RecentFilesHandler.hpp>
 
 
 /////////////////////// libXpertMassGui includes
 #include <MsXpS/libXpertMassGui/MassDataClientServerConfigDlg.hpp>
 #include <MsXpS/libXpertMassGui/IsotopicClusterGeneratorDlg.hpp>
 #include <MsXpS/libXpertMassGui/IsotopicClusterShaperDlg.hpp>
-#include <MsXpS/libXpertMassGui/ScriptingGuiUtils.hpp>
-#include <MsXpS/libXpertMassGui/ScriptingWnd.hpp>
+#include "MsXpS/libXpertMassGui/JavaScriptingEnvironment.hpp"
+#include "MsXpS/libXpertMassGui/JavaScriptingGuiUtils.hpp"
+#include "MsXpS/libXpertMassGui/JavaScriptingWnd.hpp"
+#include "MsXpS/libXpertMassGui/ActionManager.hpp"
 
 
 /////////////////////// Local includes
-#include "config.h"
-#include "AboutDlg.hpp"
-
-#include "MsRunLoader.hpp"
-#include "vendor/BrukerTimsTofMsRunLoader.hpp"
-#include "vendor/PwizLiteMsRunLoader.hpp"
-
-#include "OpenMsRunDataSetsDlg.hpp"
-
-#include "../nongui/MassDataIntegrator.hpp"
-
-#include "TaskMonitorWnd.hpp"
-
-#include "DataPlottableTree.hpp"
-#include "../nongui/MassSpecDataFileLoader.hpp"
-
-#include "BasePlotCompositeWidget.hpp"
-
-#include "TicXicChromTracePlotWnd.hpp"
-#include "MassSpecTracePlotWnd.hpp"
-#include "DriftSpecTracePlotWnd.hpp"
-
-#include "DriftSpecMassSpecColorMapWnd.hpp"
-#include "TicXicChromMassSpecColorMapWnd.hpp"
-#include "TicXicChromDriftSpecColorMapWnd.hpp"
-
-#include "XicExtractionWnd.hpp"
-
-#include "ConsoleWnd.hpp"
-
-#include "../nongui/AnalysisPreferences.hpp"
-#include "AnalysisPreferencesDlg.hpp"
 
 // All the integrators that are based on the use of Qualified Mass Spectrum
 // Vector Visitors.
 
-#include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToRt.hpp"
-#include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToDt.hpp"
-#include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToMz.hpp"
-#include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToTicInt.hpp"
-#include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz.hpp"
-#include "../nongui/QualifiedMassSpectrumVectorMassDataIntegratorToRtDt.hpp"
+#include "AboutDlg.hpp"
+#include "BasePlotCompositeWidget.hpp"
+#include "DataPlottableTree.hpp"
+#include "DriftSpecMassSpecColorMapWnd.hpp"
+#include "OpenMsRunDataSetsDlg.hpp"
+#include "QualifiedMassSpectrumVectorMassDataIntegratorToDt.hpp"
+#include "QualifiedMassSpectrumVectorMassDataIntegratorToMz.hpp"
+#include "TaskMonitorWnd.hpp"
+#include "TicXicChromDriftSpecColorMapWnd.hpp"
+#include "TicXicChromMassSpecColorMapWnd.hpp"
+#include "TicXicChromTracePlotWnd.hpp"
+#include "XicExtractionWnd.hpp"
+#include "MassSpecTracePlotWnd.hpp"
+#include "DriftSpecTracePlotWnd.hpp"
+#include "ConsoleWnd.hpp"
+#include "DiscoveriesPreferencesDlg.hpp"
 
 namespace MsXpS
 {
@@ -112,6 +93,7 @@ namespace MineXpert
 
 class MsRunReadTask;
 class MsRunProbeTask;
+class ApplicationPreferencesWnd;
 
 class ProgramWindow: public QMainWindow
 {
@@ -147,11 +129,13 @@ class ProgramWindow: public QMainWindow
 
   const QString &applicationName() const;
 
-  void setMaxThreadUseCount(std::size_t count);
-  std::size_t getMaxThreadUseCount();
+  void setMaxThreadUseCount(int count);
+  int getMaxThreadUseCount();
 
   void incrementLoadedFileCount();
 
+  void setupWindow();
+
   Q_INVOKABLE bool
   openMassSpectrometryFileDlg(const QString &dir_name = QDir::homePath(),
                               bool full_in_memory     = false);
@@ -170,7 +154,7 @@ class ProgramWindow: public QMainWindow
   void openMassSpectrometryFileFromText(const QString &text,
                                         const QString &sample_name);
 
-  void openAnalysisPreferencesDlg();
+  void updateDiscoveriesPreferences(const DiscoveriesPreferences &discovery_preferences);
 
   void msRunDataSetRemovalRequested(MsRunDataSetCstSPtr &ms_run_data_set_csp);
 
@@ -184,35 +168,35 @@ class ProgramWindow: public QMainWindow
 
   AboutDlg *showAboutDlg();
 
-  void showOpenMsRunDataSetsWnd();
+  void showMsRunDataSetsWnd();
   const OpenMsRunDataSetsDlg *getOpenMsRunDataSetsDlg() const;
 
   void showTicXicChromatogramsWnd();
   void showMassSpectraWnd();
-  void showDriftSpectraWnd();
+  void showIonMobilitySpectraWnd();
 
-  void showXicExtractionWnd();
+  void showXicExtractionsWnd();
 
-  void showTicXicChromMassSpecColorMapWnd();
-  void showTicXicChromDriftSpecColorMapWnd();
-  void showDriftSpecMassSpecColorMapWnd();
+  void showTicXicChromMassSpecColorMapsWnd();
+  void showTicXicChromIonMobSpecColorMapsWnd();
+  void showIonMobSpecMassSpecColorMapsWnd();
 
   void showTaskMonitorWnd();
 
   void showConsoleWnd();
 
   void showScriptingWnd();
-  libXpertMassGui::ScriptingWnd *getScriptingWnd();
-
-  void saveWorkspace();
+  libXpertMassGui::JavaScriptingWnd *getScriptingWnd();
 
   void showMsRunDataSetTableViewWnd(MsRunDataSetCstSPtr ms_run_data_set_csp,
                                     const QColor &color);
 
-  void showIsotopicClusterShaperDlg();
   Q_INVOKABLE void showIsotopicClusterGeneratorDlg();
+  void showIsotopicClusterShaperDlg();
 
-  void initializeScripting();
+  void showApplicationPreferencesWnd();
+
+  void saveWorkspace();
 
   BaseTracePlotWnd *getPlotWndPtr(const QString &type_name);
   TaskMonitorWnd *getTaskMonitorWnd() const;
@@ -292,6 +276,8 @@ class ProgramWindow: public QMainWindow
 
   bool startClient(const QString &ip_address, int port_number);
 
+  libXpertMassGui::ActionManager *getActionManager();
+
   ///////////////////////////// public slots /////////////////////////////
   ///////////////////////////// public slots /////////////////////////////
 
@@ -305,18 +291,18 @@ class ProgramWindow: public QMainWindow
 
   void finishedXicIntegrationToRt(MassDataIntegrator *mass_data_integrator_p);
 
-  libXpertMassGui::MassDataClientServerConfigDlg *configureNetworkConnection(bool no_dlg_show = false);
+  libXpertMassGui::MassDataClientServerConfigDlg *
+  configureNetworkConnection(bool no_dlg_show = false);
 
-  void logTextToConsole(QString msg);
-  void logColoredTextToConsole(QString text, const QColor &color);
+  void logTextToConsole(const QString &msg);
+  void logColoredTextToConsole(const QString &text, const QColor &color);
 
   QColor getColorForMsRunDataSet(MsRunDataSetCstSPtr ms_run_data_set_csp) const;
 
   QFile *getAnalysisFilePtr();
-  AnalysisPreferences *getAnalysisPreferences();
-
-  void recordAnalysisStanza(QString stanza, const QColor &color = Qt::black);
+  DiscoveriesPreferences *getDiscoveriesPreferences();
 
+  void recordAnalysisStanza(const QString &stanza, const QColor &color = Qt::black);
 
   ///////////////////////////// signals /////////////////////////////
   ///////////////////////////// signals /////////////////////////////
@@ -369,7 +355,7 @@ class ProgramWindow: public QMainWindow
 
   // The user can limit the max number of threads to use. 0 is no limitation
   // (all the available threads are going to be used).
-  std::size_t m_maxThreadUseCount = 0;
+  int m_maxThreadUseCount = 0;
 
   // We need to track all the plot widgets and plottables. This tree aims at
   // storing the structure of all the plottables in all the plot widgets, in all
@@ -397,7 +383,8 @@ class ProgramWindow: public QMainWindow
 
   ConsoleWnd *mp_consoleWnd = nullptr;
 
-  libXpertMassGui::ScriptingWnd *mp_scriptingWnd = nullptr;
+  libXpertMassGui::JavaScriptingWnd *mp_scriptingWnd = nullptr;
+  ApplicationPreferencesWnd *mp_applicationPreferencesWnd = nullptr;
 
   libXpertMassGui::IsotopicClusterGeneratorDlg *mp_isotopicClusterGeneratorDlg =
     nullptr;
@@ -407,23 +394,26 @@ class ProgramWindow: public QMainWindow
   libXpertMassGui::MassDataClientServerConfigDlg *mp_clientServerConfigDlg =
     nullptr;
 
-  AnalysisPreferencesDlg *mp_analysisPreferencesDlg = nullptr;
-
   QFile *mpa_analysisFile = nullptr;
 
   AboutDlg *mp_aboutDlg = nullptr;
 
-  AnalysisPreferences *mpa_analysisPreferences = nullptr;
+  DiscoveriesPreferences *mpa_discoveriesPreferences = nullptr;
 
-  libXpertMassCore::MassDataClient *mp_massDataClient  = nullptr;
+  libXpertMassCore::MassDataClient *mp_massDataClient = nullptr;
   libXpertMassCore::MassDataServer *mp_massDataServer = nullptr;
 
+  libXpertMassGui::ActionManager *mp_actionManager = nullptr;
+
   // The map that relates each MS run data set with the corresponding ms run
   // data set table view window.
   std::map<MsRunDataSetCstSPtr, MsRunDataSetTableViewWnd *>
     mp_msRunDataSetTableViewWndMap;
 
-  QMenu *mp_fileMenu                = nullptr;
+  QMenu *mp_fileMenu                   = nullptr;
+  QMenu *mp_recentFilesMenu            = nullptr;
+  QAction *mp_recentFilesMenuSeparator = nullptr;
+
   QMenu *mp_windowsMenu             = nullptr;
   QMenu *mp_utilitiesMenu           = nullptr;
   QMenu *mp_preferencesMenu         = nullptr;
@@ -435,13 +425,16 @@ class ProgramWindow: public QMainWindow
   QAction *mp_clientServerConfigDlgAct;
   QAction *mp_quitAct;
 
+  libXpertMassCore::RecentFilesHandler m_recentFilesHandler;
+
   void writeSettings();
   void readSettings();
 
   void initializeAllWindows();
   void createMenusAndActions();
+  void updateRecentFilesMenu();
 
-  void setupWindow();
+  void initializeApplicationPreferencesWnd();
 
   int selectMsRun(std::vector<pappso::MsRunIdCstSPtr> &ms_run_ids);
 
@@ -452,6 +445,10 @@ class ProgramWindow: public QMainWindow
   void calculateInitialMsRunDataSetStatistics(
     MsRunDataSetCstSPtr ms_run_data_set_csp);
 
+  void initializeScripting();
+
+  void displayArticleCitationHelpPage();
+
   bool startServer();
   void stopServer();
   void stopClient();
