@@ -74,12 +74,10 @@ SaveToGraphicsFileDlg::SaveToGraphicsFileDlg(
   initialize();
 }
 
-
 SaveToGraphicsFileDlg::~SaveToGraphicsFileDlg()
 {
 }
 
-
 void
 SaveToGraphicsFileDlg::readSettings()
 {
@@ -113,7 +111,6 @@ SaveToGraphicsFileDlg::readSettings()
   settings.endGroup();
 }
 
-
 void
 SaveToGraphicsFileDlg::writeSettings()
 {
@@ -134,7 +131,6 @@ SaveToGraphicsFileDlg::writeSettings()
   settings.endGroup();
 }
 
-
 void
 SaveToGraphicsFileDlg::initialize()
 {
@@ -199,12 +195,11 @@ SaveToGraphicsFileDlg::initialize()
           &SaveToGraphicsFileDlg::cancelPushButton);
 }
 
-
 void
 SaveToGraphicsFileDlg::okPushButton()
 {
   if(mp_plotWidget == Q_NULLPTR)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // We only need file names if the destination is not the clipboard.
 
@@ -282,7 +277,6 @@ SaveToGraphicsFileDlg::okPushButton()
   done(QDialog::Accepted);
 }
 
-
 void
 SaveToGraphicsFileDlg::cancelPushButton()
 {
@@ -290,7 +284,6 @@ SaveToGraphicsFileDlg::cancelPushButton()
   done(QDialog::Rejected);
 }
 
-
 void
 SaveToGraphicsFileDlg::formatItemChanged(int index)
 {
