@@ -55,7 +55,7 @@ SavitzkyGolayFilterParamsDlg::SavitzkyGolayFilterParamsDlg(QWidget *parent)
   : QDialog(parent), m_ui(new ::Ui::SavitzkyGolayFilterParamsDlg)
 {
   if(parent == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   m_ui->setupUi(this);
 
@@ -72,7 +72,7 @@ SavitzkyGolayFilterParamsDlg::SavitzkyGolayFilterParamsDlg(
     m_ui(new ::Ui::SavitzkyGolayFilterParamsDlg)
 {
   if(parent == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug().noquote() << "The mz integration params at dialog construction:"
   //<< m_savgolParams.toString();
@@ -82,14 +82,12 @@ SavitzkyGolayFilterParamsDlg::SavitzkyGolayFilterParamsDlg(
   setupWidget();
 }
 
-
 SavitzkyGolayFilterParamsDlg::~SavitzkyGolayFilterParamsDlg()
 {
   // qDebug();
   writeSettings();
 }
 
-
 void
 SavitzkyGolayFilterParamsDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
 {
@@ -100,7 +98,6 @@ SavitzkyGolayFilterParamsDlg::closeEvent([[maybe_unused]] QCloseEvent *event)
   emit savitzkyGolayFilterParamsDlgShouldBeDestroyedSignal();
 }
 
-
 //! Write the settings to as to restore the window geometry later.
 void
 SavitzkyGolayFilterParamsDlg::writeSettings()
@@ -115,7 +112,6 @@ SavitzkyGolayFilterParamsDlg::writeSettings()
   settings.endGroup();
 }
 
-
 //! Read the settings to as to restore the window geometry.
 void
 SavitzkyGolayFilterParamsDlg::readSettings()
@@ -130,7 +126,6 @@ SavitzkyGolayFilterParamsDlg::readSettings()
   settings.endGroup();
 }
 
-
 void
 SavitzkyGolayFilterParamsDlg::setupWidget()
 {
@@ -158,14 +153,12 @@ SavitzkyGolayFilterParamsDlg::setupWidget()
   readSettings();
 }
 
-
 QString
 SavitzkyGolayFilterParamsDlg::toString() const
 {
   return m_savgolParams.toString();
 }
 
-
 void
 SavitzkyGolayFilterParamsDlg::keyPressEvent(QKeyEvent *event)
 {
@@ -187,7 +180,6 @@ SavitzkyGolayFilterParamsDlg::show()
   QDialog::show();
 }
 
-
 void
 SavitzkyGolayFilterParamsDlg::applyPushButtonClicked()
 {
