@@ -48,11 +48,9 @@
 
 /////////////////////// Local includes
 #include "TicXicChromDriftSpecColorMapPlotCompositeWidget.hpp"
-#include "TicXicChromTracePlotWidget.hpp"
 #include "BaseColorMapPlotWnd.hpp"
 #include "ui_BasePlotCompositeWidget.h"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -68,19 +66,19 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::
   setupWidget();
 }
 
-
 TicXicChromDriftSpecColorMapPlotCompositeWidget::
   ~TicXicChromDriftSpecColorMapPlotCompositeWidget()
 {
   // qDebug();
 }
 
-
 void
 TicXicChromDriftSpecColorMapPlotCompositeWidget::setupWidget()
 {
   // qDebug();
 
+  setWindowIcon(qApp->windowIcon());
+
   /************  The QCustomPlot widget *************/
   /************  The QCustomPlot widget *************/
   mp_plotWidget = new pappso::TicXicChromDriftSpecColorMapPlotWidget(
@@ -165,7 +163,6 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::setupWidget()
   m_ui->duplicateTracePushButton->hide();
 }
 
-
 void
 TicXicChromDriftSpecColorMapPlotCompositeWidget::lastCursorHoveredPoint(
   const QPointF &pointf)
@@ -177,7 +174,6 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::lastCursorHoveredPoint(
   // calculations.
 }
 
-
 void
 TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
@@ -352,12 +348,12 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
   if(x_axis_data_kind == pappso::Enums::DataKind::dt &&
      y_axis_data_kind != pappso::Enums::DataKind::rt)
     {
-      qFatal("Programming error.");
+      qFatal() << "Programming error.";
     }
   else if(x_axis_data_kind == pappso::Enums::DataKind::rt &&
           y_axis_data_kind != pappso::Enums::DataKind::dt)
     {
-      qFatal("Programming error.");
+      qFatal() << "Programming error.";
     }
 
   // The colormap can have its axes transposed, so we need to ensure that we
@@ -455,8 +451,10 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Now we know we have the right integration scope for x:DT and y:RT.
 
-  processing_step_sp->setDataKind(pappso::Enums::Axis::x, pappso::Enums::DataKind::dt);
-  processing_step_sp->setDataKind(pappso::Enums::Axis::y, pappso::Enums::DataKind::rt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::x,
+                                  pappso::Enums::DataKind::dt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::y,
+                                  pappso::Enums::DataKind::rt);
 
   // And now actually set the integration scope to the step.
 
@@ -551,7 +549,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
 
       if(!res)
         {
-          qFatal("Failed to get the m/z range out of the selection polygon");
+          qFatal() << "Failed to get the m/z range out of the selection polygon";
         }
 
       // At this point, change the values in the mz_integration_params so
@@ -641,7 +639,8 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
       temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
-        ->integrateToTicIntensity(plottable_p, nullptr, *temp_processing_flow_p);
+        ->integrateToTicIntensity(
+          plottable_p, nullptr, *temp_processing_flow_p);
     }
   else
     {
@@ -655,7 +654,7 @@ TicXicChromDriftSpecColorMapPlotCompositeWidget::integrationRequested(
         QMessageBox::StandardButton::NoButton);
     }
 
-    delete temp_processing_flow_p;
+  delete temp_processing_flow_p;
 
   return;
 }
