@@ -49,11 +49,9 @@
 
 /////////////////////// Local includes
 #include "TicXicChromMassSpecColorMapPlotCompositeWidget.hpp"
-#include "TicXicChromTracePlotWidget.hpp"
 #include "TicXicChromMassSpecColorMapWnd.hpp"
 #include "ui_BasePlotCompositeWidget.h"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -69,19 +67,19 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::
   setupWidget();
 }
 
-
 TicXicChromMassSpecColorMapPlotCompositeWidget::
   ~TicXicChromMassSpecColorMapPlotCompositeWidget()
 {
   // qDebug();
 }
 
-
 void
 TicXicChromMassSpecColorMapPlotCompositeWidget::setupWidget()
 {
   // qDebug();
 
+  setWindowIcon(qApp->windowIcon());
+
   /************  The QCustomPlot widget *************/
   /************  The QCustomPlot widget *************/
   mp_plotWidget = new pappso::TicXicChromMassSpecColorMapPlotWidget(
@@ -165,7 +163,6 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::setupWidget()
   m_ui->duplicateTracePushButton->hide();
 }
 
-
 void
 TicXicChromMassSpecColorMapPlotCompositeWidget::lastCursorHoveredPoint(
   const QPointF &pointf)
@@ -177,7 +174,6 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::lastCursorHoveredPoint(
   // calculations.
 }
 
-
 void
 TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
@@ -353,12 +349,12 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
   if(x_axis_data_kind == pappso::Enums::DataKind::mz &&
      y_axis_data_kind != pappso::Enums::DataKind::rt)
     {
-      qFatal("Programming error.");
+      qFatal() << "Programming error.";
     }
   else if(x_axis_data_kind == pappso::Enums::DataKind::rt &&
           y_axis_data_kind != pappso::Enums::DataKind::mz)
     {
-      qFatal("Programming error.");
+      qFatal() << "Programming error.";
     }
 
   // The colormap can have its axes transposed, so we need to ensure that we
@@ -474,8 +470,10 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
   // Now we know we have the right selection polygon for x:RT and y:MZ.
 
-  processing_step_sp->setDataKind(pappso::Enums::Axis::x, pappso::Enums::DataKind::rt);
-  processing_step_sp->setDataKind(pappso::Enums::Axis::y, pappso::Enums::DataKind::mz);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::x,
+                                  pappso::Enums::DataKind::rt);
+  processing_step_sp->setDataKind(pappso::Enums::Axis::y,
+                                  pappso::Enums::DataKind::mz);
 
   // And now actually set the integration scope to the step.
 
@@ -571,7 +569,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
 
       if(!res)
         {
-          qFatal("Failed to get the m/z range out of the selection polygon");
+          qFatal() << "Failed to get the m/z range out of the selection polygon";
         }
 
       // At this point, change the values in the mz_integration_params so
@@ -660,7 +658,8 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
       temp_processing_flow_p->getStepsRef().push_back(processing_step_sp);
 
       static_cast<BasePlotWnd *>(mp_parentWnd)
-        ->integrateToTicIntensity(plottable_p, nullptr, *temp_processing_flow_p);
+        ->integrateToTicIntensity(
+          plottable_p, nullptr, *temp_processing_flow_p);
     }
   else
     {
@@ -674,7 +673,7 @@ TicXicChromMassSpecColorMapPlotCompositeWidget::integrationRequested(
         QMessageBox::StandardButton::NoButton);
     }
 
-    delete temp_processing_flow_p;
+  delete temp_processing_flow_p;
 
   return;
 }
