@@ -36,6 +36,7 @@
 
 /////////////////////// Qt includes
 #include <QWidget>
+#include <QApplication>
 
 /////////////////////// QCustomPlot
 
@@ -46,8 +47,8 @@
 
 
 /////////////////////// Local includes
+#include "Application.hpp"
 #include "TicXicChromTracePlotCompositeWidget.hpp"
-#include "TicXicChromTracePlotWidget.hpp"
 #include "TicXicChromTracePlotWnd.hpp"
 #include "ui_BasePlotCompositeWidget.h"
 
@@ -74,6 +75,10 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
 {
   // qDebug();
 
+  static_assert(std::is_base_of_v<QWidget, TicXicChromTracePlotCompositeWidget>);
+
+  dynamic_cast<QWidget*>(this)->setWindowIcon(qApp->windowIcon());
+
   /************  The QCustomPlot widget *************/
   /************  The QCustomPlot widget *************/
   mp_plotWidget =
@@ -82,7 +87,8 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
 
   connect(mp_plotWidget,
           &pappso::TicXicChromTracePlotWidget::setFocusSignal,
-          [this]() {
+          this,
+          [&]() {
             BaseTracePlotCompositeWidget::mp_parentWnd->plotWidgetGotFocus(
               this);
           });
@@ -143,6 +149,7 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
           this,
           &TicXicChromTracePlotCompositeWidget::integrationRequested);
 
+  // createMainMenu();
 
   /************ The QCustomPlot widget *************/
 
@@ -158,6 +165,16 @@ TicXicChromTracePlotCompositeWidget::setupWidget()
   });
 }
 
+void
+TicXicChromTracePlotCompositeWidget::createMainMenu()
+{
+  qDebug() << "Completing the main menu:" << mp_mainMenu;
+
+  // Update the menu tooltip.
+  m_ui->mainMenuPushButton->setToolTip(
+    "TIC/XIC chrom. trace plot widget menu (Ctrl+P, M)");
+}
+
 void
 TicXicChromTracePlotCompositeWidget::plotWidgetKeyPressEvent(
   const pappso::BasePlotContext &context)
@@ -178,8 +195,8 @@ TicXicChromTracePlotCompositeWidget::plotWidgetKeyPressEvent(
       if(plottable_p == nullptr)
         {
 #if 0
-					// We actually do not do this because that part is handled by the base
-					// class.
+                                        // We actually do not do this because that part is handled by the base
+                                        // class.
 
           // We should inform the user if there are more than one plottable.
 
@@ -264,7 +281,7 @@ void
 TicXicChromTracePlotCompositeWidget::integrationRequested(
   const pappso::BasePlotContext &context)
 {
-  qDebug().noquote() << "20250904 - context:" << context.toString();
+  qDebug().noquote() << "context:" << context.toString();
 
   // Make a local copy of the context because we may need to modify it.
   pappso::BasePlotContext local_context;
@@ -282,11 +299,11 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
 
       double width;
       if(!local_context.msp_integrationScope->getWidth(width))
-        qFatal("Failed to get width.");
+        qFatal() << "Failed to get width.";
 
       QPointF point;
       if(!local_context.msp_integrationScope->getPoint(point))
-        qFatal("Failed to get point.");
+        qFatal() << "Failed to get point.";
 
       local_context.msp_integrationScope =
         std::make_shared<const pappso::IntegrationScope>(
@@ -307,10 +324,10 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   local_context.msp_integrationScope->range(
     pappso::Enums::Axis::x, range_start, range_end);
 
-  qDebug().noquote() << "20250904 - Local copy of context:" << local_context.toString();
+  qDebug().noquote() << "Local copy of context:" << local_context.toString();
 
-  qDebug() << "20250904 - X axis range extracted from integration scope:"
-           << range_start << "-" << range_end;
+  qDebug() << "X axis range extracted from integration scope:" << range_start
+           << "-" << range_end;
 
   // Having negative retention times does not make any sense.
   if(range_start < 0 && range_end < 0)
@@ -337,11 +354,13 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
   // need to know on what graph the user is willing to perform the
   // integration.
 
-  QCPAbstractPlottable *plottable_p = plottableToBeUsedAsIntegrationSource();
+  QCPAbstractPlottable *plottable_p =
+    dynamic_cast<const BasePlotCompositeWidget *>(this)
+      ->plottableToBeUsedAsIntegrationSource();
 
   if(plottable_p == nullptr)
     {
-      QMessageBox::information(this,
+      QMessageBox::information(dynamic_cast<QWidget *>(this),
                                "Please select *one* trace",
                                "In order to perform an integration, the source "
                                "graph needs to be selected.",
@@ -464,18 +483,6 @@ TicXicChromTracePlotCompositeWidget::integrationRequested(
       pappso::MzIntegrationParams *mz_integration_params_p =
         BasePlotCompositeWidget::getSensibleMzIntegrationParams(plottable_p);
 
-      // FIXME: this is no more correct, we now let the user define the way
-      // the integrations are performed.
-      // // Note that we cannot integrate mass spectra with a high resolution
-      // // here. We need to reduce the resolution to integer resolution.
-      // if(m_ui->integrateToDtMzPushButton->isChecked() ||
-      //    m_ui->integrateToMzRtPushButton->isChecked())
-      //   {
-      //     mz_integration_params_p->setBinningType(
-      //       pappso::MzIntegrationParams::BinningType::NONE);
-      //     mz_integration_params_p->setDecimalPlaces(0);
-      //   }
-
       // We finally have mz integ params that we can set to the processing step
       // that we are creating to document this current integration.
       // Takes ownership.
@@ -568,209 +575,19 @@ QString
 TicXicChromTracePlotCompositeWidget::craftAnalysisStanza(
   const pappso::BasePlotContext &context)
 {
-  // qDebug();
+    Q_UNUSED(context)
 
-  QCPAbstractPlottable *plottable_p = plottableToBeUsedAsIntegrationSource();
+    // qDebug().noquote() << "With context:" << context.toString();
+    // qDebug().noquote()
+    // << "We get from the base class stanza work the following text:"
+    // << m_analysisStanza;
 
-  if(plottable_p == nullptr)
-    {
-      // We should inform the user if there are more than one plottable.
+    // Since this class has no specialized data, apart those already handled
+    // in the base class function, all we need to do is return the stanza that
+    // has already been crafted by the base class.
 
-      int plottable_count = mp_plotWidget->plottableCount();
-
-      if(plottable_count > 1)
-        {
-          QMessageBox::information(
-            this,
-            "Crafting an analysis stanza for a graph",
-            "Please select a single trace and try again.");
-        }
-
-      m_analysisStanza = "";
-      return QString();
-    }
-
-  MsRunDataSetCstSPtr ms_run_data_set_csp =
-    getProcessingFlowPtrForPlottable(plottable_p)->getMsRunDataSetCstSPtr();
-
-  QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
-
-  // Craft the analysis stanza by copying the m_analysisStanza that was
-  // partially filled-in by the base classes and go on filling-in fields still
-  // marked with "%<char>" format patterns.
-
-  QString orig_stanza = m_analysisStanza;
-  QString stanza;
-
-  QChar prevChar = ' ';
-
-  for(int iter = 0; iter < orig_stanza.size(); ++iter)
-    {
-      QChar curChar = orig_stanza.at(iter);
-
-      // qDebug() << "Current char:" << curChar;
-
-      if(curChar == '\\')
-        {
-          if(prevChar == '\\')
-            {
-              stanza   += '\\';
-              prevChar  = ' ';
-              continue;
-            }
-          else
-            {
-              prevChar = '\\';
-              continue;
-            }
-        }
-
-      if(curChar == '%')
-        {
-          if(prevChar == '\\')
-            {
-              stanza   += '%';
-              prevChar  = ' ';
-              continue;
-            }
-          else
-            {
-              prevChar = '%';
-              continue;
-            }
-        }
-
-      if(curChar == 'n')
-        {
-          if(prevChar == '\\')
-            {
-              stanza += QString("\n");
-
-              // Because a newline only works if it is followed by something,
-              // and
-              // if the user wants a termination newline, then we need to
-              // duplicate that new line char if we are at the end of the
-              // string.
-
-              if(iter == orig_stanza.size() - 1)
-                {
-                  // This is the last character of the line, then, duplicate
-                  // the
-                  // newline so that it actually creates a new line in the
-                  // text.
-
-                  stanza += QString("\n");
-                }
-
-              prevChar = ' ';
-              continue;
-            }
-        }
-
-      if(prevChar == '%')
-        {
-          // The current character might have a specific signification.
-          if(curChar == 'f')
-            {
-              QFileInfo fileInfo(sample_name);
-              if(fileInfo.exists())
-                stanza += fileInfo.fileName();
-              else
-                stanza += "Untitled";
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 's')
-            {
-              QFileInfo fileInfo(sample_name);
-              if(fileInfo.exists())
-                stanza += fileInfo.fileName();
-              else
-                stanza += "Untitled";
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'X')
-            {
-              stanza += QString("%1").arg(
-                context.m_lastCursorHoveredPoint.x(), 0, 'g', 6);
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'Y')
-            {
-              // We need to get the value of the intensity for the graph, but
-              // not as an integration to INT, but simply as the y coordinate
-              // of the point at X.
-              stanza += QString("%1").arg(
-                static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
-                  ->getYatX(context.m_lastCursorHoveredPoint.x(),
-                            static_cast<QCPGraph *>(plottable_p)),
-                0,
-                'g',
-                6);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'x')
-            {
-              stanza   += QString("%1").arg(context.m_xDelta, 0, 'g', 6);
-              prevChar  = ' ';
-              continue;
-            }
-          if(curChar == 'y')
-            {
-              stanza += QString("%1").arg(context.m_yDelta, 0, 'g', 6);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'I')
-            {
-              stanza += QString("%1").arg(m_lastTicIntensity, 0, 'g', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'b')
-            {
-              stanza +=
-                QString("%1").arg(context.m_xRegionRangeStart, 0, 'f', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          if(curChar == 'e')
-            {
-              stanza += QString("%1").arg(context.m_xRegionRangeEnd, 0, 'f', 3);
-
-              prevChar = ' ';
-              continue;
-            }
-          // At this point the '%' is not followed by any special character
-          // above, so we skip them both from the text. If the '%' is to be
-          // printed, then it needs to be escaped. We do this because we do not
-          // expect that derived classes will do the format-based field-filling
-          // work later.
-
-          continue;
-        }
-      // End of
-      // if(prevChar == '%')
-
-      // The character prior this current one was not '%' so we just append
-      // the current character.
-      stanza += curChar;
-    }
-  // End of
-  // for (int iter = 0; iter < pattern.size(); ++iter)
-
-  // Finally copy the result into the member datum.
-  m_analysisStanza = stanza;
-  return stanza;
+    return m_analysisStanza;
 }
 
-
 } // namespace MineXpert
 } // namespace MsXpS
