@@ -30,29 +30,25 @@
  * END software license
  */
 
-
 /////////////////////// StdLib includes
 
-
 /////////////////////// Qt includes
-#include <QSettings>
 #include <QDebug>
 #include <QMainWindow>
+#include <QSettings>
 #include <pappsomspp/core/processing/combiners/mzintegrationparams.h>
 #include <pappsomspp/core/trace/datapoint.h>
 
-
 /////////////////////// pappsomspp includes
 
-
 /////////////////////// Local includes
+#include "../nongui/MassDataIntegratorTask.hpp"
 #include "Application.hpp"
 #include "ProgramWindow.hpp"
-#include "TicXicChromTracePlotWnd.hpp"
-#include "TicXicChromTracePlotCompositeWidget.hpp"
-#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
-#include "../nongui/MassDataIntegratorTask.hpp"
 #include "TaskMonitorCompositeWidget.hpp"
+#include "TicXicChromTracePlotCompositeWidget.hpp"
+#include "TicXicChromTracePlotWnd.hpp"
+#include <MsXpS/libXpertMassGui/ColorSelector.hpp>
 
 namespace MsXpS
 {
@@ -68,6 +64,7 @@ TicXicChromTracePlotWnd::TicXicChromTracePlotWnd(QWidget *parent,
                                                  const QString &description)
   : BaseTracePlotWnd(parent, title, settingsTitle, description)
 {
+  setWindowIcon(qApp->windowIcon());
 }
 
 //! Destruct \c this TicXicChromTracePlotWnd instance.
@@ -92,7 +89,6 @@ TicXicChromTracePlotWnd::addTracePlot(
   TicXicChromTracePlotCompositeWidget *composite_widget_p =
     new TicXicChromTracePlotCompositeWidget(
       this, "retention time (min)", "counts (a.u.)");
-
   // qDebug() << "The color:" << color;
 
   QCPGraph *new_graph_p = finalNewTracePlotConfiguration(
@@ -101,35 +97,33 @@ TicXicChromTracePlotWnd::addTracePlot(
   // Make sure we do create a new JS item for both the plot widget and the
   // graph.
 
-  QJSValue script_value;
+  QJSValue returned_js_value;
 
-  static_cast<Application *>(qApp)->publishQObject(
-    dynamic_cast<QObject *>(composite_widget_p),
-    dynamic_cast<QObject *>(this),
-    script_value,
-    "plotWidget" /*name*/,
-    QString() /*alias*/,
-    "Make available the created TicXicChromTracePlot widget.\n" /*comment*/,
-    "TicXicChromTracePlot widget can plot any number of trace graphs" /*help*/,
-    "" /*tool_tip*/,
-    color,
-    QJSEngine::CppOwnership);
+  getProgramWindow()
+    ->getScriptingWnd()
+    ->getScriptingEnvironment()
+    ->exposeQObject("plotWidget" /*name*/,
+                    QString() /*alias*/,
+                    "The newly created TicXicChromTracePlot widget",
+                    dynamic_cast<QObject *>(composite_widget_p),
+                    dynamic_cast<QObject *>(this),
+                    returned_js_value,
+                    QJSEngine::CppOwnership);
 
   QString sample_name = ms_run_data_set_csp->getMsRunId()->getSampleName();
 
   // qDebug() << "The color:" << color;
 
-  static_cast<Application *>(qApp)->publishQObject(
-    dynamic_cast<QObject *>(new_graph_p),
-    dynamic_cast<QObject *>(composite_widget_p),
-    script_value,
-    "plotGraph" /*name*/,
-    sample_name /*alias*/,
-    "Make available the created TicXicChromTracePlot graph.\n" /*comment*/,
-    "" /*help*/,
-    QString("Graph for sample %1").arg(sample_name) /*tool_tip*/,
-    color,
-    QJSEngine::CppOwnership);
+  getProgramWindow()
+    ->getScriptingWnd()
+    ->getScriptingEnvironment()
+    ->exposeQObject("plotGraph" /*name*/,
+                    sample_name.replace(" ", "_").replace("-", "_") /*alias*/,
+                    "The newly created TicXicChromTracePlot graph",
+                    dynamic_cast<QObject *>(new_graph_p),
+                    dynamic_cast<QObject *>(composite_widget_p),
+                    returned_js_value,
+                    QJSEngine::CppOwnership);
 
   return new_graph_p;
 }
@@ -169,7 +163,7 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
         {
           // That's absurd, if the MS run data set is empty and we get data
           // points, programming error.
-          qFatal("Programming error.");
+          qFatal() << "Programming error.";
         }
 
       // At this point, we have nothing to do. Inform the user.
@@ -286,7 +280,7 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
 
   // Sanity check
   if(ms_run_data_set_csp != temp_processing_flow_p->getMsRunDataSetCstSPtr())
-    qFatal("Cannot be that the ms run data set pointers be different.");
+    qFatal() << "Cannot be that the ms run data set pointers be different.";
 
   // Finally, we can delete the integrator, now that the
   // calculation is finished.
@@ -339,6 +333,7 @@ TicXicChromTracePlotWnd::finishedIntegratingToInitialTicChromatogram(
 
   // qDebug() << "going to call addTracePlot()";
 
+  // FIXME:: we could get the graph and expose it to the JavaScript environment.
   addTracePlot(integrated_trace,
                ms_run_data_set_csp,
                *temp_processing_flow_p,
@@ -362,7 +357,7 @@ TicXicChromTracePlotWnd::integrateToRt(
   MsRunDataSetCstSPtr ms_run_data_set_csp =
     processing_flow.getMsRunDataSetCstSPtr();
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Cannot be that the pointer is nullptr.");
+    qFatal() << "Cannot be that the pointer is nullptr.";
 
   // FIXME: BEGIN Sanity check that might be removed when the program is
   // stabilized.
@@ -371,7 +366,7 @@ TicXicChromTracePlotWnd::integrateToRt(
   bool integration_rt = processing_flow.innermostRange("ANY_RT", range_pair);
 
   if(!integration_rt)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // qDebug() << qSetRealNumberPrecision(10) << "Innermost RT range:"
   //          << "for y axis: " << range_pair.first << "-" << range_pair.second;
@@ -474,7 +469,6 @@ TicXicChromTracePlotWnd::integrateToRt(
                                           parent_plottable_p);
           });
 
-
   // qDebug() << "the integrator pointer:" << mass_data_integrator_p;
 
   // Allocate a new TaskMonitorCompositeWidget that will receive all the
@@ -597,7 +591,6 @@ TicXicChromTracePlotWnd::finishedIntegratingToRt(
 
   if(integrated_trace.size() < 2)
     {
-
       // This situation might be encountered when the user integration to RT:
       //
       // 1. a single spectrum for a given RT
@@ -618,7 +611,6 @@ TicXicChromTracePlotWnd::finishedIntegratingToRt(
       // qDebug() << "tic trace:" << integrated_trace.toString();
     }
 
-
   // Now that we got all we need and that we have made a safe copy
   // of the ProcessingFlow, we can delete the integrator.
   delete mass_data_integrator_p;
@@ -665,7 +657,7 @@ TicXicChromTracePlotWnd::integrateToMz(QCPAbstractPlottable *parent_plottable_p,
                                        const ProcessingFlow &processing_flow)
 {
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   // We do not handle integrations to m/z, because each trace plot window
   // handles their own data. So we just relay this call to the main program
@@ -683,7 +675,7 @@ TicXicChromTracePlotWnd::integrateToDt(QCPAbstractPlottable *parent_plottable_p,
                                        const ProcessingFlow &processing_flow)
 {
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   // We do not handle integrations to dt, because each trace plot window
   // handles their own data. So we just relay this call to the main program
@@ -698,7 +690,7 @@ TicXicChromTracePlotWnd::integrateToDtMz(
   const ProcessingFlow &processing_flow)
 {
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   // We do not handle integrations to dt, because each trace plot window
   // handles their own data. So we just relay this call to the main program
@@ -714,7 +706,7 @@ TicXicChromTracePlotWnd::integrateToMzRt(
   const ProcessingFlow &processing_flow)
 {
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToMzRt(
     parent_plottable_p, nullptr, processing_flow);
@@ -726,13 +718,12 @@ TicXicChromTracePlotWnd::integrateToDtRt(
   const ProcessingFlow &processing_flow)
 {
   if(parent_plottable_p == nullptr)
-    qFatal("Cannot be that pointer is nullptr.");
+    qFatal() << "Cannot be that pointer is nullptr.";
 
   mp_programWindow->integrateToDtRt(
     parent_plottable_p, nullptr, processing_flow);
 }
 
-
 } // namespace MineXpert
 
 } // namespace MsXpS
