@@ -39,31 +39,23 @@
 
 
 /////////////////////// pappsomspp includes
-#include <pappsomspp/massspectrum/qualifiedmassspectrum.h>
-#include <pappsomspp/msrun/msrundatasettreenode.h>
-#include <pappsomspp/msrun/msrundatasettreevisitor.h>
+#include <pappsomspp/core/massspectrum/qualifiedmassspectrum.h>
+#include <pappsomspp/core/msrun/msrundatasettreenode.h>
+#include <pappsomspp/core/msrun/msrundatasettreevisitor.h>
 
 
 /////////////////////// Local includes
 #include "ProcessingFlow.hpp"
 #include "MsRunDataSet.hpp"
 
-
 namespace MsXpS
 {
-namespace minexpert
+namespace MineXpert
 {
 
 
-class BaseMsRunDataSetTreeNodeVisitor;
-
 class MassDataIntegrator;
 
-typedef std::shared_ptr<BaseMsRunDataSetTreeNodeVisitor>
-  BaseMsRunDataSetTreeNodeVisitorSPtr;
-typedef std::shared_ptr<const BaseMsRunDataSetTreeNodeVisitor>
-  BaseMsRunDataSetTreeNodeVisitorCstSPtr;
-
 class BaseMsRunDataSetTreeNodeVisitor
   : public QObject,
     public pappso::MsRunDataSetTreeNodeVisitorInterface
@@ -73,17 +65,21 @@ class BaseMsRunDataSetTreeNodeVisitor
   friend class MassDataIntegrator;
 
   public:
+  BaseMsRunDataSetTreeNodeVisitor(QObject *parent = nullptr);
   BaseMsRunDataSetTreeNodeVisitor(MsRunDataSetCstSPtr ms_run_data_set_csp,
-                                  const ProcessingFlow &processing_flow);
-
-  BaseMsRunDataSetTreeNodeVisitor(const BaseMsRunDataSetTreeNodeVisitor &other);
+                                  const ProcessingFlow &processing_flow,
+                                  QObject *parent = nullptr);
 
   virtual ~BaseMsRunDataSetTreeNodeVisitor();
 
-  void setProcessingFlow(const ProcessingFlow &processing_flow);
+  virtual BaseMsRunDataSetTreeNodeVisitor *clone(QObject *parent) const = 0;
 
-  BaseMsRunDataSetTreeNodeVisitor &
-  operator=(const BaseMsRunDataSetTreeNodeVisitor &other);
+  void setMsRunDataSet(MsRunDataSetCstSPtr ms_run_data_set_csp);
+
+  void setProcessingFlow(const ProcessingFlow &processing_flow);
+  const ProcessingFlow &getProcessingFlowCstRef() const;
+  ProcessingFlow &getProcessingFlowRef();
+  ProcessingFlow *getProcessingFlowPtr();
 
   virtual pappso::QualifiedMassSpectrumCstSPtr
   checkQualifiedMassSpectrum(const pappso::MsRunDataSetTreeNode &node);
@@ -114,7 +110,7 @@ class BaseMsRunDataSetTreeNodeVisitor
 
   protected:
   MsRunDataSetCstSPtr mcsp_msRunDataSet;
-  ProcessingFlow m_processingFlow;
+  ProcessingFlow *mp_processingFlow;
 
   std::pair<double, double> m_dtRange =
     std::pair<double, double>(std::numeric_limits<double>::quiet_NaN(),
@@ -142,6 +138,6 @@ class BaseMsRunDataSetTreeNodeVisitor
 };
 
 
-} // namespace minexpert
+} // namespace MineXpert
 
 } // namespace MsXpS
