@@ -64,7 +64,7 @@ MassDataIntegrator::MassDataIntegrator(QObject *parent)
   : QObject(parent),
     mp_processingFlow(new ProcessingFlow(dynamic_cast<QObject *>(this)))
 {
-  qFatal("Cannot be that the default constructor be used.");
+  qFatal() << "Cannot be that the default constructor be used.";
 }
 
 MassDataIntegrator::MassDataIntegrator(MsRunDataSetCstSPtr ms_run_data_set_csp,
@@ -114,7 +114,7 @@ void
 MassDataIntegrator::setMsRunDataSet(MsRunDataSetCstSPtr ms_run_data_set_csp)
 {
   if(ms_run_data_set_csp == nullptr)
-    qFatal("Pointer cannot be nullptr. Program aborted.");
+    qFatal() << "Pointer cannot be nullptr. Program aborted.";
 
   mcsp_msRunDataSet = ms_run_data_set_csp;
 }
