@@ -71,15 +71,15 @@ void
 MassDataIntegratorTask::seedInitialTicChromatogramAndMsRunDataSetStatistics(
   MsRunDataSetTreeMassDataIntegratorToRt *mass_data_integrator_p)
 {
-  qDebug() << "From thread" << QThread::currentThreadId()
-           << "now starting "
-              "mass_data_integrator_p->"
-              "seedInitialTicChromatogramAndMsRunDataSetStatistics()";
+  // qDebug() << "From thread" << QThread::currentThreadId()
+  //          << "now starting "
+  //             "mass_data_integrator_p->"
+  //             "seedInitialTicChromatogramAndMsRunDataSetStatistics()";
 
   mass_data_integrator_p->seedInitialTicChromatogramAndMsRunDataSetStatistics();
 
-  qDebug() << "From thread" << QThread::currentThreadId()
-           << "done, going to emit finishedIntegratingDataSignal";
+  // qDebug() << "From thread" << QThread::currentThreadId()
+  //          << "done, going to emit finishedIntegratingDataSignal";
 
   emit finishedIntegratingDataSignal(mass_data_integrator_p);
 }
