@@ -48,7 +48,6 @@ int massSpecDataFileLoaderSPtrMetaTypeId =
   qRegisterMetaType<MsXpS::MineXpert::MassSpecDataFileLoaderSPtr>(
     "MsXpS::MineXpert::MassSpecDataFileLoaderSPtr");
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -69,13 +68,11 @@ MassSpecDataFileLoader::MassSpecDataFileLoader(const QString &fileName,
     m_fileName = fileName;
 }
 
-
 //! Destruct \c this MassSpecDataFileLoader instance.
 MassSpecDataFileLoader::~MassSpecDataFileLoader()
 {
 }
 
-
 //! Set the MsRunDataSet in which to store the mass data.
 /*!
 
@@ -91,7 +88,7 @@ void
 MassSpecDataFileLoader::setMsRunDataSet(MsRunDataSetSPtr &ms_run_data_set_sp)
 {
   if(ms_run_data_set_sp == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // Let's see the usage count of the MsRunDataSetCstSPtr.
   // qDebug() << "Usage count:" << ms_run_data_set_sp.use_count();
@@ -102,14 +99,12 @@ MassSpecDataFileLoader::setMsRunDataSet(MsRunDataSetSPtr &ms_run_data_set_sp)
   // qDebug() << "Usage count:" << ms_run_data_set_sp.use_count();
 }
 
-
 MsRunDataSetSPtr
 MassSpecDataFileLoader::getMsRunDataSet()
 {
   return msp_msRunDataSet;
 }
 
-
 //! Set the name of the file to load.
 /*!
 
@@ -122,7 +117,6 @@ MassSpecDataFileLoader::setFileName(const QString &fileName)
   m_fileName = fileName;
 }
 
-
 //! Cancel the running operation.
 /*!
 
@@ -136,14 +130,12 @@ MassSpecDataFileLoader::cancelOperation()
   m_isOperationCancelled = true;
 }
 
-
 bool
 MassSpecDataFileLoader::shouldStop()
 {
   return m_isOperationCancelled;
 }
 
-
 void
 MassSpecDataFileLoader::spectrumListHasSize(std::size_t size)
 {
@@ -154,7 +146,6 @@ MassSpecDataFileLoader::spectrumListHasSize(std::size_t size)
   qDebug() << "20240529 - The spectrum list has size:" << m_spectrumListSize;
 }
 
-
 // This function is a callback that is called each time a new spectrum is read
 // from file. The data reading work is performed by pappso::MsRunReaderSp. Note
 // that the qualified mass spectrum might have a mass spectrum pointer that is
@@ -178,7 +169,7 @@ MassSpecDataFileLoader::setQualifiedMassSpectrum(
 
   if(qualified_mass_spectrum_csp == nullptr ||
      qualified_mass_spectrum_csp.get() == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   // Note that this is no more true: the pointer can be nullptr if the data are
   // loaded, which is now the default and soon the unique mode, in streamed
@@ -186,7 +177,7 @@ MassSpecDataFileLoader::setQualifiedMassSpectrum(
   // if(const_cast<pappso::QualifiedMassSpectrum *>(
   // qualified_mass_spectrum_csp.get())
   //->getMassSpectrumSPtr() != nullptr)
-  // qFatal("Cannot be non-nullptr");
+  // qFatal() << "Cannot be non-nullptr";
 
   // qDebug() << "Now mapping new qualified mass spectrum.";
   msp_msRunDataSet->mapMassSpectrum(qualified_mass_spectrum_csp);
@@ -207,13 +198,12 @@ MassSpecDataFileLoader::setQualifiedMassSpectrum(
     m_setQualifiedMassSpectrumCount);
 }
 
-
 int
 MassSpecDataFileLoader::loadDataFromString(const QString &msDataString,
                                            MsRunDataSet *msRunDataSet)
 {
   if(msRunDataSet == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   QStringList msDataList = msDataString.split("\n");
 
@@ -257,14 +247,12 @@ MassSpecDataFileLoader::loadDataFromString(const QString &msDataString,
   return msRunDataSet->size();
 }
 
-
 bool
 MassSpecDataFileLoader::needPeakList() const
 {
   return m_isLoadFullInMemory;
 }
 
-
 void
 MassSpecDataFileLoader::loadingEnded()
 {
