@@ -54,6 +54,7 @@
 
 /////////////////////// Local includes
 #include "globals.hpp"
+#include "MsRunDataSet.hpp"
 #include "MsRunDataSetStats.hpp"
 
 namespace MsXpS
@@ -69,9 +70,10 @@ typedef std::shared_ptr<const MsRunDataSet> MsRunDataSetCstSPtr;
 
 
 class MsRunDataSetStats;
+
 // class pappso::MzIntegrationParams;
 
-class MsRunDataSet : public QObject
+class MsRunDataSet: public QObject
 {
   Q_OBJECT
 
@@ -168,7 +170,8 @@ class MsRunDataSet : public QObject
 
   pappso::MsRunIdCstSPtr mcsp_msRunId = nullptr;
 
-  pappso::Enums::MsDataFormat m_fileFormat = pappso::Enums::MsDataFormat::unknown;
+  pappso::Enums::MsDataFormat m_fileFormat =
+    pappso::Enums::MsDataFormat::unknown;
 
   //! Tells if the data are to be or were loaded in streamed mode or not.
   bool m_isStreamed = false;
