@@ -45,7 +45,6 @@
 #include "MsRunDataSetStats.hpp"
 #include "globals.hpp"
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -56,7 +55,6 @@ MsRunDataSetStats::MsRunDataSetStats()
 {
 }
 
-
 MsRunDataSetStats::MsRunDataSetStats(const MsRunDataSetStats &other)
 {
   m_spectrumCount = other.m_spectrumCount;
@@ -133,7 +131,6 @@ MsRunDataSetStats::MsRunDataSetStats(const MsRunDataSetStats &other)
                        other.m_stdDevSteps.end());
 }
 
-
 MsRunDataSetStats &
 MsRunDataSetStats::operator=(const MsRunDataSetStats &other)
 {
@@ -225,12 +222,10 @@ MsRunDataSetStats::operator=(const MsRunDataSetStats &other)
   return *this;
 }
 
-
 MsRunDataSetStats::~MsRunDataSetStats()
 {
 }
 
-
 void
 MsRunDataSetStats::reset()
 {
@@ -282,7 +277,6 @@ MsRunDataSetStats::reset()
   m_stdDevSteps.clear();
 }
 
-
 //! Fill-in \p bins with all the m/z intervals in \p mass_spectrum
 /*!
 
@@ -354,7 +348,6 @@ MsRunDataSetStats::spectrumBins(const pappso::MassSpectrum &mass_spectrum,
   return bins.size();
 }
 
-
 void
 MsRunDataSetStats::incrementStatistics(
   const pappso::MassSpectrum &mass_spectrum)
@@ -440,7 +433,7 @@ MsRunDataSetStats::incrementStatistics(
 
   int binCount = spectrumBins(mass_spectrum, bins);
   if(mass_spectrum.size() > 1 && !binCount)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   double sum;
   double average;
@@ -478,7 +471,6 @@ MsRunDataSetStats::incrementStatistics(
   m_stdDevSteps.push_back(stdDeviation);
 }
 
-
 void
 MsRunDataSetStats::incrementStatistics(
   const pappso::MassSpectrumCstSPtr mass_spectrum_csp)
@@ -489,7 +481,6 @@ MsRunDataSetStats::incrementStatistics(
   return incrementStatistics(mass_spectrum);
 }
 
-
 void
 MsRunDataSetStats::merge(const MsRunDataSetStats &other)
 
@@ -580,7 +571,6 @@ MsRunDataSetStats::merge(const MsRunDataSetStats &other)
   // qDebug();
 }
 
-
 void
 MsRunDataSetStats::consolidate()
 {
@@ -702,7 +692,6 @@ MsRunDataSetStats::consolidate()
   // qDebug().noquote() << text;
 }
 
-
 bool
 MsRunDataSetStats::isValid()
 {
@@ -734,7 +723,6 @@ MsRunDataSetStats::isValid()
   return !errors;
 }
 
-
 QString
 MsRunDataSetStats::toString() const
 {
