@@ -94,7 +94,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::MsRunDataSetTreeMassDataIntegratorToRt(
   // Essential that the mp_processingFlow member is configured to have the right
   // pointer to the ms run data set.
   if(ms_run_data_set_csp != mp_processingFlow->getMsRunDataSetCstSPtr())
-    qFatal("The pointers should be identical.");
+    qFatal() << "The pointers should be identical.";
 }
 
 MsRunDataSetTreeMassDataIntegratorToRt::
@@ -129,8 +129,8 @@ void
 MsRunDataSetTreeMassDataIntegratorToRt::
   seedInitialTicChromatogramAndMsRunDataSetStatistics()
 {
-  qDebug() << "From thread" << QThread::currentThreadId()
-           << "starting the calculation.";
+  // qDebug() << "From thread" << QThread::currentThreadId()
+  //          << "starting the calculation.";
 
   std::chrono::system_clock::time_point chrono_start_time =
     std::chrono::system_clock::now();
@@ -183,7 +183,9 @@ MsRunDataSetTreeMassDataIntegratorToRt::
 
   pappso::IntegrationScopeCstSPtr integration_scope_csp =
     std::make_shared<const pappso::IntegrationScope>(
-      QPointF(range_start, 0), range_end - range_start, pappso::Enums::DataKind::rt);
+      QPointF(range_start, 0),
+      range_end - range_start,
+      pappso::Enums::DataKind::rt);
   step_sp->setIntegrationScope(integration_scope_csp);
   qDebug() << "Step is:" << step_sp->toString();
 
@@ -219,8 +221,8 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   std::pair<std::size_t, std::size_t> best_parallel_params =
     bestParallelIntegrationParams(node_count);
 
-  qDebug() << "ideal thread count:" << best_parallel_params.first << "with"
-           << best_parallel_params.second << "mass spec nodes per thread";
+  // qDebug() << "ideal thread count:" << best_parallel_params.first << "with"
+  //          << best_parallel_params.second << "mass spec nodes per thread";
 
   std::vector<MultiTreeNodeCombinerVisitor *> visitors;
 
@@ -228,40 +230,53 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   // the calculation.
   using Iterator = std::vector<pappso::MsRunDataSetTreeNode *>::const_iterator;
 
-  qDebug() << "Now computing calculateMsRunDataSetTreeNodeIteratorPairs, thread"
-           << QThread::currentThreadId();
+  // qDebug() << "Now computing calculateMsRunDataSetTreeNodeIteratorPairs,
+  // thread"
+  //          << QThread::currentThreadId();
 
   std::vector<std::pair<Iterator, Iterator>> iterators =
     calculateMsRunDataSetTreeNodeIteratorPairs(
       node_count, best_parallel_params.first, best_parallel_params.second);
-  qDebug()
-    << "Done computing calculateMsRunDataSetTreeNodeIteratorPairs, thread"
-    << QThread::currentThreadId();
+
+  // qDebug()
+  //   << "Done computing calculateMsRunDataSetTreeNodeIteratorPairs, thread"
+  //   << QThread::currentThreadId();
 
   for(std::size_t iter = 0; iter < iterators.size(); ++iter)
     {
-      qDebug() << "Now preparing visitors for new thread - index:" << iter
-               << "thread" << QThread::currentThreadId()
-               << "with parent's (this) thread:" << this->thread();
+      // qDebug() << "Now preparing visitors for new thread - index:" << iter
+      //          << "thread" << QThread::currentThreadId()
+      //          << "with parent's (this) thread:" << this->thread();
+
       MultiTreeNodeCombinerVisitor *multi_visitor_p =
         new MultiTreeNodeCombinerVisitor(
-          mcsp_msRunDataSet, *mp_processingFlow, this);
-      qDebug() << "Done preparing visitors for new thread - index:" << iter
-               << "thread" << QThread::currentThreadId()
-               << "with parent's (this) thread:" << this->thread();
+          mcsp_msRunDataSet,
+          *mp_processingFlow,
+          /*this not passed because of different threads.*/ nullptr);
+
+      // qDebug() << "Done preparing visitors for new thread - index:" << iter
+      //          << "thread" << QThread::currentThreadId()
+      //          << "with parent's (this) thread:" << this->thread();
 
       // Now configure the visitor to hold as many visitors as we need. We want
       // one visitor for initial TIC chrom calculation and one for the initial
       // ms run data set statistics.
 
-      qDebug() << "Now heap-allocating TicChromTreeNodeCombinerVisitor, thread"
-               << QThread::currentThreadId();
+      // qDebug() << "Now heap-allocating TicChromTreeNodeCombinerVisitor, thread"
+      //          << QThread::currentThreadId();
+
       // Start with first visitor that will compute the TIC chromatogram
       TicChromTreeNodeCombinerVisitor *tic_visitor_p =
         new TicChromTreeNodeCombinerVisitor(
-          mcsp_msRunDataSet, *mp_processingFlow, multi_visitor_p);
-      qDebug() << "Done heap-allocating TicChromTreeNodeCombinerVisitor, thread"
-               << QThread::currentThreadId();
+          mcsp_msRunDataSet,
+          *mp_processingFlow,
+          /* When we delete the multi_visitor_sp,
+           this tic_visitor_p will be* deleted
+           thanks to this parentship.*/
+          multi_visitor_p);
+
+      // qDebug() << "Done heap-allocating TicChromTreeNodeCombinerVisitor, thread"
+      //          << QThread::currentThreadId();
 
       multi_visitor_p->addVisitor(tic_visitor_p);
 
@@ -273,10 +288,14 @@ MsRunDataSetTreeMassDataIntegratorToRt::
       MsRunDataSetStats ms_run_data_set_stats;
 
       MsRunStatisticsTreeNodeVisitor *stats_visitor_p =
-        new MsRunStatisticsTreeNodeVisitor(mcsp_msRunDataSet,
-                                           *mp_processingFlow,
-                                           ms_run_data_set_stats,
-                                           multi_visitor_p);
+        new MsRunStatisticsTreeNodeVisitor(
+          mcsp_msRunDataSet,
+          *mp_processingFlow,
+          ms_run_data_set_stats,
+          /* When we delete the multi_visitor_sp,
+            this stats_visitor_p will be deleted
+            thanks to this parentship.*/
+          multi_visitor_p);
 
       multi_visitor_p->addVisitor(stats_visitor_p);
 
@@ -353,8 +372,8 @@ MsRunDataSetTreeMassDataIntegratorToRt::
       visitors.push_back(multi_visitor_p);
     }
 
-  qDebug() << "Done preparing all the visitors" << visitors.size()
-           << "in their container.";
+  // qDebug() << "Done preparing all the visitors" << visitors.size()
+  //          << "in their container.";
 
   // Now that we have configured all the visitors, perform a parallel iteration
   // in these and ask them to work on the matching ms run data
@@ -365,13 +384,13 @@ MsRunDataSetTreeMassDataIntegratorToRt::
     {
       auto multi_visitor_p = visitors.at(iter);
 
-      qDebug() << "Multi-visitor:" << multi_visitor_p << "at index:" << iter
-               << "Executing from thread:" << QThread::currentThreadId();
+      // qDebug() << "Multi-visitor:" << multi_visitor_p << "at index:" << iter
+      //          << "Executing from thread:" << QThread::currentThreadId();
 
       mcsp_msRunDataSet->msp_msRunDataSetTree->accept(
         *multi_visitor_p, iterators.at(iter).first, iterators.at(iter).second);
 
-      qDebug() << "Finished running the visitor at index:" << iter;
+      // qDebug() << "Finished running the visitor at index:" << iter;
     }
   // End of
   // #pragma omp parallel for
@@ -497,6 +516,10 @@ MsRunDataSetTreeMassDataIntegratorToRt::
   emit logTextToConsoleSignal(chrono_string);
   // qDebug().noquote() << chrono_string;
 
+  // Free all the visitors (we can do this because we have passed nullptr as the parent):
+  foreach(BaseMsRunDataSetTreeNodeVisitor *visitor_p, visitors)
+    delete visitor_p;
+
   emit finishedIntegratingToInitialTicChromatogramSignal(this);
 }
 
@@ -517,7 +540,7 @@ MsRunDataSetTreeMassDataIntegratorToRt::integrateToRt()
   // before using the integrator, that is, calling this function.
 
   if(!mp_processingFlow->getStepsCstRef().size())
-    qFatal("The processing flow cannot be empty. Program aborted.");
+    qFatal() << "The processing flow cannot be empty. Program aborted.";
 
   // Get the most recent step that holds all the specifics of this integration.
   ProcessingStepCstSPtr processing_step_csp =
