@@ -59,12 +59,14 @@ MultiTreeNodeCombinerVisitor::MultiTreeNodeCombinerVisitor(
 {
   //  qDebug() << "Processing flow has" <<
   //  mp_processingFlow.getStepsCstRef().size() << "steps";
-  qDebug() << "Current thread:" << QThread::currentThreadId()
-           << "parent thread: " << parent->thread();
+  // qDebug() << "Current thread:" << QThread::currentThreadId();
+  // if(parent != nullptr)
+  //   qDebug() << "parent thread: " << parent->thread();
 }
 
 MultiTreeNodeCombinerVisitor::~MultiTreeNodeCombinerVisitor()
 {
+  // qDebug();
 }
 
 BaseMsRunDataSetTreeNodeVisitor *
@@ -107,9 +109,9 @@ MultiTreeNodeCombinerVisitor::visit(const pappso::MsRunDataSetTreeNode &node)
     local_node.getQualifiedMassSpectrum();
 
   if(qualified_mass_spectrum_csp == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
   if(qualified_mass_spectrum_csp.get() == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   if(qualified_mass_spectrum_csp->getMassSpectrumSPtr() == nullptr)
     {
@@ -145,7 +147,7 @@ MultiTreeNodeCombinerVisitor::visit(const pappso::MsRunDataSetTreeNode &node)
 
   if(local_node.getQualifiedMassSpectrum() == nullptr)
     {
-      qFatal("Failed to read the mass spectral data from the file.");
+      qFatal() << "Failed to read the mass spectral data from the file.";
     }
 
   // From now on, the visitors will no need to load the mass spectral data from
