@@ -38,8 +38,7 @@
 
 /////////////////////// Qt includes
 #include <QDebug>
-#include <QtQml>
-
+#include <QObject>
 
 /////////////////////// pappsomspp includes
 
@@ -164,6 +163,10 @@ ProcessingFlow::getSensibleMzIntegrationParams() const
   // 1. The binning logic params are those that
   // configure the size of the bins and it is desirable that they be stored
   // on disk because they are the same over a large analysis session.
+  // One member, m_binSizeDivisor is set by default at a value of 6, because
+  // empirically this is the best value to have the best shaped peaks. The
+  // bottom line of this is that 6 points are required to nicely shape
+  // a peak with a calculated FWHM value.
   //
   // 2. The other two members m_smallestMz and m_greatestMz values describe
   // the very first and very last points of the spectrum. If binning is
@@ -211,7 +214,7 @@ ProcessingFlow::getSensibleMzIntegrationParams() const
     }
 
   // If the binning logic parameters were not full, that might be because
-  // some values were not set because they not needed, in particular, if
+  // some values were not set because they are not needed, in particular, if
   // there is no binning, then the other binning logic parameters are not
   // needed, which in fact makes the binning logic parameters full if
   // decimal places and remove zero-val data ponts were also set.
@@ -309,10 +312,15 @@ ProcessingFlow::addFilter(pappso::FilterNameInterfaceCstSPtr filter_csp)
 {
   QString filter_name = filter_csp->name();
 
+  // qDebug() << "The filter has name:" << filter_name
+  //          << "and is:" << filter_csp->toString();
+
   using Pair     = std::pair<QString, pappso::FilterNameInterfaceCstSPtr>;
   using Map      = std::map<QString, pappso::FilterNameInterfaceCstSPtr>;
   using Iterator = Map::iterator;
 
+  // qDebug() << "Now inserting the new filter in the map.";
+
   std::pair<Iterator, bool> res =
     m_filterMap.insert(Pair(filter_name, filter_csp));
 
@@ -320,10 +328,12 @@ ProcessingFlow::addFilter(pappso::FilterNameInterfaceCstSPtr filter_csp)
     {
       // Insertion failed because one other same filter by that name was
       // already in the map. Set the new value.
+      // qDebug() << "An instance by that name existed already.";
 
       res.first->second = filter_csp;
     }
-  // else: the insert operation was performed fine.
+  // else
+    // qDebug() << "The insertion of the filter went fine.";
 }
 
 std::size_t
@@ -355,7 +365,8 @@ ProcessingFlow::innermostRange(
   bool store_only_2d_steps,
   bool store_only_rhomboid) const
 {
-  // qDebug() << "Searching for innermost range for source ProcessingType mask: "
+  // qDebug() << "Searching for innermost range for source ProcessingType mask:
+  // "
   //          << src_processing_type_mask.toBriefDesc()
   //          << "in a ProcessingFlow holding" << getStepsCstRef().size()
   //          << "steps";
@@ -388,7 +399,7 @@ ProcessingFlow::innermostRange(
 
   for(const ProcessingStepCstSPtr &step_csp : m_steps)
     {
-      // qDebug().noquote() << "20250904 - Iterating in step:\n"
+      // qDebug().noquote() << "Iterating in step:\n"
       //                    << step_csp->toString(0, "  ") << step_csp.get();
 
       double range_start;
@@ -397,7 +408,7 @@ ProcessingFlow::innermostRange(
       ProcessingType iter_x_processing_type = step_csp->m_xSrcType;
       ProcessingType iter_y_processing_type = step_csp->m_ySrcType;
 
-      // qDebug().noquote() << "20250904 - This step has X axis source type:"
+      // qDebug().noquote() << "This step has X axis source type:"
       //                    << iter_x_processing_type.toBriefDesc()
       //                    << "and Y axis source type:"
       //                    << iter_y_processing_type.toBriefDesc();
@@ -420,7 +431,7 @@ ProcessingFlow::innermostRange(
           // This is the simplest situation, there is only one dimension,
           // the x dimension, that is of interest.
 
-          // qDebug() << "20250904 - This step is 1D";
+          // qDebug() << "This step is 1D";
 
           step_csp->msp_integrationScope->range(
             pappso::Enums::Axis::x, range_start, range_end);
@@ -430,12 +441,12 @@ ProcessingFlow::innermostRange(
               inner_range_start = range_start;
               inner_range_end   = range_end;
 
-              // qDebug() << "20250904 - First iterated step, with inner range:"
+              // qDebug() << "First iterated step, with inner range:"
               //          << inner_range_start << "-" << inner_range_end;
 
               if(!store_only_2d_steps)
                 {
-                  // qDebug() << "20250904 - Step is 1D, setting step as "
+                  // qDebug() << "Step is 1D, setting step as "
                   //             "innermost step as requested.";
                   innermost_step_csp = step_csp;
                 }
@@ -496,7 +507,7 @@ ProcessingFlow::innermostRange(
         }
       else
         {
-          // qDebug() << "20250904 - This step is 2D, either Rect or Rhomb";
+          // qDebug() << "This step is 2D, either Rect or Rhomb";
 
           // At this point, we know the selection polygon is either
           // Rectangle or Rhomboid, which means we have to check what
@@ -532,11 +543,12 @@ ProcessingFlow::innermostRange(
               step_csp->msp_integrationScope->range(
                 pappso::Enums::Axis::y, range_start, range_end);
 
-              // qDebug() << "20250904 -Gotten range values:" << range_start << "-"
+              // qDebug() << "20250904 -Gotten range values:" << range_start <<
+              // "-"
               //          << range_end;
             }
           else
-            qFatal("Programming error.");
+            qFatal() << "Programming error.";
 
           // And now use the gotten range values of the currently iterated
           // step to establish if that dimension is inner or not.
@@ -544,7 +556,7 @@ ProcessingFlow::innermostRange(
           if(is_first_iterated_item)
             {
               // qDebug()
-              //   << "20250904 - This was the first item we iterated into.";
+              //   << "This was the first item we iterated into.";
 
               // Special situation where we are just setting values
               // because this is the first step that we iterate into and
@@ -563,7 +575,7 @@ ProcessingFlow::innermostRange(
             }
           else
             {
-              // qDebug() << "20250904 - Not first iterated step.";
+              // qDebug() << "Not first iterated step.";
 
               // This is not the first step we iterate into,
               // so there are already range values, that we
