@@ -129,7 +129,7 @@ ProcessingStep::setSrcProcessingType(pappso::Enums::Axis axis,
   else if(axis == pappso::Enums::Axis::y)
     m_ySrcType = processing_type;
   else
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 }
 
 void
@@ -197,7 +197,7 @@ ProcessingStep::setDataKind(pappso::Enums::Axis axis,
   else if(static_cast<int>(axis) & static_cast<int>(pappso::Enums::Axis::y))
     m_yAxisDataKind = data_kind;
   else
-    qFatal("The axis provided is not correct.");
+    qFatal() << "The axis provided is not correct.";
 }
 
 pappso::Enums::DataKind
@@ -208,7 +208,10 @@ ProcessingStep::getDataKind(pappso::Enums::Axis axis) const
   else if(static_cast<int>(axis) & static_cast<int>(pappso::Enums::Axis::y))
     return m_yAxisDataKind;
   else
-    qFatal("The axis provided is not correct.");
+    qFatal() << "The axis provided is not correct.";
+
+  // To avoid the warning.
+  return pappso::Enums::DataKind::unset;
 }
 
 bool
@@ -393,7 +396,7 @@ ProcessingStep::toString(int offset, const QString &spacer) const
 
   QString integration_scope = msp_integrationScope->toString();
   if(!integration_scope.isEmpty())
-  {
+    {
       text += "Step's integration scope:";
       text += msp_integrationScope->toString();
       text += "\n";
