@@ -82,7 +82,8 @@ class ProcessingStep
 
   void setSrcProcessingType(pappso::Enums::Axis axis,
                             const ProcessingType &processing_type);
-  void setSrcProcessingType(pappso::Enums::Axis axis, const QString &processing_type);
+  void setSrcProcessingType(pappso::Enums::Axis axis,
+                            const QString &processing_type);
   ProcessingType getSrcProcessingType(pappso::Enums::Axis axis) const;
 
   void setDestProcessingType(const ProcessingType &processing_type);
