@@ -126,9 +126,9 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkQualifiedMassSpectrum(
   pappso::QualifiedMassSpectrumCstSPtr &qualified_mass_spectrum_csp)
 {
   if(qualified_mass_spectrum_csp == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
   if(qualified_mass_spectrum_csp.get() == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   // Verify that the inner MassSpectrum in the QualifiedMassSpectrum is
   // non-nullptr.
@@ -155,7 +155,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkQualifiedMassSpectrum(
     }
 
   if(qualified_mass_spectrum_csp == nullptr)
-    qFatal("QualifiedMassSpectrum cannot be nullptr.");
+    qFatal() << "QualifiedMassSpectrum cannot be nullptr.";
 
   // qDebug() << "Retention time is:" <<
   // qualified_mass_spectrum_csp->getRtInMinutes();
@@ -164,7 +164,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkQualifiedMassSpectrum(
   // Leptocheline_MS3_DDA_IT_1.mzml test file.
 
   // if(!qualified_mass_spectrum_csp->size())
-  // qFatal("The qualified mass spectrum is empty (size is 0).");
+  // qFatal() << "The qualified mass spectrum is empty (size is 0).";
 
   // If the parameter had effectively the binary data in it, then we return it
   // as it was. Otherwise we have created one new.
@@ -271,7 +271,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::calculateIteratorPairs(
         for(auto &mass_spectrum_csp : *mcsp_qualifiedMassSpectraToIntegrateVector)
         {
           if(nullptr == mass_spectrum_csp || nullptr == mass_spectrum_csp.get())
-            qFatal("Cannot be nullptr.");
+            qFatal() << "Cannot be nullptr.";
 
           qDebug() << "Iterated mass spectrum at rt:"
             << mass_spectrum_csp.get()->getRtInMinutes();
@@ -519,10 +519,10 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
   // qDebug();
 
   if(qualified_mass_spectrum_csp == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   if(qualified_mass_spectrum_csp.get() == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   const MsFragmentationSpec fragmentation_spec =
     processing_step_csp->getMsFragmentationSpec();
@@ -612,10 +612,10 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
 
 
   if(qualified_mass_spectrum_csp == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   if(qualified_mass_spectrum_csp.get() == nullptr)
-    qFatal("Cannot be nullptr");
+    qFatal() << "Cannot be nullptr";
 
   // We want to go through all the ProcessingStep_s in the Flow.
 
@@ -633,9 +633,8 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkMsFragmentation(
 void
 QualifiedMassSpectrumVectorMassDataIntegrator::setInnermostRanges()
 {
-  qDebug().noquote()
-    << "20250904 - Setting innermost ranges for processing flow:"
-    << mp_processingFlow->toString(0, "  ");
+  qDebug().noquote() << "Setting innermost ranges for processing flow:"
+                     << mp_processingFlow->toString(0, "  ");
 
   m_innermostSteps2D.clear();
 
@@ -832,7 +831,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
                 local_integration_scope_sp, pappso::Enums::DataKind::rt));
             }
           else
-            qFatal("Programming error.");
+            qFatal() << "Programming error.";
         }
       else if(step_csp->getSrcProcessingType(pappso::Enums::Axis::y)
                 .bitMatches("MZ"))
@@ -865,7 +864,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::fillInIntegrationScopeSpecs(
                 pappso::Enums::DataKind::rt));
             }
           else
-            qFatal("Programming error.");
+            qFatal() << "Programming error.";
         }
       // else
       // qDebug() << "The step a no source type involving MZ data.";
@@ -906,7 +905,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkInnermostDtRt2DSteps(
           ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
           if(!ok)
             {
-              qFatal("Failed to convert QVariant 1/K0 value to double.");
+              qFatal() << "Failed to convert QVariant 1/K0 value to double.";
             }
         }
     }
@@ -1027,7 +1026,7 @@ QualifiedMassSpectrumVectorMassDataIntegrator::checkDtRange(
           ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
           if(!ok)
             {
-              qFatal("Failed to convert QVariant 1/K0 value to double.");
+              qFatal() << "Failed to convert QVariant 1/K0 value to double.";
             }
         }
     }
