@@ -193,7 +193,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
   // processing flow's processing type.
 
   if(!mp_processingFlow->getStepsCstRef().size())
-    qFatal("The processing flow cannot be empty. Program aborted.");
+    qFatal() << "The processing flow cannot be empty. Program aborted.";
 
   ProcessingStepCstSPtr last_processing_step_csp =
     mp_processingFlow->mostRecentStep();
@@ -211,7 +211,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
   else if(last_processing_type.bitMatches("MZ_RT"))
     m_lastIntegrationDataKind = pappso::Enums::DataKind::rt;
   else
-    qFatal("Programming error. The processing is not allowed here.");
+    qFatal() << "Programming error. The processing is not allowed here.";
 
   // Choose the right message to emit and make sanity checks.
   if(m_lastIntegrationDataKind == pappso::Enums::DataKind::rt)
@@ -225,7 +225,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
         "Integrating to a drift spectrum/mass spectrum color map");
     }
   else
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // Check the mz integration params to see if the user wants binning or not.
 
@@ -260,7 +260,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
       chrono_start_time,
       chrono_end_time);
   else
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   emit logTextToConsoleSignal(chrono_string);
 
@@ -561,7 +561,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
               first_key = ion_mobility_value;
             }
           else
-            qFatal("Programming error.");
+            qFatal() << "Programming error.";
 
           // We need to iterate in the current_map_trace_sp and find if there is
           // already a map trace by the same dt|rt value in it.
@@ -1088,7 +1088,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
               ion_mobility_value = ion_mobility_variant_value.toDouble(&ok);
               if(!ok)
                 {
-                  qFatal("Failed to convert QVariant 1/K0 value to double.");
+                  qFatal() << "Failed to convert QVariant 1/K0 value to double.";
                 }
             }
           else
@@ -1112,7 +1112,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
               //<< first_key;
             }
           else
-            qFatal("Programming error.");
+            qFatal() << "Programming error.";
 
           // Before combining, we need to check if some filtering is
           // required as for m/z data.
