@@ -88,7 +88,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::
 }
 
 QualifiedMassSpectrumVectorMassDataIntegrator *
-QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::clone(QObject *parent) const
+QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::clone(
+  QObject *parent) const
 {
   QualifiedMassSpectrumVectorMassDataIntegratorToRtDt *copy =
     new QualifiedMassSpectrumVectorMassDataIntegratorToRtDt(
@@ -192,7 +193,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
   // that will plot dt data against rt data or vice versa.
 
   if(!mp_processingFlow->getStepsCstRef().size())
-    qFatal("The processing flow cannot be empty. Program aborted.");
+    qFatal() << "The processing flow cannot be empty. Program aborted.";
 
   // When constructing this integrator, the processing flow passed as parameter
   // was used to gather innermost ranges data. When the steps that match
@@ -481,7 +482,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToRtDt::integrate()
               // m_mzRange. So we can account that limit right away.
 
               if(std::isnan(m_mzRange.first) || std::isnan(m_mzRange.second))
-                qFatal("Programming error.");
+                qFatal() << "Programming error.";
 
               pappso::Trace filtered_trace(
                 *qualified_mass_spectrum_csp->getMassSpectrumSPtr());
