@@ -74,7 +74,8 @@ class TicChromTreeNodeCombinerVisitor: public BaseMsRunDataSetTreeNodeVisitor
 
   virtual ~TicChromTreeNodeCombinerVisitor();
 
-  virtual BaseMsRunDataSetTreeNodeVisitor *clone(QObject *parent = nullptr) const override;
+  virtual BaseMsRunDataSetTreeNodeVisitor *
+  clone(QObject *parent = nullptr) const override;
 
   const pappso::MapTrace &getTicChromMapTrace() const;
 
