@@ -48,7 +48,6 @@ int ticChromatogramFromMassSpecDataFileSPtrMetaTypeId =
   qRegisterMetaType<MsXpS::MineXpert::TicChromatogramFromMassSpecDataFileSPtr>(
     "MsXpS::MineXpert::TicChromatogramFromMassSpecDataFileSPtr");
 
-
 namespace MsXpS
 {
 namespace MineXpert
@@ -69,13 +68,11 @@ TicChromatogramFromMassSpecDataFile::TicChromatogramFromMassSpecDataFile(
     m_fileName = fileName;
 }
 
-
 //! Destruct \c this TicChromatogramFromMassSpecDataFile instance.
 TicChromatogramFromMassSpecDataFile::~TicChromatogramFromMassSpecDataFile()
 {
 }
 
-
 //! Set the MsRunDataSet in which to store the mass data.
 /*!
 
@@ -92,7 +89,7 @@ TicChromatogramFromMassSpecDataFile::setMsRunDataSet(
   MsRunDataSetSPtr &ms_run_data_set_sp)
 {
   if(ms_run_data_set_sp == nullptr)
-    qFatal("Programming error.");
+    qFatal() << "Programming error.";
 
   // Let's see the usage count of the MsRunDataSetCstSPtr.
   // qDebug() << "Usage count:" << ms_run_data_set_sp.use_count();
@@ -103,14 +100,12 @@ TicChromatogramFromMassSpecDataFile::setMsRunDataSet(
   // qDebug() << "Usage count:" << ms_run_data_set_sp.use_count();
 }
 
-
 MsRunDataSetSPtr
 TicChromatogramFromMassSpecDataFile::getMsRunDataSet()
 {
   return msp_msRunDataSet;
 }
 
-
 //! Set the name of the file to load.
 /*!
 
@@ -123,7 +118,6 @@ TicChromatogramFromMassSpecDataFile::setFileName(const QString &fileName)
   m_fileName = fileName;
 }
 
-
 //! Cancel the running operation.
 /*!
 
@@ -137,14 +131,12 @@ TicChromatogramFromMassSpecDataFile::cancelOperation()
   m_isOperationCancelled = true;
 }
 
-
 bool
 TicChromatogramFromMassSpecDataFile::shouldStop()
 {
   return m_isOperationCancelled;
 }
 
-
 void
 TicChromatogramFromMassSpecDataFile::spectrumListHasSize(std::size_t size)
 {
@@ -155,7 +147,6 @@ TicChromatogramFromMassSpecDataFile::spectrumListHasSize(std::size_t size)
   // qDebug() << "The spectrum list has size:" << m_spectrumListSize;
 }
 
-
 // This function is a callback that is called each time a new spectrum is read
 // from file. The data reading work is performed by pappso::MsRunReaderSp. Note
 // that the qualified mass spectrum might have a mass spectrum pointer that is
@@ -190,14 +181,12 @@ TicChromatogramFromMassSpecDataFile::setQualifiedMassSpectrum(
     m_setQualifiedMassSpectrumCount);
 }
 
-
 bool
 TicChromatogramFromMassSpecDataFile::needPeakList() const
 {
   return m_isLoadFullInMemory;
 }
 
-
 void
 TicChromatogramFromMassSpecDataFile::loadingEnded()
 {
